@@ -47,7 +47,7 @@ static gboolean update (Icon *pIcon, CairoDock *pDock, CDAnimationData *pData, d
 	
 	pData->iBlinkCount --;
 	
-	cairo_dock_redraw_icon (pIcon, CAIRO_CONTAINER (pDock));
+	cairo_dock_redraw_icon (pIcon);
 	
 	gboolean bContinue = (pData->iBlinkCount > 0);
 	if (! bContinue && bRepeat)
