@@ -56,7 +56,7 @@ dbus-send --session --dest=org.cairodock.CairoDock /org/cairodock/CairoDock org.
 #include "interface-applet-signals.h"
 #include "applet-dbus.h"
 
-#define DISTANT_DIR "3.3.0"
+#define DISTANT_DIR "3.4.0"
 #define GETTEXT_NAME_EXTRAS "cairo-dock-plugins-extra"
 #define LOCALE_DIR_NAME "locale"
 
@@ -328,7 +328,7 @@ static gboolean _apply_package_update (gchar *cModuleName)
 	}
 	
 	// get corresponding task and free it.
-	CairoDockTask *pUpdateTask = NULL;
+	GldiTask *pUpdateTask = NULL;
 	GList *t;
 	for (t = myData.pUpdateTasksList; t != NULL; t = t->next)
 	{
@@ -336,7 +336,7 @@ static gboolean _apply_package_update (gchar *cModuleName)
 		if (pUpdateTask->pSharedMemory && strcmp (pUpdateTask->pSharedMemory, cModuleName) == 0)
 		{
 			myData.pUpdateTasksList = g_list_delete_link (myData.pUpdateTasksList, t);
-			cairo_dock_discard_task (pUpdateTask);
+			gldi_task_discard (pUpdateTask);
 			break;
 		}
 	}
@@ -351,13 +351,13 @@ static void _check_update_package (const gchar *cModuleName, CairoDockPackage *p
 		if (g_file_test (cUserDirPath, G_FILE_TEST_EXISTS))
 		{
 			cd_message ("*** the applet '%s' needs to be updated", cModuleName);
-			CairoDockTask *pUpdateTask = cairo_dock_new_task_full (0,
-				(CairoDockGetDataAsyncFunc) _get_package_path,
-				(CairoDockUpdateSyncFunc) _apply_package_update,
+			GldiTask *pUpdateTask = gldi_task_new_full (0,
+				(GldiGetDataAsyncFunc) _get_package_path,
+				(GldiUpdateSyncFunc) _apply_package_update,
 				(GFreeFunc) g_free,
 				g_strdup (cModuleName));
 			myData.pUpdateTasksList = g_list_prepend (myData.pUpdateTasksList, pUpdateTask);
-			cairo_dock_launch_task (pUpdateTask);
+			gldi_task_launch (pUpdateTask);
 		}
 	}
 }
@@ -367,7 +367,7 @@ static void _on_got_list (GHashTable *pPackagesTable, gpointer data)
 	{
 		g_hash_table_foreach (pPackagesTable, (GHFunc) _check_update_package, NULL);
 	}
-	cairo_dock_discard_task (myData.pGetListTask);
+	gldi_task_discard (myData.pGetListTask);
 	myData.pGetListTask = NULL;
 }
 
@@ -516,13 +516,7 @@ void cd_dbus_launch_service (void)
 	//\____________ create the main object on the bus.
 	myData.pMainObject = g_object_new (cd_dbus_main_get_type(), NULL);  // call cd_dbus_main_class_init() and cd_dbus_main_init().
 	
-	//\____________ register the applets installed in the default folders.
-	gboolean bAppletRegistered = FALSE;
-	bAppletRegistered |= _cd_dbus_register_all_applets_in_dir (MY_APPLET_SHARE_DATA_DIR);
-	
-	bAppletRegistered |= _cd_dbus_register_all_applets_in_dir (g_cCairoDockDataDir);
-	
-	//\____________ internationalize the applets.
+	//\____________ internationalize the applets (we need to do that before registering applets).
 	gchar *cLocaleDir = g_strdup_printf ("%s/"CD_DBUS_APPLETS_FOLDER"/"LOCALE_DIR_NAME, g_cCairoDockDataDir);  // user version of /usr/share/locale
 	if (! g_file_test (cLocaleDir, G_FILE_TEST_EXISTS))  // translations not downloaded yet.
 	{
@@ -559,6 +553,12 @@ void cd_dbus_launch_service (void)
 	bind_textdomain_codeset (GETTEXT_NAME_EXTRAS, "UTF-8");
 	g_free (cLocaleDir);
 	
+	//\____________ register the applets installed in the default folders.
+	gboolean bAppletRegistered = FALSE;
+	bAppletRegistered |= _cd_dbus_register_all_applets_in_dir (MY_APPLET_SHARE_DATA_DIR);
+	
+	bAppletRegistered |= _cd_dbus_register_all_applets_in_dir (g_cCairoDockDataDir);
+	
 	//\____________ download in background the list of existing applets.
 	if (bAppletRegistered)  // only if some third-party applets are present on the disk.
 	{
