@@ -41,6 +41,7 @@ struct _AppletConfig {
 	gboolean bEnablePopUp;
 	gboolean bEnableAnimateIcon;
 	gboolean bEnableNewModule;
+	gboolean bLaunchLauncherAPIDaemon;
 	} ;
 
 
@@ -61,7 +62,7 @@ struct _dbusApplet {
 	GObject parent;
 	DBusGConnection *connection;
 	DBusGProxy *proxy;
-	CairoDockModuleInstance *pModuleInstance;
+	GldiModuleInstance *pModuleInstance;
 	gchar *cModuleName;
 	gint id;
 	gchar *cBusPath;
@@ -102,13 +103,8 @@ typedef enum {
 
 
 #ifdef DBUSMENU_GTK_FOUND
-#if (GTK_MAJOR_VERSION < 3) || defined (DBUSMENU_GTK3_NEW)
 #include <libdbusmenu-gtk/menuitem.h>
 #include <libdbusmenu-gtk/client.h>
-#else
-#include <libdbusmenu-gtk3/menuitem.h>
-#include <libdbusmenu-gtk3/client.h>
-#endif
 
 typedef struct _CDIconData {
 	gchar *cMenuPath;
@@ -127,8 +123,8 @@ struct _AppletData {
 	GtkWidget *pModuleMainMenu;
 	dbusApplet *pCurrentMenuDbusApplet;
 	gint iMenuPosition;
-	Window xActiveWindow;
-	CairoDockTask *pGetListTask;
+	GldiWindowActor *pActiveWindow;;
+	GldiTask *pGetListTask;
 	GList *pUpdateTasksList;
 	} ;
 
