@@ -37,14 +37,14 @@ dbus-send --session --dest=org.cairodock.CairoDock /org/cairodock/CairoDock/demo
 #include "interface-applet-signals.h"
 #include "interface-applet-methods.h"
 
-static inline CairoDockModuleInstance *_get_module_instance_from_dbus_applet (dbusApplet *pDbusApplet)
+static inline GldiModuleInstance *_get_module_instance_from_dbus_applet (dbusApplet *pDbusApplet)
 {
 	return pDbusApplet->pModuleInstance;
 }
 
-static inline gboolean _get_icon_and_container_from_id (dbusApplet *pDbusApplet, const gchar *cIconID, Icon **pIcon, CairoContainer **pContainer)
+static inline gboolean _get_icon_and_container_from_id (dbusApplet *pDbusApplet, const gchar *cIconID, Icon **pIcon, GldiContainer **pContainer)
 {
-	CairoDockModuleInstance *pInstance = _get_module_instance_from_dbus_applet (pDbusApplet);
+	GldiModuleInstance *pInstance = _get_module_instance_from_dbus_applet (pDbusApplet);
 	g_return_val_if_fail (pInstance != NULL, FALSE);
 	
 	if (cIconID == NULL)
@@ -62,35 +62,51 @@ static inline gboolean _get_icon_and_container_from_id (dbusApplet *pDbusApplet,
 	return TRUE;
 }
 
+static inline int _get_container_type (GldiContainer *pContainer)
+{
+	int iType = -1;
+	
+	if (CAIRO_DOCK_IS_DOCK (GLDI_OBJECT(pContainer)))
+		return 0;
+	if (CAIRO_DOCK_IS_DESKLET (pContainer))
+		return 1;
+	if (CAIRO_DOCK_IS_DIALOG (pContainer))
+		return 2;
+	if (CAIRO_DOCK_IS_FLYING_CONTAINER (pContainer))
+		return 3;
+	
+	return iType;
+}
+
 
 static gboolean _applet_set_quick_info (dbusApplet *pDbusApplet, const gchar *cQuickInfo, const gchar *cIconID, GError **error)
 {
 	Icon *pIcon;
-	CairoContainer *pContainer;
+	GldiContainer *pContainer;
 	if (! _get_icon_and_container_from_id (pDbusApplet, cIconID, &pIcon, &pContainer))
 		return FALSE;
 	
-	cairo_dock_set_quick_info (pIcon, pContainer, cQuickInfo && *cQuickInfo != '\0' ? cQuickInfo : NULL);
-	cairo_dock_redraw_icon (pIcon, pContainer);
+	gldi_icon_set_quick_info (pIcon, cQuickInfo && *cQuickInfo != '\0' ? cQuickInfo : NULL);
+	cairo_dock_redraw_icon (pIcon);
 	return TRUE;
 }
 
 static gboolean _applet_set_label (dbusApplet *pDbusApplet, const gchar *cLabel, const gchar *cIconID, GError **error)
 {
 	Icon *pIcon;
-	CairoContainer *pContainer;
+	GldiContainer *pContainer;
 	if (! _get_icon_and_container_from_id (pDbusApplet, cIconID, &pIcon, &pContainer))
 		return FALSE;
 	
-	cairo_dock_set_icon_name (cLabel, pIcon, pContainer);
-	cairo_dock_redraw_icon (pIcon, pContainer);  /// needs a function to redraw the label...
+	gldi_icon_set_name (pIcon, cLabel);
+	cairo_dock_redraw_icon (pIcon);  /// needs a function to redraw the label...
 	return TRUE;
 }
 
 static gboolean _applet_set_icon (dbusApplet *pDbusApplet, const gchar *cImage, const gchar *cIconID, GError **error)
 {
 	Icon *pIcon;
-	CairoContainer *pContainer;
+	GldiContainer *pContainer;
 	if (! _get_icon_and_container_from_id (pDbusApplet, cIconID, &pIcon, &pContainer))
 		return FALSE;
 	
@@ -98,7 +114,7 @@ static gboolean _applet_set_icon (dbusApplet *pDbusApplet, const gchar *cImage,
 	cairo_t *pIconContext = cairo_create (pIcon->image.pSurface);
 	cairo_dock_set_image_on_icon (pIconContext, cImage, pIcon, pContainer);
 	cairo_destroy (pIconContext);
-	cairo_dock_redraw_icon (pIcon, pContainer);
+	cairo_dock_redraw_icon (pIcon);
 	return TRUE;
 }
 
@@ -106,7 +122,7 @@ static gboolean _applet_set_icon (dbusApplet *pDbusApplet, const gchar *cImage,
 static gboolean _applet_set_icon_with_default (dbusApplet *pDbusApplet, const gchar **cImages, const gchar *cIconID, GError **error)
 {
 	Icon *pIcon;
-	CairoContainer *pContainer;
+	GldiContainer *pContainer;
 	if (! _get_icon_and_container_from_id (pDbusApplet, cIconID, &pIcon, &pContainer))
 		return FALSE;
 	
@@ -119,14 +135,14 @@ static gboolean _applet_set_icon_with_default (dbusApplet *pDbusApplet, const gc
 		///cairo_dock_set_image_on_icon (pIconContext, cImage, pIcon, pContainer);
 	}
 	cairo_destroy (pIconContext);
-	cairo_dock_redraw_icon (pIcon, pContainer);
+	cairo_dock_redraw_icon (pIcon);
 	return TRUE;
 }
 */
 static gboolean _applet_set_emblem (dbusApplet *pDbusApplet, const gchar *cImage, gint iPosition, const gchar *cIconID, GError **error)
 {
 	Icon *pIcon;
-	CairoContainer *pContainer;
+	GldiContainer *pContainer;
 	if (! _get_icon_and_container_from_id (pDbusApplet, cIconID, &pIcon, &pContainer))
 		return FALSE;
 	
@@ -137,25 +153,25 @@ static gboolean _applet_set_emblem (dbusApplet *pDbusApplet, const gchar *cImage
 	else
 	{
 		if (iPosition >= CAIRO_OVERLAY_NB_POSITIONS)  // [N; 2N-1] => print the overlay
-			cairo_dock_print_overlay_on_icon_from_image (pIcon, pContainer, cImage, iPosition - CAIRO_OVERLAY_NB_POSITIONS);
+			cairo_dock_print_overlay_on_icon_from_image (pIcon, cImage, iPosition - CAIRO_OVERLAY_NB_POSITIONS);
 		else  // [0, N-1] => add it
 			cairo_dock_add_overlay_from_image (pIcon, cImage, iPosition, myApplet);  // use 'myApplet' to identify the overlays set by the Dbus plug-in (since the plug-in can't be deactivated, 'myApplet' is constant).
 	}
 	
-	cairo_dock_redraw_icon (pIcon, pContainer);
+	cairo_dock_redraw_icon (pIcon);
 	return TRUE;
 }
 
 static gboolean _applet_animate (dbusApplet *pDbusApplet, const gchar *cAnimation, gint iNbRounds, const gchar *cIconID, GError **error)
 {
 	Icon *pIcon;
-	CairoContainer *pContainer;
+	GldiContainer *pContainer;
 	if (! _get_icon_and_container_from_id (pDbusApplet, cIconID, &pIcon, &pContainer))
 		return FALSE;
 	
 	if (CAIRO_DOCK_IS_DOCK (pContainer) && cAnimation != NULL)
 	{
-		cairo_dock_request_icon_animation (pIcon, pContainer, cAnimation, iNbRounds);
+		gldi_icon_request_animation (pIcon, cAnimation, iNbRounds);
 		return TRUE;
 	}
 	return FALSE;
@@ -164,14 +180,14 @@ static gboolean _applet_animate (dbusApplet *pDbusApplet, const gchar *cAnimatio
 static gboolean _applet_show_dialog (dbusApplet *pDbusApplet, const gchar *message, gint iDuration, const gchar *cIconID, GError **error)
 {
 	Icon *pIcon;
-	CairoContainer *pContainer;
+	GldiContainer *pContainer;
 	if (! _get_icon_and_container_from_id (pDbusApplet, cIconID, &pIcon, &pContainer))
 		return FALSE;
 	
 	// On empeche l'accumulation de dialogues informatifs.
-	cairo_dock_remove_dialog_if_any_full (pIcon, FALSE);  // hors dialogues interactifs.
+	gldi_dialogs_remove_on_icon (pIcon);
 	
-	cairo_dock_show_temporary_dialog_with_icon (message, pIcon, pContainer, 1000 * iDuration, "same icon");
+	gldi_dialog_show_temporary_with_icon (message, pIcon, pContainer, 1000 * iDuration, "same icon");
 	return TRUE;
 }
 
@@ -179,39 +195,39 @@ static gboolean _applet_show_dialog (dbusApplet *pDbusApplet, const gchar *messa
 static gboolean _applet_ask_question (dbusApplet *pDbusApplet, const gchar *cMessage, const gchar *cIconID, GError **error)
 {
 	Icon *pIcon;
-	CairoContainer *pContainer;
+	GldiContainer *pContainer;
 	if (! _get_icon_and_container_from_id (pDbusApplet, cIconID, &pIcon, &pContainer))
 		return FALSE;
 	
 	if (pDbusApplet->pDialog)  // on n'autorise qu'un seul dialogue interactif a la fois.
-		cairo_dock_dialog_unreference (pDbusApplet->pDialog);
-	pDbusApplet->pDialog = cairo_dock_show_dialog_with_question (cMessage, pIcon, pContainer, "same icon", (CairoDockActionOnAnswerFunc) cd_dbus_applet_emit_on_answer_question, pDbusApplet, NULL);
+		gldi_object_unref (GLDI_OBJECT(pDbusApplet->pDialog));
+	pDbusApplet->pDialog = gldi_dialog_show_with_question (cMessage, pIcon, pContainer, "same icon", (CairoDockActionOnAnswerFunc) cd_dbus_applet_emit_on_answer_question, pDbusApplet, NULL);
 	return TRUE;
 }
 
 static gboolean _applet_ask_value (dbusApplet *pDbusApplet, const gchar *cMessage, gdouble fInitialValue, gdouble fMaxValue, const gchar *cIconID, GError **error)
 {
 	Icon *pIcon;
-	CairoContainer *pContainer;
+	GldiContainer *pContainer;
 	if (! _get_icon_and_container_from_id (pDbusApplet, cIconID, &pIcon, &pContainer))
 		return FALSE;
 	
 	if (pDbusApplet->pDialog)  // on n'autorise qu'un seul dialogue interactif a la fois.
-		cairo_dock_dialog_unreference (pDbusApplet->pDialog);
-	pDbusApplet->pDialog = cairo_dock_show_dialog_with_value (cMessage, pIcon, pContainer, "same icon", fInitialValue, fMaxValue, (CairoDockActionOnAnswerFunc) cd_dbus_applet_emit_on_answer_value, pDbusApplet, NULL);
+		gldi_object_unref (GLDI_OBJECT(pDbusApplet->pDialog));
+	pDbusApplet->pDialog = gldi_dialog_show_with_value (cMessage, pIcon, pContainer, "same icon", fInitialValue, fMaxValue, (CairoDockActionOnAnswerFunc) cd_dbus_applet_emit_on_answer_value, pDbusApplet, NULL);
 	return TRUE;
 }
 
 static gboolean _applet_ask_text (dbusApplet *pDbusApplet, const gchar *cMessage, const gchar *cInitialText, const gchar *cIconID, GError **error)
 {
 	Icon *pIcon;
-	CairoContainer *pContainer;
+	GldiContainer *pContainer;
 	if (! _get_icon_and_container_from_id (pDbusApplet, cIconID, &pIcon, &pContainer))
 		return FALSE;
 	
 	if (pDbusApplet->pDialog)  // on n'autorise qu'un seul dialogue interactif a la fois.
-		cairo_dock_dialog_unreference (pDbusApplet->pDialog);
-	pDbusApplet->pDialog = cairo_dock_show_dialog_with_entry (cMessage, pIcon, pContainer, "same icon", cInitialText, (CairoDockActionOnAnswerFunc) cd_dbus_applet_emit_on_answer_text, pDbusApplet, NULL);
+		gldi_object_unref (GLDI_OBJECT(pDbusApplet->pDialog));
+	pDbusApplet->pDialog = gldi_dialog_show_with_entry (cMessage, pIcon, pContainer, "same icon", cInitialText, (CairoDockActionOnAnswerFunc) cd_dbus_applet_emit_on_answer_text, pDbusApplet, NULL);
 	return TRUE;
 }
 // end of deprecated
@@ -238,7 +254,7 @@ static void _on_text_changed (GtkWidget *pEntry, GtkWidget *pLabel)
 	else
 		cLabel = g_strdup_printf ("<span color=\"red\"><b>%d</b></span>", iNbChars);
 	gtk_label_set_markup (GTK_LABEL (pLabel), cLabel);
-	cairo_dock_set_dialog_widget_text_color (pLabel);
+	gldi_dialog_set_widget_text_color (pLabel);
 	g_free (cLabel);
 }
 static void _on_dialog_destroyed (dbusApplet *pDbusApplet)
@@ -251,15 +267,15 @@ static gboolean _applet_popup_dialog (dbusApplet *pDbusApplet, GHashTable *hDial
 {
 	g_return_val_if_fail (hDialogAttributes != NULL, FALSE);
 	Icon *pIcon;
-	CairoContainer *pContainer;
+	GldiContainer *pContainer;
 	if (! _get_icon_and_container_from_id (pDbusApplet, cIconID, &pIcon, &pContainer))
 		return FALSE;
 	
 	if (pDbusApplet->pDialog)  // on n'autorise qu'un seul dialogue interactif a la fois.
-		cairo_dock_dialog_unreference (pDbusApplet->pDialog);
+		gldi_object_unref (GLDI_OBJECT(pDbusApplet->pDialog));
 	
-	CairoDialogAttribute attr;
-	memset (&attr, 0, sizeof (CairoDialogAttribute));
+	CairoDialogAttr attr;
+	memset (&attr, 0, sizeof (CairoDialogAttr));
 	GValue *v;
 	
 	// attributs du dialogue.
@@ -345,7 +361,11 @@ static gboolean _applet_popup_dialog (dbusApplet *pDbusApplet, GHashTable *hDial
 						pOneWidget = gtk_text_view_new ();
 						GtkWidget *pScrolledWindow = gtk_scrolled_window_new (NULL, NULL);
 						gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (pScrolledWindow), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+						#if GTK_CHECK_VERSION (3, 8, 0)
+						gtk_container_add (GTK_CONTAINER (pScrolledWindow), pOneWidget);
+						#else
 						gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (pScrolledWindow), pOneWidget);
+						#endif
 						g_object_set (pScrolledWindow, "width-request", 230, "height-request", 130, NULL);
 						pInteractiveWidget = pScrolledWindow;
 						
@@ -383,7 +403,7 @@ static gboolean _applet_popup_dialog (dbusApplet *pDbusApplet, GHashTable *hDial
 						GtkWidget *pLabel = gtk_label_new (cLabel);
 						g_free (cLabel);
 						gtk_label_set_use_markup (GTK_LABEL (pLabel), TRUE);
-						GtkWidget *pBox = _gtk_hbox_new (3);
+						GtkWidget *pBox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 3);
 						gtk_box_pack_start (GTK_BOX (pBox), pInteractiveWidget, TRUE, TRUE, 0);
 						gtk_box_pack_start (GTK_BOX (pBox), pLabel, FALSE, FALSE, 0);
 						pInteractiveWidget = pBox;
@@ -438,21 +458,17 @@ static gboolean _applet_popup_dialog (dbusApplet *pDbusApplet, GHashTable *hDial
 					if (v && G_VALUE_HOLDS_STRING (v))
 						cMaxLabel = g_value_get_string (v);
 
-					#if (GTK_MAJOR_VERSION < 3)
-					pScale = gtk_hscale_new_with_range (fMinValue, fMaxValue, (fMaxValue - fMinValue) / 100.);
-					#else
 					pScale = gtk_scale_new_with_range (GTK_ORIENTATION_HORIZONTAL, fMinValue, fMaxValue, (fMaxValue - fMinValue) / 100.);
-					#endif
 					pOneWidget = pScale;
 					gtk_scale_set_digits (GTK_SCALE (pScale), iNbDigit);
 					gtk_range_set_value (GTK_RANGE (pScale), fInitialValue);
 					
 					g_object_set (pScale, "width-request", 150, NULL);
-					cairo_dock_set_dialog_widget_text_color (pScale);
+					gldi_dialog_set_widget_text_color (pScale);
 					
 					if (cMinLabel || cMaxLabel)
 					{
-						GtkWidget *pExtendedWidget = _gtk_hbox_new (0);
+						GtkWidget *pExtendedWidget = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 						GtkWidget *label = gtk_label_new (cMinLabel);
 						GtkWidget *pAlign = gtk_alignment_new (1., 1., 0., 0.);
 						gtk_container_add (GTK_CONTAINER (pAlign), label);
@@ -477,7 +493,7 @@ static gboolean _applet_popup_dialog (dbusApplet *pDbusApplet, GHashTable *hDial
 					gchar **cValuesList = NULL;
 					const gchar *cInitialText = NULL;
 					int iInitialValue = 0;
-					
+
 					v = g_hash_table_lookup (hWidgetAttributes, "editable");
 					if (v && G_VALUE_HOLDS_BOOLEAN (v))
 						bEditable = g_value_get_boolean (v);
@@ -485,33 +501,22 @@ static gboolean _applet_popup_dialog (dbusApplet *pDbusApplet, GHashTable *hDial
 					v = g_hash_table_lookup (hWidgetAttributes, "values");
 					if (v && G_VALUE_HOLDS_STRING (v))
 						cValues = g_value_get_string (v);
-					
+
 					if (cValues != NULL)
 						cValuesList = g_strsplit (cValues, ";", -1);
-					
-					#if (GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 24)
-					if (bEditable)
-						pOneWidget = gtk_combo_box_entry_new_text ();
-					else
-						pOneWidget = gtk_combo_box_new_text ();
-					#else
+
 					if (bEditable)
 						pOneWidget = gtk_combo_box_text_new_with_entry ();
 					else
 						pOneWidget = gtk_combo_box_text_new ();
-					#endif
 					pInteractiveWidget = pOneWidget;
-					
+
 					if (cValuesList != NULL)
 					{
 						int i;
 						for (i = 0; cValuesList[i] != NULL; i ++)
 						{
-							#if (GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 24)
-							gtk_combo_box_append_text (GTK_COMBO_BOX (pInteractiveWidget), cValuesList[i]);
-							#else
 							gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (pInteractiveWidget), cValuesList[i]);
-							#endif
 						}
 					}
 					
@@ -556,7 +561,10 @@ static gboolean _applet_popup_dialog (dbusApplet *pDbusApplet, GHashTable *hDial
 	else
 		g_object_set_data (G_OBJECT (pInteractiveWidget), "cd-widget", pOneWidget);
 	
-	pDbusApplet->pDialog = cairo_dock_build_dialog (&attr, pIcon, pContainer);
+	attr.pIcon = pIcon;
+	attr.pContainer = pContainer;
+	
+	pDbusApplet->pDialog = gldi_dialog_new (&attr);
 	if (pOneWidget)
 		gtk_widget_grab_focus (pOneWidget);
 	
@@ -627,13 +635,13 @@ gboolean cd_dbus_sub_applet_popup_dialog (dbusSubApplet *pDbusSubApplet, GHashTa
 gboolean cd_dbus_sub_applet_add_sub_icons (dbusSubApplet *pDbusSubApplet, const gchar **pIconFields, GError **error)
 {
 	//g_print ("%s ()\n", __func__);
-	CairoDockModuleInstance *pInstance = _get_module_instance_from_dbus_applet (pDbusSubApplet->pApplet);
+	GldiModuleInstance *pInstance = _get_module_instance_from_dbus_applet (pDbusSubApplet->pApplet);
 	g_return_val_if_fail (pInstance != NULL, FALSE);
 	
 	Icon *pIcon = pInstance->pIcon;
 	g_return_val_if_fail (pIcon != NULL, FALSE);
 	
-	CairoContainer *pContainer = pInstance->pContainer;
+	GldiContainer *pContainer = pInstance->pContainer;
 	g_return_val_if_fail (pContainer != NULL, FALSE);
 	
 	GList *pCurrentIconsList = (pInstance->pDock ? (pIcon->pSubDock ? pIcon->pSubDock->icons : NULL) : pInstance->pDesklet->icons);
@@ -665,13 +673,13 @@ gboolean cd_dbus_sub_applet_add_sub_icons (dbusSubApplet *pDbusSubApplet, const
 
 gboolean cd_dbus_sub_applet_remove_sub_icon (dbusSubApplet *pDbusSubApplet, const gchar *cIconID, GError **error)
 {
-	CairoDockModuleInstance *pInstance = _get_module_instance_from_dbus_applet (pDbusSubApplet->pApplet);
+	GldiModuleInstance *pInstance = _get_module_instance_from_dbus_applet (pDbusSubApplet->pApplet);
 	g_return_val_if_fail (pInstance != NULL, FALSE);
 	
 	Icon *pIcon = pInstance->pIcon;
 	g_return_val_if_fail (pIcon != NULL, FALSE);
 	
-	CairoContainer *pContainer = pInstance->pContainer;
+	GldiContainer *pContainer = pInstance->pContainer;
 	g_return_val_if_fail (pContainer != NULL, FALSE);
 	
 	if (cIconID == NULL || strcmp (cIconID, "any") == 0)  // remove all
@@ -682,7 +690,8 @@ gboolean cd_dbus_sub_applet_remove_sub_icon (dbusSubApplet *pDbusSubApplet, cons
 	{
 		GList *pIconsList = (pInstance->pDock ? (pIcon->pSubDock ? pIcon->pSubDock->icons : NULL) : pInstance->pDesklet->icons);
 		Icon *pOneIcon = cairo_dock_get_icon_with_command (pIconsList, cIconID);
-		cairo_dock_remove_icon_from_applet (pInstance, pOneIcon);
+		///cairo_dock_remove_icon_from_applet (pInstance, pOneIcon);
+		gldi_object_unref (GLDI_OBJECT(pOneIcon));
 	}
 	
 	return TRUE;
@@ -721,7 +730,7 @@ gboolean cd_dbus_applet_animate (dbusApplet *pDbusApplet, const gchar *cAnimatio
 gboolean cd_dbus_applet_demands_attention (dbusApplet *pDbusApplet, gboolean bStart, const gchar *cAnimation, GError **error)
 {
 	Icon *pIcon;
-	CairoContainer *pContainer;
+	GldiContainer *pContainer;
 	if (! _get_icon_and_container_from_id (pDbusApplet, NULL, &pIcon, &pContainer))
 		return FALSE;
 	
@@ -729,12 +738,12 @@ gboolean cd_dbus_applet_demands_attention (dbusApplet *pDbusApplet, gboolean bSt
 	{
 		if (CAIRO_DOCK_IS_DOCK (pContainer))
 		{
-			cairo_dock_request_icon_attention (pIcon, CAIRO_DOCK (pContainer), cAnimation, 0);  // 0 <=> sans arret.
+			gldi_icon_request_attention (pIcon, cAnimation, 0);  // 0 <=> sans arret.
 		}
 	}
 	else if (pIcon->bIsDemandingAttention)
 	{
-		cairo_dock_stop_icon_attention (pIcon, CAIRO_DOCK (pContainer));
+		gldi_icon_stop_attention (pIcon);
 	}
 	return TRUE;
 }
@@ -773,19 +782,20 @@ gboolean cd_dbus_applet_popup_dialog (dbusApplet *pDbusApplet, GHashTable *hDial
 
 gboolean cd_dbus_applet_add_data_renderer (dbusApplet *pDbusApplet, const gchar *cType, gint iNbValues, const gchar *cTheme, GError **error)
 {
-	CairoDockModuleInstance *pInstance = _get_module_instance_from_dbus_applet (pDbusApplet);
+	GldiModuleInstance *pInstance = _get_module_instance_from_dbus_applet (pDbusApplet);
 	g_return_val_if_fail (pInstance != NULL, FALSE);
 	
 	Icon *pIcon = pInstance->pIcon;
 	g_return_val_if_fail (pIcon != NULL, FALSE);
 	
-	CairoContainer *pContainer = pInstance->pContainer;
+	GldiContainer *pContainer = pInstance->pContainer;
 	g_return_val_if_fail (pContainer != NULL, FALSE);
 	
 	CairoDataRendererAttribute *pRenderAttr = NULL;  // attributes for the global data-renderer.
 	CairoGaugeAttribute aGaugeAttr;  // gauge attributes.
 	CairoGraphAttribute aGraphAttr;  // graph attributes.
 	CairoGraphAttribute aProgressBarAttr;  // progressbar attributes.
+	double *fHighColor = NULL, *fLowColor = NULL;
 	if (strcmp (cType, "gauge") == 0)
 	{
 		memset (&aGaugeAttr, 0, sizeof (CairoGaugeAttribute));
@@ -811,8 +821,8 @@ gboolean cd_dbus_applet_add_data_renderer (dbusApplet *pDbusApplet, const gchar
 		else if (strcmp (cTheme, "Plain Circle") == 0)
 			aGraphAttr.iType = CAIRO_DOCK_GRAPH_CIRCLE_PLAIN;
 		aGraphAttr.bMixGraphs = FALSE;
-		double *fHighColor = g_new (double, iNbValues*3);
-		double *fLowColor = g_new (double, iNbValues*3);
+		fHighColor = g_new (double, iNbValues*3);
+		fLowColor  = g_new (double, iNbValues*3);
 		int i;
 		for (i = 0; i < iNbValues; i ++)
 		{
@@ -850,18 +860,21 @@ gboolean cd_dbus_applet_add_data_renderer (dbusApplet *pDbusApplet, const gchar
 	g_return_val_if_fail (pIcon->image.pSurface != NULL, FALSE);
 	cairo_dock_add_new_data_renderer_on_icon (pIcon, pContainer, pRenderAttr);
 
+	g_free (fHighColor);
+	g_free (fLowColor);
+
 	return TRUE;
 }
 
 gboolean cd_dbus_applet_render_values (dbusApplet *pDbusApplet, GArray *pValues, GError **error)
 {
-	CairoDockModuleInstance *pInstance = _get_module_instance_from_dbus_applet (pDbusApplet);
+	GldiModuleInstance *pInstance = _get_module_instance_from_dbus_applet (pDbusApplet);
 	g_return_val_if_fail (pInstance != NULL, FALSE);
 	
 	Icon *pIcon = pInstance->pIcon;
 	g_return_val_if_fail (pIcon != NULL, FALSE);
 	
-	CairoContainer *pContainer = pInstance->pContainer;
+	GldiContainer *pContainer = pInstance->pContainer;
 	g_return_val_if_fail (pContainer != NULL, FALSE);
 	
 	g_return_val_if_fail (pIcon->image.pSurface != NULL, FALSE);
@@ -869,13 +882,13 @@ gboolean cd_dbus_applet_render_values (dbusApplet *pDbusApplet, GArray *pValues,
 	cairo_dock_render_new_data_on_icon (pIcon, pContainer, pDrawContext, (double *)pValues->data);
 	cairo_destroy (pDrawContext);
 	
-	cairo_dock_redraw_icon (pIcon, pContainer);
+	cairo_dock_redraw_icon (pIcon);
 	return TRUE;
 }
 
 gboolean cd_dbus_applet_control_appli (dbusApplet *pDbusApplet, const gchar *cApplicationClass, GError **error)
 {
-	CairoDockModuleInstance *pInstance = _get_module_instance_from_dbus_applet (pDbusApplet);
+	GldiModuleInstance *pInstance = _get_module_instance_from_dbus_applet (pDbusApplet);
 	g_return_val_if_fail (pInstance != NULL, FALSE);
 	
 	Icon *pIcon = pInstance->pIcon;
@@ -892,9 +905,9 @@ gboolean cd_dbus_applet_control_appli (dbusApplet *pDbusApplet, const gchar *cAp
 		}
 		if (! cairo_dock_is_loading ())
 		{
-			CairoContainer *pContainer = pInstance->pContainer;
+			GldiContainer *pContainer = pInstance->pContainer;
 			if (pContainer != NULL)
-				cairo_dock_redraw_icon (pIcon, pContainer);
+				cairo_dock_redraw_icon (pIcon);
 		}
 	}
 	
@@ -904,53 +917,53 @@ gboolean cd_dbus_applet_control_appli (dbusApplet *pDbusApplet, const gchar *cAp
 
 gboolean cd_dbus_applet_show_appli (dbusApplet *pDbusApplet, gboolean bShow, GError **error)  // deprecated
 {
-	CairoDockModuleInstance *pInstance = _get_module_instance_from_dbus_applet (pDbusApplet);
+	GldiModuleInstance *pInstance = _get_module_instance_from_dbus_applet (pDbusApplet);
 	g_return_val_if_fail (pInstance != NULL, FALSE);
 	
 	Icon *pIcon = pInstance->pIcon;
-	g_return_val_if_fail (pIcon != NULL && pIcon->Xid != 0, FALSE);
+	g_return_val_if_fail (pIcon != NULL && pIcon->pAppli != NULL, FALSE);
 	
 	if (bShow)
-		cairo_dock_show_xwindow (pIcon->Xid);
+		gldi_window_show (pIcon->pAppli);
 	else
-		cairo_dock_minimize_xwindow (pIcon->Xid);
+		gldi_window_minimize (pIcon->pAppli);
 	
 	return TRUE;
 }
 
 gboolean cd_dbus_applet_act_on_appli (dbusApplet *pDbusApplet, const gchar *cAction, GError **error)
 {
-	CairoDockModuleInstance *pInstance = _get_module_instance_from_dbus_applet (pDbusApplet);
+	GldiModuleInstance *pInstance = _get_module_instance_from_dbus_applet (pDbusApplet);
 	g_return_val_if_fail (pInstance != NULL, FALSE);
 	
 	Icon *pIcon = pInstance->pIcon;
-	g_return_val_if_fail (pIcon != NULL && pIcon->Xid != 0, FALSE);
+	g_return_val_if_fail (pIcon != NULL && pIcon->pAppli != NULL, FALSE);
 	
 	g_return_val_if_fail (cAction != NULL, FALSE);
 	
 	if (strcmp (cAction, "minimize") == 0)
-		cairo_dock_minimize_xwindow (pIcon->Xid);
+		gldi_window_minimize (pIcon->pAppli);
 	else if (strcmp (cAction, "show") == 0)
-		cairo_dock_show_xwindow (pIcon->Xid);
+		gldi_window_show (pIcon->pAppli);
 	else if (strcmp (cAction, "toggle-visibility") == 0)
 	{
-		if (pIcon->bIsHidden)
-			cairo_dock_show_xwindow (pIcon->Xid);
+		if (pIcon->pAppli->bIsHidden)
+			gldi_window_show (pIcon->pAppli);
 		else
-			cairo_dock_minimize_xwindow (pIcon->Xid);
+			gldi_window_minimize (pIcon->pAppli);
 	}	
 	else if (strcmp (cAction, "maximize") == 0)
-		cairo_dock_maximize_xwindow (pIcon->Xid, TRUE);
+		 gldi_window_maximize(pIcon->pAppli, TRUE);
 	else if (strcmp (cAction, "restore") == 0)
-		cairo_dock_maximize_xwindow (pIcon->Xid, FALSE);
+		gldi_window_maximize (pIcon->pAppli, FALSE);
 	else if (strcmp (cAction, "toggle-size") == 0)
 	{
-		cairo_dock_maximize_xwindow (pIcon->Xid, ! pIcon->bIsMaximized);
+		gldi_window_maximize (pIcon->pAppli, ! pIcon->pAppli->bIsMaximized);
 	}
 	else if (strcmp (cAction, "close") == 0)
-		cairo_dock_close_xwindow (pIcon->Xid);
+		gldi_window_close (pIcon->pAppli);
 	else if (strcmp (cAction, "kill") == 0)
-		cairo_dock_kill_xwindow (pIcon->Xid);
+		gldi_window_kill (pIcon->pAppli);
 	else
 	{
 		cd_warning ("invalid action '%s' on window %s", cAction, pIcon->cName);
@@ -999,6 +1012,8 @@ gboolean cd_dbus_applet_add_menu_items (dbusApplet *pDbusApplet, GPtrArray *pIte
 	GtkRequisition natural_size;
 	gtk_widget_get_preferred_size (myData.pModuleMainMenu, NULL, &natural_size);
 	int iItemHeight = 0, iMenuHeight = natural_size.height;
+	int iIconSize;
+	gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &iIconSize, NULL);
 	
 	// get the position of our items in the menu.
 	int iPosition = myData.iMenuPosition;
@@ -1048,6 +1063,13 @@ gboolean cd_dbus_applet_add_menu_items (dbusApplet *pDbusApplet, GPtrArray *pIte
 			id = g_value_get_int (v);
 		data = GINT_TO_POINTER (id);
 		
+		if (iType == 0 || iType == 1)
+		{
+			v = g_hash_table_lookup (pItem, "icon");
+			if (v && G_VALUE_HOLDS_STRING (v))
+				cIcon = g_value_get_string (v);
+		}
+		
 		v = g_hash_table_lookup (pItem, "state");
 		if (v && G_VALUE_HOLDS_BOOLEAN (v))
 			bState = g_value_get_boolean (v);
@@ -1065,16 +1087,16 @@ gboolean cd_dbus_applet_add_menu_items (dbusApplet *pDbusApplet, GPtrArray *pIte
 		switch (iType)
 		{
 			case 0 :  // normal entry
-				pMenuItem = gtk_image_menu_item_new_with_label (cLabel);
-				g_signal_connect (G_OBJECT (pMenuItem), "activate", G_CALLBACK (cd_dbus_emit_on_menu_select), data);
+				pMenuItem = gldi_menu_item_new_with_action (cLabel, cIcon, G_CALLBACK (cd_dbus_emit_on_menu_select), data);
 			break;
 			case 1:  // sub-menu
-				pMenuItem = gtk_image_menu_item_new_with_label (cLabel);
-				GtkWidget *pSubMenu = gtk_menu_new ();
-				gtk_menu_item_set_submenu (GTK_MENU_ITEM (pMenuItem), pSubMenu);
+			{
+				GtkWidget *pSubMenu;
+				pMenuItem = gldi_menu_item_new_with_submenu (cLabel, cIcon, &pSubMenu);
 				int *pID = g_new (int, 1);
 				*pID = id;
 				g_hash_table_insert (pSubMenus, pID, pSubMenu);
+			}
 			break;
 			case 2:  // separator
 				pMenuItem = gtk_separator_menu_item_new ();
@@ -1106,37 +1128,6 @@ gboolean cd_dbus_applet_add_menu_items (dbusApplet *pDbusApplet, GPtrArray *pIte
 		if (v && G_VALUE_HOLDS_BOOLEAN (v))
 			gtk_widget_set_sensitive (pMenuItem, g_value_get_boolean (v));
 		
-		// set an icon
-		if (iType == 0 || iType == 1)
-		{
-			v = g_hash_table_lookup (pItem, "icon");
-			if (v && G_VALUE_HOLDS_STRING (v))
-			{
-				cIcon = g_value_get_string (v);
-				if (cIcon)
-				{
-					GtkWidget *image = NULL;
-					if (*cIcon == '/')
-					{
-						GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file_at_size (cIcon, 16, 16, NULL);
-						if (pixbuf)
-						{
-							image = gtk_image_new_from_pixbuf (pixbuf);
-							g_object_unref (pixbuf);
-						}
-					}
-					else
-					{
-						image = gtk_image_new_from_stock (cIcon, GTK_ICON_SIZE_MENU);
-					}
-#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 16)
-					gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (pMenuItem), TRUE);
-#endif
-					gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (pMenuItem), image);
-				}
-			}
-		}
-		
 		// set the tooltip
 		v = g_hash_table_lookup (pItem, "tooltip");
 		if (v && G_VALUE_HOLDS_STRING (v))
@@ -1161,6 +1152,7 @@ gboolean cd_dbus_applet_add_menu_items (dbusApplet *pDbusApplet, GPtrArray *pIte
 		gtk_menu_shell_insert (GTK_MENU_SHELL (pMenu), pMenuItem, iPosition++);
 		if (pMenu == myData.pModuleMainMenu)
 		{
+			gtk_widget_show_all (pMenuItem);  // make it visible now so that its height is correctly calculated by GTK (else its child is ignored)
 			gtk_widget_get_preferred_size (pMenuItem, NULL, &natural_size);
 			iItemHeight += natural_size.height;
 		}
@@ -1182,11 +1174,11 @@ gboolean cd_dbus_applet_bind_shortkey (dbusApplet *pDbusApplet, const gchar **cS
 	cd_debug ("%s ()", __func__);
 	g_return_val_if_fail (cShortkeys != NULL, FALSE);
 	
-	CairoDockModuleInstance *pInstance = _get_module_instance_from_dbus_applet (pDbusApplet);
+	GldiModuleInstance *pInstance = _get_module_instance_from_dbus_applet (pDbusApplet);
 	g_return_val_if_fail (pInstance != NULL, FALSE);
 	
-	const gchar *cShortkey, *cDescription = "Pouet", *cGroupName = "Configuration", *cKeyName = "shortkey";
-	CairoKeyBinding *pKeyBinding;
+	const gchar *cShortkey, *cDescription = "-", *cGroupName = "Configuration", *cKeyName = "shortkey";
+	GldiShortkey *pKeyBinding;
 	int i;
 	GList *kb;
 	
@@ -1195,7 +1187,7 @@ gboolean cd_dbus_applet_bind_shortkey (dbusApplet *pDbusApplet, const gchar **cS
 		for (i = 0; cShortkeys[i] != NULL; i ++)
 		{
 			cShortkey = cShortkeys[i];
-			pKeyBinding = cd_keybinder_bind (cShortkey,
+			pKeyBinding = gldi_shortkey_new (cShortkey,
 				pInstance->pModule->pVisitCard->cTitle,
 				cDescription,
 				pInstance->pModule->pVisitCard->cIconFilePath,
@@ -1211,52 +1203,9 @@ gboolean cd_dbus_applet_bind_shortkey (dbusApplet *pDbusApplet, const gchar **cS
 		{
 			cShortkey = cShortkeys[i];
 			pKeyBinding = kb->data;
-			cd_keybinder_rebind (pKeyBinding, cShortkey, NULL);
+			gldi_shortkey_rebind (pKeyBinding, cShortkey, NULL);
 		}
 	}
-	/** // on enleve les vieux raccourcis dont l'applet ne veut plus.
-	sk = pDbusApplet->pShortkeyList;
-	while (sk != NULL)
-	{
-		next_sk = sk->next;
-		key = sk->data;
-		
-		// on cherche ce raccourci parmi la nouvelle liste.
-		for (i = 0; cShortkeys[i] != NULL; i ++)
-		{
-			cShortkey = cShortkeys[i];
-			if (strcmp (cShortkey, key) == 0)
-				break;
-		}
-		if (! cShortkeys[i])  // raccourci non trouve dans la nouvelle liste => on l'enleve
-		{
-			//g_print (" shortkey '%s' not wanted anymore\n", key);
-			cd_keybinder_unbind (key, (CDBindkeyHandler) cd_dbus_applet_emit_on_shortkey);
-			pDbusApplet->pShortkeyList = g_list_delete_link (pDbusApplet->pShortkeyList, sk);
-		}
-		sk = next_sk;
-	}
-	
-	// on lie les nouveaux raccourcis non encore lies.
-	gboolean bCouldBind;
-	for (i = 0; cShortkeys[i] != NULL; i ++)
-	{
-		cShortkey = cShortkeys[i];
-		for (sk = pDbusApplet->pShortkeyList; sk != NULL; sk = sk->next)  // on regarde si ce nouveau raccourci est deja lie.
-		{
-			key = sk->data;
-			if (strcmp (cShortkey, key) == 0)  // ce raccourci a deja ete lie avec succes precedemment.
-				break;
-		}
-		if (! sk)  // raccourci non encore lie => on lie.
-		{
-			//g_print (" shortkey '%s' wanted\n", cShortkey);
-			bCouldBind = cd_keybinder_bind (cShortkey, (CDBindkeyHandler) cd_dbus_applet_emit_on_shortkey, pDbusApplet);
-			if (bCouldBind)
-				pDbusApplet->pShortkeyList = g_list_prepend (pDbusApplet->pShortkeyList, g_strdup (cShortkey));
-			cd_debug ("*** bind %s: %d", cShortkey, bCouldBind);
-		}
-	}*/
 	return TRUE;
 }
 
@@ -1264,13 +1213,13 @@ gboolean cd_dbus_applet_bind_shortkey (dbusApplet *pDbusApplet, const gchar **cS
 gboolean cd_dbus_applet_get (dbusApplet *pDbusApplet, const gchar *cProperty, GValue *v, GError **error)
 {
 	cd_debug ("%s (%s)", __func__, cProperty);
-	CairoDockModuleInstance *pInstance = _get_module_instance_from_dbus_applet (pDbusApplet);
+	GldiModuleInstance *pInstance = _get_module_instance_from_dbus_applet (pDbusApplet);
 	g_return_val_if_fail (pInstance != NULL, FALSE);
 	
 	Icon *pIcon = pInstance->pIcon;
 	g_return_val_if_fail (pIcon != NULL, FALSE);
 	
-	CairoContainer *pContainer = pInstance->pContainer;
+	GldiContainer *pContainer = pInstance->pContainer;
 	g_return_val_if_fail (pContainer != NULL, FALSE);
 	
 	// x, y, orientation, type, width, height
@@ -1311,7 +1260,8 @@ gboolean cd_dbus_applet_get (dbusApplet *pDbusApplet, const gchar *cProperty, GV
 	else if (strcmp (cProperty, "container") == 0)
 	{
 		g_value_init (v, G_TYPE_UINT);
-		g_value_set_uint (v, pContainer->iType);
+		int iType = _get_container_type (pContainer);
+		g_value_set_uint (v, iType);
 	}
 	else if (strcmp (cProperty, "width") == 0)  // this is the dimension of the icon when it's hovered.
 	{
@@ -1329,13 +1279,12 @@ gboolean cd_dbus_applet_get (dbusApplet *pDbusApplet, const gchar *cProperty, GV
 	}
 	else if (strncmp (cProperty, "Xid", 3) == 0)
 	{
-		Window Xid = pIcon->Xid;
 		g_value_init (v, G_TYPE_UINT64);
-		g_value_set_uint64 (v, Xid);
+		g_value_set_uint64 (v, GPOINTER_TO_INT(pIcon->pAppli));
 	}
 	else if (strcmp (cProperty, "has_focus") == 0)
 	{
-		gboolean bHasFocus = (pIcon->Xid != 0 && pIcon->Xid == cairo_dock_get_current_active_window ());
+		gboolean bHasFocus = (pIcon->pAppli != NULL && pIcon->pAppli == gldi_windows_get_active ());
 		g_value_init (v, G_TYPE_BOOLEAN);
 		g_value_set_boolean (v, bHasFocus);
 	}
@@ -1350,13 +1299,13 @@ gboolean cd_dbus_applet_get (dbusApplet *pDbusApplet, const gchar *cProperty, GV
 gboolean cd_dbus_applet_get_all (dbusApplet *pDbusApplet, GHashTable **hProperties, GError **error)
 {
 	cd_debug ("%s ()", __func__);
-	CairoDockModuleInstance *pInstance = _get_module_instance_from_dbus_applet (pDbusApplet);
+	GldiModuleInstance *pInstance = _get_module_instance_from_dbus_applet (pDbusApplet);
 	g_return_val_if_fail (pInstance != NULL, FALSE);
 	
 	Icon *pIcon = pInstance->pIcon;
 	g_return_val_if_fail (pIcon != NULL, FALSE);
 	
-	CairoContainer *pContainer = pInstance->pContainer;
+	GldiContainer *pContainer = pInstance->pContainer;
 	g_return_val_if_fail (pContainer != NULL, FALSE);
 	
 	int x, y;
@@ -1374,8 +1323,7 @@ gboolean cd_dbus_applet_get_all (dbusApplet *pDbusApplet, GHashTable **hProperti
 	int iWidth, iHeight;
 	cairo_dock_get_icon_extent (pIcon, &iWidth, &iHeight);
 	
-	Window Xid = pIcon->Xid;
-	gboolean bHasFocus = (pIcon->Xid != 0 && pIcon->Xid == cairo_dock_get_current_active_window ());
+	gboolean bHasFocus = (pIcon->pAppli != NULL && pIcon->pAppli == gldi_windows_get_active ());
 	
 	GHashTable *h = g_hash_table_new_full (g_str_hash,
 		g_str_equal,
@@ -1401,7 +1349,8 @@ gboolean cd_dbus_applet_get_all (dbusApplet *pDbusApplet, GHashTable **hProperti
 	
 	v = g_new0 (GValue, 1);
 	g_value_init (v, G_TYPE_UINT);
-	g_value_set_uint (v, pContainer->iType);
+	int iType = _get_container_type (pContainer);
+	g_value_set_uint (v, iType);
 	g_hash_table_insert (h, g_strdup ("container"), v);
 	
 	v = g_new0 (GValue, 1);
@@ -1416,7 +1365,7 @@ gboolean cd_dbus_applet_get_all (dbusApplet *pDbusApplet, GHashTable **hProperti
 	
 	v = g_new0 (GValue, 1);
 	g_value_init (v, G_TYPE_UINT64);
-	g_value_set_uint64(v, Xid);
+	g_value_set_uint64(v, GPOINTER_TO_INT(pIcon->pAppli));
 	g_hash_table_insert (h, g_strdup ("Xid"), v);
 	
 	v = g_new0 (GValue, 1);
