@@ -58,11 +58,13 @@ CD_APPLET_DEFINITION (N_("Disks"),
 	"SQP");
 
 
-static void _set_data_renderer (CairoDockModuleInstance *myApplet)
+static void _set_data_renderer (GldiModuleInstance *myApplet)
 {
 	CairoDataRendererAttribute *pRenderAttr = NULL;  // attributes for the global data-renderer.
 	CairoGaugeAttribute aGaugeAttr;  // gauge attributes.
 	CairoGraphAttribute aGraphAttr;  // graph attributes.
+	double fHighColor[CD_DISKS_NB_MAX_VALUES*3]; // attributes for the graph
+	double fLowColor[CD_DISKS_NB_MAX_VALUES*3];  // (but have to be declared here to force GCC to keep data)
 	if (myConfig.iDisplayType == CD_DISKS_GAUGE)
 	{
 		memset (&aGaugeAttr, 0, sizeof (CairoGaugeAttribute));
@@ -79,8 +81,6 @@ static void _set_data_renderer (CairoDockModuleInstance *myApplet)
 		pRenderAttr->iMemorySize = (myIcon->fWidth > 1 ? myIcon->fWidth : 32);  // fWidth peut etre <= 1 en mode desklet au chargement.
 		aGraphAttr.iType = myConfig.iGraphType;
 		aGraphAttr.bMixGraphs = myConfig.bMixGraph;
-		double fHighColor[CD_DISKS_NB_MAX_VALUES*3];
-		double fLowColor[CD_DISKS_NB_MAX_VALUES*3];
 		gsize i;
 		for (i = 0; i < myData.iNumberDisks * 2; i+=2)
 		{
@@ -155,12 +155,12 @@ CD_APPLET_INIT_BEGIN
 	
 	// Initialisation de la tache periodique de mesure.
 	myData.pClock = g_timer_new ();
-	myData.pPeriodicTask = cairo_dock_new_task (myConfig.iCheckInterval,
-		(CairoDockGetDataAsyncFunc) cd_disks_get_data,
-		(CairoDockUpdateSyncFunc) cd_disks_update_from_data,
+	myData.pPeriodicTask = gldi_task_new (myConfig.iCheckInterval,
+		(GldiGetDataAsyncFunc) cd_disks_get_data,
+		(GldiUpdateSyncFunc) cd_disks_update_from_data,
 		myApplet);
 	//~ myData.bAcquisitionOK = TRUE;
-	cairo_dock_launch_task (myData.pPeriodicTask);
+	gldi_task_launch (myData.pPeriodicTask);
 	
 	CD_APPLET_REGISTER_FOR_CLICK_EVENT;
 	CD_APPLET_REGISTER_FOR_BUILD_MENU_EVENT;
@@ -202,14 +202,14 @@ CD_APPLET_RELOAD_BEGIN
 				CD_APPLET_SET_NAME_FOR_MY_ICON (myApplet->pModule->pVisitCard->cTitle);
 		}
 		
-		cairo_dock_relaunch_task_immediately (myData.pPeriodicTask, myConfig.iCheckInterval);
+		gldi_task_change_frequency_and_relaunch (myData.pPeriodicTask, myConfig.iCheckInterval);
 	}
 	else {  // on redessine juste l'icone.
 		//CD_APPLET_RELOAD_MY_DATA_RENDERER (NULL);
 		if (myConfig.iDisplayType == CD_DISKS_GRAPH)
 			CD_APPLET_SET_MY_DATA_RENDERER_HISTORY_TO_MAX;
 		
-		/**if (! cairo_dock_task_is_running (myData.pPeriodicTask))
+		/**if (! gldi_task_is_running (myData.pPeriodicTask))
 			cd_disks_update_from_data (myApplet);*/
 	}
 CD_APPLET_RELOAD_END
