@@ -37,16 +37,16 @@ CD_APPLET_ON_CLICK_BEGIN
 		}
 		else if (CD_APPLET_MY_ICONS_LIST == NULL)  // repertoire vide, ou illisible, ou non defini
 		{
-			cairo_dock_remove_dialog_if_any (myIcon);
+			gldi_dialogs_remove_on_icon (myIcon);
 			if (myConfig.cDirPath == NULL)
-				cairo_dock_show_temporary_dialog_with_icon (D_("Open the configuration of the applet to choose a folder to import."),
+				gldi_dialog_show_temporary_with_icon (D_("Open the configuration of the applet to choose a folder to import."),
 					myIcon, myContainer,
 					8000.,
 					myConfig.iSubdockViewType == 0 ? "same icon" : MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE);
 			else
 			{
 				gchar *cPath = g_filename_from_uri (myConfig.cDirPath, NULL, NULL);
-				cairo_dock_show_temporary_dialog_with_icon_printf ("%s :\n%s",
+				gldi_dialog_show_temporary_with_icon_printf ("%s :\n%s",
 					myIcon, myContainer,
 					4000.,
 					myConfig.iSubdockViewType == 0 ? "same icon" : MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE,
@@ -56,7 +56,7 @@ CD_APPLET_ON_CLICK_BEGIN
 			}
 		}
 		else
-			CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);  // on laisse passer la notification (pour ouvrir le sous-dock au clic).
+			CD_APPLET_LEAVE (GLDI_NOTIFICATION_LET_PASS);  // on laisse passer la notification (pour ouvrir le sous-dock au clic).
 	}
 	else if (CD_APPLET_CLICKED_ICON != NULL)
 	{
@@ -128,7 +128,7 @@ static void _cd_folders_show_file_properties (GtkMenuItem *pMenuItem, gpointer *
 		gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG(pDialog))), pFrame);
 		gtk_frame_set_shadow_type (GTK_FRAME (pFrame), GTK_SHADOW_OUT);
 
-		GtkWidget *pVBox = _gtk_vbox_new (MARGIN);
+		GtkWidget *pVBox = gtk_box_new (GTK_ORIENTATION_VERTICAL, MARGIN);
 		gtk_container_add (GTK_CONTAINER (pFrame), pVBox);
 
 		pLabel = gtk_label_new (NULL);
@@ -161,11 +161,7 @@ static void _cd_folders_show_file_properties (GtkMenuItem *pMenuItem, gpointer *
 			gtk_container_add (GTK_CONTAINER (pVBox), pLabel);
 		}
 
-		#if (GTK_MAJOR_VERSION < 3)
-		GtkWidget *pSeparator = gtk_hseparator_new ();
-		#else
 		GtkWidget *pSeparator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
-		#endif
 		gtk_container_add (GTK_CONTAINER (pVBox), pSeparator);
 
 		pLabel = gtk_label_new (NULL);
@@ -209,7 +205,7 @@ static void _on_answer_delete_file (int iClickedButton, GtkWidget *pInteractiveW
 		{
 			cd_warning ("couldn't delete this file.\nCheck that you have writing rights on this file.\n");
 			gchar *cMessage = g_strdup_printf (D_("Warning: could not delete this file.\nPlease check file permissions."));
-			cairo_dock_show_temporary_dialog_with_default_icon (cMessage, icon, icon->pContainer, 4000);
+			gldi_dialog_show_temporary_with_default_icon (cMessage, icon, icon->pContainer, 4000);
 			g_free (cMessage);
 		}
 	}
@@ -217,14 +213,14 @@ static void _on_answer_delete_file (int iClickedButton, GtkWidget *pInteractiveW
 static void _cd_folders_delete_file (GtkMenuItem *pMenuItem, gpointer *data)
 {
 	Icon *icon = data[0];
-	CairoContainer *pContainer = data[1];
+	GldiContainer *pContainer = data[1];
 	cd_message ("%s (%s)", __func__, icon->cName);
 	
 	gchar *cPath = g_filename_from_uri (icon->cBaseURI, NULL, NULL);
 	g_return_if_fail (cPath != NULL);
 	gchar *question = g_strdup_printf (D_("You're about deleting this file\n  (%s)\nfrom your hard-disk. Sure ?"), cPath);
 	g_free (cPath);
-	cairo_dock_show_dialog_with_question (question,
+	gldi_dialog_show_with_question (question,
 		icon, pContainer,
 		"same icon",
 		(CairoDockActionOnAnswerFunc) _on_answer_delete_file, icon, (GFreeFunc)NULL);  // if the icon is deleted during the question, the dialog will disappear with it, and we won't be called back.
@@ -241,7 +237,7 @@ static void _on_answer_rename_file (int iClickedButton, GtkWidget *pInteractiveW
 			if (! bSuccess)
 			{
 				cd_warning ("couldn't rename this file.\nCheck that you have writing rights, and that the new name does not already exist.");
-				cairo_dock_show_temporary_dialog_with_icon_printf (D_("Warning: could not rename %s.\nCheck file permissions \nand that the new name does not already exist."), icon, icon->pContainer, 5000, NULL, icon->cBaseURI);
+				gldi_dialog_show_temporary_with_icon_printf (D_("Warning: could not rename %s.\nCheck file permissions \nand that the new name does not already exist."), icon, icon->pContainer, 5000, NULL, icon->cBaseURI);
 			}
 		}
 	}
@@ -250,7 +246,7 @@ static void _cd_folders_rename_file (GtkMenuItem *pMenuItem, gpointer *data)
 {
 	Icon *icon = data[0];
 	cd_message ("%s (%s)", __func__, icon->cName);
-	cairo_dock_show_dialog_with_entry (D_("Rename to:"),
+	gldi_dialog_show_with_entry (D_("Rename to:"),
 		icon, icon->pContainer,
 		"same icon",
 		icon->cName,
@@ -260,17 +256,17 @@ static void _cd_folders_rename_file (GtkMenuItem *pMenuItem, gpointer *data)
 static void _cd_folders_move_file (GtkMenuItem *pMenuItem, gpointer *data)
 {
 	Icon *icon = data[0];
-	CairoContainer *pContainer = data[1];
-	CairoDockModuleInstance *myApplet = data[2];
+	GldiContainer *pContainer = data[1];
+	GldiModuleInstance *myApplet = data[2];
 	cd_message ("%s (%s)", __func__, icon->cName);
 	
 	GtkWidget* pFileChooserDialog = gtk_file_chooser_dialog_new (
 		_("Pick up a directory"),
 		GTK_WINDOW (pContainer->pWidget),
 		GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
-		GTK_STOCK_OK,
+		_("Ok"),
 		GTK_RESPONSE_OK,
-		GTK_STOCK_CANCEL,
+		_("Cancel"),
 		GTK_RESPONSE_CANCEL,
 		NULL);
 	
@@ -293,7 +289,7 @@ static void _on_answer_create_file (int iClickedButton, GtkWidget *pInteractiveW
 	if (iClickedButton == 0 || iClickedButton == -1)  // ok button or Enter.
 	{
 		gboolean bFolder = GPOINTER_TO_INT (data[0]);
-		CairoDockModuleInstance *myApplet = data[1];
+		GldiModuleInstance *myApplet = data[1];
 		const gchar *cNewName = gtk_entry_get_text (GTK_ENTRY (pInteractiveWidget));
 		if (cNewName != NULL && *cNewName != '\0')
 		{
@@ -302,32 +298,32 @@ static void _on_answer_create_file (int iClickedButton, GtkWidget *pInteractiveW
 			if (! bSuccess)
 			{
 				cd_warning ("couldn't create this file.\nCheck that you have writing rights, and that the new name does not already exist.");
-				cairo_dock_show_temporary_dialog_with_icon_printf (D_("Warning: could not create %s.\nCheck file permissions \nand that the new name does not already exist."), myIcon, myContainer, 5000, NULL, cNewName);
+				gldi_dialog_show_temporary_with_icon_printf (D_("Warning: could not create %s.\nCheck file permissions \nand that the new name does not already exist."), myIcon, myContainer, 5000, NULL, cNewName);
 			}
 		}
 	}
 }
-static inline void _create_new_file (CairoDockModuleInstance *myApplet, gboolean bFolder)
+static inline void _create_new_file (GldiModuleInstance *myApplet, gboolean bFolder)
 {
 	gpointer *data = g_new (gpointer, 2);
 	data[0] = GINT_TO_POINTER (bFolder);
 	data[1] = myApplet;
-	cairo_dock_show_dialog_with_entry (D_("Enter a file name:"),
+	gldi_dialog_show_with_entry (D_("Enter a file name:"),
 		myIcon, myContainer,
 		"same icon",
 		NULL,
 		(CairoDockActionOnAnswerFunc)_on_answer_create_file, data, (GFreeFunc)g_free);
 }
-static void _cd_folders_new_file (GtkMenuItem *pMenuItem, CairoDockModuleInstance *myApplet)
+static void _cd_folders_new_file (GtkMenuItem *pMenuItem, GldiModuleInstance *myApplet)
 {
 	_create_new_file (myApplet, FALSE);
 }
-static void _cd_folders_new_folder (GtkMenuItem *pMenuItem, CairoDockModuleInstance *myApplet)
+static void _cd_folders_new_folder (GtkMenuItem *pMenuItem, GldiModuleInstance *myApplet)
 {
 	_create_new_file (myApplet, TRUE);
 }
 
-static void _cd_folders_open_folder (GtkMenuItem *pMenuItem, CairoDockModuleInstance *myApplet)
+static void _cd_folders_open_folder (GtkMenuItem *pMenuItem, GldiModuleInstance *myApplet)
 {
 	cairo_dock_fm_launch_uri (myConfig.cDirPath);
 }
@@ -343,22 +339,22 @@ static void _cd_folders_launch_with (GtkMenuItem *pMenuItem, gpointer *app)
 	g_free (cUri);
 }
 
-static void _cd_folders_sort_by_name (GtkMenuItem *pMenuItem, CairoDockModuleInstance *myApplet)
+static void _cd_folders_sort_by_name (GtkMenuItem *pMenuItem, GldiModuleInstance *myApplet)
 {
 	cd_folders_sort_icons (myApplet, CAIRO_DOCK_FM_SORT_BY_NAME);
 }
 
-static void _cd_folders_sort_by_date (GtkMenuItem *pMenuItem, CairoDockModuleInstance *myApplet)
+static void _cd_folders_sort_by_date (GtkMenuItem *pMenuItem, GldiModuleInstance *myApplet)
 {
 	cd_folders_sort_icons (myApplet, CAIRO_DOCK_FM_SORT_BY_DATE);
 }
 
-static void _cd_folders_sort_by_size (GtkMenuItem *pMenuItem, CairoDockModuleInstance *myApplet)
+static void _cd_folders_sort_by_size (GtkMenuItem *pMenuItem, GldiModuleInstance *myApplet)
 {
 	cd_folders_sort_icons (myApplet, CAIRO_DOCK_FM_SORT_BY_SIZE);
 }
 
-static void _cd_folders_sort_by_type (GtkMenuItem *pMenuItem, CairoDockModuleInstance *myApplet)
+static void _cd_folders_sort_by_type (GtkMenuItem *pMenuItem, GldiModuleInstance *myApplet)
 {
 	cd_folders_sort_icons (myApplet, CAIRO_DOCK_FM_SORT_BY_TYPE);
 }
@@ -368,7 +364,7 @@ static void _free_app (gpointer *app)
 	g_free (app[3]);
 	g_free (app);
 }
-void cd_folders_free_apps_list (CairoDockModuleInstance *myApplet)
+void cd_folders_free_apps_list (GldiModuleInstance *myApplet)
 {
 	if (myData.pAppList != NULL)
 	{
@@ -392,21 +388,21 @@ CD_APPLET_ON_BUILD_MENU_BEGIN
 		if (myConfig.bShowFiles)
 		{
 			gchar *cLabel = g_strdup_printf ("%s (%s)", D_("Open the folder"), D_("middle-click"));
-			CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (cLabel, GTK_STOCK_OPEN, _cd_folders_open_folder, CD_APPLET_MY_MENU, myApplet);
+			CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (cLabel, GLDI_ICON_NAME_OPEN, _cd_folders_open_folder, CD_APPLET_MY_MENU, myApplet);
 			g_free (cLabel);
 		}
 	}
 	else  // clic on a file.
 	{
-		CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Rename this file"), GTK_STOCK_SAVE_AS, _cd_folders_rename_file, CD_APPLET_MY_MENU, data);
-		CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Delete this file"), GTK_STOCK_REMOVE, _cd_folders_delete_file, CD_APPLET_MY_MENU, data);
-		CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Move this file"), GTK_STOCK_JUMP_TO, _cd_folders_move_file, CD_APPLET_MY_MENU, data);
+		CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Rename this file"), GLDI_ICON_NAME_SAVE_AS, _cd_folders_rename_file, CD_APPLET_MY_MENU, data);
+		CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Delete this file"), GLDI_ICON_NAME_REMOVE, _cd_folders_delete_file, CD_APPLET_MY_MENU, data);
+		CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Move this file"), GLDI_ICON_NAME_JUMP_TO, _cd_folders_move_file, CD_APPLET_MY_MENU, data);
 		
 		GList *pApps = cairo_dock_fm_list_apps_for_file (CD_APPLET_CLICKED_ICON->cBaseURI);
 		if (pApps != NULL)
 		{
 			CD_APPLET_ADD_SEPARATOR_IN_MENU (CD_APPLET_MY_MENU);
-			GtkWidget *pSubMenu = CD_APPLET_ADD_SUB_MENU_WITH_IMAGE (D_("Open with"), CD_APPLET_MY_MENU, GTK_STOCK_OPEN);
+			GtkWidget *pSubMenu = CD_APPLET_ADD_SUB_MENU_WITH_IMAGE (D_("Open with"), CD_APPLET_MY_MENU, GLDI_ICON_NAME_OPEN);
 			
 			cd_folders_free_apps_list (myApplet);
 			
@@ -439,16 +435,16 @@ CD_APPLET_ON_BUILD_MENU_BEGIN
 		}
 		
 		CD_APPLET_ADD_SEPARATOR_IN_MENU (CD_APPLET_MY_MENU);
-		CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Properties"), GTK_STOCK_PROPERTIES, _cd_folders_show_file_properties, CD_APPLET_MY_MENU, data);
+		CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Properties"), GLDI_ICON_NAME_PROPERTIES, _cd_folders_show_file_properties, CD_APPLET_MY_MENU, data);
 		
 		CD_APPLET_ADD_SEPARATOR_IN_MENU (CD_APPLET_MY_MENU);
-		CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Create a new file"), GTK_STOCK_NEW, _cd_folders_new_file, CD_APPLET_MY_MENU, myApplet);
-		CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Create a new folder"), GTK_STOCK_NEW, _cd_folders_new_folder, CD_APPLET_MY_MENU, myApplet);
+		CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Create a new file"), GLDI_ICON_NAME_NEW, _cd_folders_new_file, CD_APPLET_MY_MENU, myApplet);
+		CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Create a new folder"), GLDI_ICON_NAME_NEW, _cd_folders_new_folder, CD_APPLET_MY_MENU, myApplet);
 	}
 	
 	if (myConfig.bShowFiles)
 	{
-		GtkWidget *pSubMenu = CD_APPLET_ADD_SUB_MENU_WITH_IMAGE (D_("Sort by"), CD_APPLET_MY_MENU, GTK_STOCK_SORT_DESCENDING);
+		GtkWidget *pSubMenu = CD_APPLET_ADD_SUB_MENU_WITH_IMAGE (D_("Sort by"), CD_APPLET_MY_MENU, GLDI_ICON_NAME_SORT_DESCENDING);
 		pMenuItem = CD_APPLET_ADD_IN_MENU_WITH_DATA (D_("By name"), _cd_folders_sort_by_name, pSubMenu, myApplet);
 		pMenuItem = CD_APPLET_ADD_IN_MENU_WITH_DATA (D_("By date"), _cd_folders_sort_by_date, pSubMenu, myApplet);
 		pMenuItem = CD_APPLET_ADD_IN_MENU_WITH_DATA (D_("By size"), _cd_folders_sort_by_size, pSubMenu, myApplet);
@@ -456,7 +452,7 @@ CD_APPLET_ON_BUILD_MENU_BEGIN
 	}
 	
 	if (CD_APPLET_CLICKED_ICON != NULL && CD_APPLET_CLICKED_ICON != myIcon)
-		CD_APPLET_LEAVE (CAIRO_DOCK_INTERCEPT_NOTIFICATION);
+		CD_APPLET_LEAVE (GLDI_NOTIFICATION_INTERCEPT);
 CD_APPLET_ON_BUILD_MENU_END
 
 
@@ -474,10 +470,10 @@ static void _on_answer_import (int iClickedButton, GtkWidget *pInteractiveWidget
 	gboolean bImportFiles = (iClickedButton == 0 || iClickedButton == -1);  // ok or Enter.
 	
 	// add a new conf file for the "Folders" module, with proper values.
-	CairoDockModule *pModule = cairo_dock_find_module_from_name ("Folders");
+	GldiModule *pModule = gldi_module_get ("Folders");
 	g_return_if_fail (pModule != NULL);
 
-	gchar *cConfFilePath = cairo_dock_add_module_conf_file (pModule);  // we want to update the conf file before we instanciate the applet, so don't use high-level functions.
+	gchar *cConfFilePath = gldi_module_add_conf_file (pModule);  // we want to update the conf file before we instanciate the applet, so don't use high-level functions.
 	cairo_dock_update_conf_file (cConfFilePath,
 		G_TYPE_STRING, "Configuration", "dir path", cReceivedData,
 		G_TYPE_BOOLEAN, "Configuration", "show files", bImportFiles,
@@ -486,20 +482,14 @@ static void _on_answer_import (int iClickedButton, GtkWidget *pInteractiveWidget
 		G_TYPE_INVALID);
 	
 	// instanciate the module from this conf file.
-	CairoDockModuleInstance *pNewInstance = cairo_dock_instanciate_module (pModule, cConfFilePath);  // prend le 'cConfFilePath'.
+	GldiModuleInstance *pNewInstance = gldi_module_instance_new (pModule, cConfFilePath);  // prend le 'cConfFilePath'.
 	
 	// show a success message on the new icon.
 	if (pNewInstance != NULL)
-		cairo_dock_show_temporary_dialog_with_icon (D_("The folder has been imported."),
+		gldi_dialog_show_temporary_with_icon (D_("The folder has been imported."),
 			pNewInstance->pIcon, pNewInstance->pContainer,
 			5000,
 			MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE);  // not "same icon" because the icon may not be loaded yet (eg. stack or emblem icon).
-	
-	// if the module has just been activated for the first time, write it down so that it is loaded on the next startup.
-	if (pModule->pInstancesList && pModule->pInstancesList->next == NULL)  // module nouvellement active.
-	{
-		cairo_dock_write_active_modules ();
-	}
 }
 static void _free_dialog_data (CDDropData *data)
 {
@@ -507,11 +497,11 @@ static void _free_dialog_data (CDDropData *data)
 	g_free (data->cDockName);
 	g_free (data);
 }
-gboolean cd_folders_on_drop_data (gpointer data, const gchar *cReceivedData, Icon *icon, double fOrder, CairoContainer *pContainer)
+gboolean cd_folders_on_drop_data (gpointer data, const gchar *cReceivedData, Icon *icon, double fOrder, GldiContainer *pContainer)
 {
 	//g_print ("Folders received '%s'\n", cReceivedData);
 	if (icon != NULL || fOrder == CAIRO_DOCK_LAST_ORDER)  // drop on an icon or outside of icons.
-		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+		return GLDI_NOTIFICATION_LET_PASS;
 	
 	gchar *cPath = NULL;
 	if (strncmp (cReceivedData, "file://", 7) == 0)
@@ -540,9 +530,9 @@ gboolean cd_folders_on_drop_data (gpointer data, const gchar *cReceivedData, Ico
 		if (pIcon == NULL)
 		{
 			if (CAIRO_DOCK_IS_DOCK (pContainer))
-				pIcon = cairo_dock_get_dialogless_icon_full (CAIRO_DOCK (pContainer));
+				pIcon = gldi_icons_get_without_dialog (CAIRO_DOCK (pContainer)->icons);
 			else
-				pIcon = cairo_dock_get_dialogless_icon ();
+				pIcon = gldi_icons_get_any_without_dialog ();
 		}
 		
 		// ask the user whether (s)he wants to import the folder's content.
@@ -550,8 +540,8 @@ gboolean cd_folders_on_drop_data (gpointer data, const gchar *cReceivedData, Ico
 		data->cReceivedData = g_strdup (cReceivedData);
 		data->fOrder = fOrder;
 		if (CAIRO_DOCK_IS_DOCK (pContainer))
-			data->cDockName = g_strdup (cairo_dock_search_dock_name (CAIRO_DOCK (pContainer)));
-		cairo_dock_show_dialog_full (D_("Do you want to import the content of the folder too?"),
+			data->cDockName = g_strdup (gldi_dock_get_name (CAIRO_DOCK (pContainer)));
+		gldi_dialog_show (D_("Do you want to import the content of the folder too?"),
 			pIcon, pContainer,
 			0,
 			MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE,
@@ -560,7 +550,7 @@ gboolean cd_folders_on_drop_data (gpointer data, const gchar *cReceivedData, Ico
 			data,
 			(GFreeFunc)_free_dialog_data);
 		
-		return CAIRO_DOCK_INTERCEPT_NOTIFICATION;
+		return GLDI_NOTIFICATION_INTERCEPT;
 	}
-	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+	return GLDI_NOTIFICATION_LET_PASS;
 }
