@@ -25,12 +25,12 @@
 #define IM_FAILED 0
 #define IM_SUCCESS 1
 
-double *im_getSnapshot( int fft );
+double *im_getSnapshot (void);
 
-void im_setSourceIndex( uint32_t index );
+void im_setSourceIndex (uint32_t index);
 
-void im_start( void );
+void im_start (void);
 
-void im_stop( void );
+void im_stop (void);
 
 int im_context_state (void);
