@@ -91,7 +91,7 @@ CD_APPLET_STOP_BEGIN
 	// CD_APPLET_UNREGISTER_FOR_BUILD_MENU_EVENT;
 
 	if (myData.iSidAnimate != 0)
-		cd_impulse_stop_animations ();
+		cd_impulse_stop_animations (FALSE); // no need to modify the icon
 
 	_free_shared_memory ();
 CD_APPLET_STOP_END
@@ -109,7 +109,7 @@ CD_APPLET_RELOAD_BEGIN
 		gboolean bWasLaunched;
 		if (myData.iSidAnimate != 0)
 		{
-			cd_impulse_stop_animations();
+			cd_impulse_stop_animations (FALSE); // icon will be modified here above
 			bWasLaunched = TRUE;
 		}
 		else
@@ -126,11 +126,11 @@ CD_APPLET_RELOAD_BEGIN
 		// if the icon has to be destroyed
 		if (myConfig.bLaunchAtStartup && myConfig.bFree)
 		{
-			cairo_dock_detach_icon_from_dock (myIcon, myDock);
+			gldi_icon_detach (myIcon);
 		}
 		else
 		{
-			cairo_dock_insert_icon_in_dock (myIcon, myDock, CAIRO_DOCK_ANIMATE_ICON);
+			gldi_icon_insert_in_container (myIcon, myContainer, CAIRO_DOCK_ANIMATE_ICON);
 		}
 
 		if (bWasLaunched || (myConfig.bLaunchAtStartup && myConfig.bFree)) // maybe the time has changed... or if it's automatically launched
