@@ -61,6 +61,9 @@ CD_APPLET_INIT_BEGIN
 	myData.pIndicator->get_initial_values 	= cd_messaging_get_initial_values;
 	myData.pIndicator->add_menu_handler 	= cd_messaging_add_menu_handler;
 	#else
+	if (myDock)
+		gldi_icon_detach (myIcon); // the icon is inserted when the entry will be added
+
 	myData.pIndicator = cd_indicator3_load (myConfig.cIndicatorName,
 		cd_messaging_entry_added,
 		cd_messaging_entry_removed,
@@ -68,8 +71,30 @@ CD_APPLET_INIT_BEGIN
 		NULL, // menu show
 		myApplet);
 
+	// check other names (if the one in the config file is wrong or switch ng)
 	if (! myData.pIndicator)
-		CD_APPLET_SET_DEFAULT_IMAGE_ON_MY_ICON_IF_NONE;  // set the default icon if none is specified in conf.
+	{
+		const gchar *cIndicatorNames[] = {"com.canonical.indicator.messages",
+			"libmessaging.so", NULL};
+		int i = 0;
+		do
+		{
+			// no need to reload the same wrong indicator twice.
+			if (strcmp (cIndicatorNames[i], myConfig.cIndicatorName) != 0)
+			{
+				myData.pIndicator = cd_indicator3_load (cIndicatorNames[i],
+					cd_messaging_entry_added,
+					cd_messaging_entry_removed,
+					cd_messaging_accessible_desc_update,
+					NULL, // menu show
+					myApplet);
+			}
+			i++;
+		} while (myData.pIndicator == NULL && cIndicatorNames[i] != NULL);
+
+		if (! myData.pIndicator)
+			CD_APPLET_SET_DEFAULT_IMAGE_ON_MY_ICON_IF_NONE;  // set the default icon if none is specified in conf.
+	}
 	#endif
 	
 	// mouse events
@@ -91,7 +116,7 @@ CD_APPLET_STOP_BEGIN
 	// CD_APPLET_UNREGISTER_FOR_BUILD_MENU_EVENT;
 	
 	// keyboard events
-	cd_keybinder_unbind (myData.pKeyBinding);
+	gldi_object_unref (GLDI_OBJECT(myData.pKeyBinding));
 
 	#ifndef INDICATOR_MESSAGES_WITH_IND3
 	cd_indicator_destroy (myData.pIndicator);
@@ -112,9 +137,6 @@ CD_APPLET_STOP_END
 CD_APPLET_RELOAD_BEGIN
 	#ifndef INDICATOR_MESSAGES_WITH_IND3
 	cd_indicator_reload_icon (myData.pIndicator);  // we reload the icon (if we didn't have an icon, now we have a path). It will not consider a change of icon theme, so we return the original icon.
-	#else
-	// check if the name has changed and reload the icon
-	cd_messaging_reload (myData.pIndicator, myData.pEntry, myApplet);
 	#endif
 	
 	if (CD_APPLET_MY_CONFIG_CHANGED)
@@ -124,6 +146,10 @@ CD_APPLET_RELOAD_BEGIN
 			CD_APPLET_SET_DESKLET_RENDERER ("Simple");
 		}
 		
-		cd_keybinder_rebind (myData.pKeyBinding, myConfig.cShortkey, NULL);
+		#ifdef INDICATOR_MESSAGES_WITH_IND3
+		// check if the name has changed and reload the icon
+		cd_messaging_reload (myData.pIndicator, myData.pEntry, myApplet);
+		#endif
+		gldi_shortkey_rebind (myData.pKeyBinding, myConfig.cShortkey, NULL);
 	}
 CD_APPLET_RELOAD_END
