@@ -29,67 +29,63 @@
 #include "applet-session.h"
 #include "applet-notifications.h"
 
-#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 20)
-#include <gdk/gdkkeysyms-compat.h>
-#endif
-
 #define _alpha_prompt(k,n) .6*cos (G_PI/2*fabs ((double) ((k % (2*n)) - n) / n))
 
 const int s_iNbPromptAnimationSteps = 40;
 
-static void cd_do_simulate_click (CairoContainer *pContainer, Icon *pIcon, int iModifierType)
+static void cd_do_simulate_click (GldiContainer *pContainer, Icon *pIcon, int iModifierType)
 {
 	g_return_if_fail (pIcon != NULL);
 	myData.bIgnoreClick = TRUE;  // -> ignore the "click" notification, which would close the session and remove the notification while in the loop. the caller of this method should ensure to close the session after.
-	cairo_dock_notify_on_object (pContainer, NOTIFICATION_CLICK_ICON, pIcon, pContainer, iModifierType);
+	gldi_object_notify (pContainer, NOTIFICATION_CLICK_ICON, pIcon, pContainer, iModifierType);
 	myData.bIgnoreClick = FALSE;
 }
 
-static inline int _orient_arrow (CairoContainer *pContainer, int iKeyVal)
+static inline int _orient_arrow (GldiContainer *pContainer, int iKeyVal)
 {
 	switch (iKeyVal)
 	{
-		case GDK_Up :
+		case GDK_KEY_Up :
 			if (pContainer->bIsHorizontal)
 			{
 				if (!pContainer->bDirectionUp)
-					iKeyVal = GDK_Down;
+					iKeyVal = GDK_KEY_Down;
 			}
 			else
 			{
-				iKeyVal = GDK_Left;
+				iKeyVal = GDK_KEY_Left;
 			}
 		break;
 		
-		case GDK_Down :
+		case GDK_KEY_Down :
 			if (pContainer->bIsHorizontal)
 			{
 				if (!pContainer->bDirectionUp)
-					iKeyVal = GDK_Up;
+					iKeyVal = GDK_KEY_Up;
 			}
 			else
 			{
-				iKeyVal = GDK_Right;
+				iKeyVal = GDK_KEY_Right;
 			}
 		break;
 		
-		case GDK_Left :
+		case GDK_KEY_Left :
 			if (!pContainer->bIsHorizontal)
 			{
 				if (pContainer->bDirectionUp)
-					iKeyVal = GDK_Up;
+					iKeyVal = GDK_KEY_Up;
 				else
-					iKeyVal = GDK_Down;
+					iKeyVal = GDK_KEY_Down;
 			}
 		break;
 		
-		case GDK_Right :
+		case GDK_KEY_Right :
 			if (!pContainer->bIsHorizontal)
 			{
 				if (pContainer->bDirectionUp)
-					iKeyVal = GDK_Down;
+					iKeyVal = GDK_KEY_Down;
 				else
-					iKeyVal = GDK_Up;
+					iKeyVal = GDK_KEY_Up;
 			}
 		break;
 		default:
@@ -112,19 +108,19 @@ static void _activate_nth_icon (guint iKeyVal, guint iModifierType)  // iKeyVal
 	cd_debug ("%s (%d)", __func__, iKeyVal);
 	// get the index of the icon: we want "1" to be the first icon, because it's more natural and it follows the keyboard layout. So "0" will actually be the 10th icon.
 	int iIndex;  // from 0
-	if (iKeyVal >= GDK_0 && iKeyVal <= GDK_9)
+	if (iKeyVal >= GDK_KEY_0 && iKeyVal <= GDK_KEY_9)
 	{
-		if (iKeyVal == GDK_0)
+		if (iKeyVal == GDK_KEY_0)
 			iIndex = 9;
 		else
-			iIndex = iKeyVal - GDK_1;
+			iIndex = iKeyVal - GDK_KEY_1;
 	}
 	else
 	{
-		if (iKeyVal == GDK_KP_0)
+		if (iKeyVal == GDK_KEY_KP_0)
 			iIndex = 9;
 		else
-			iIndex = iKeyVal - GDK_KP_1;
+			iIndex = iKeyVal - GDK_KEY_KP_1;
 	}
 	cd_debug ("click on %d", iIndex);
 	// retrieve the nth icon in the current dock.
@@ -149,10 +145,9 @@ static void _activate_nth_icon (guint iKeyVal, guint iModifierType)  // iKeyVal
 	if (pNthIcon != NULL)
 	{
 		cd_debug ("click on %s", pNthIcon->cName);
-		///cairo_dock_notify_on_object (CAIRO_CONTAINER (myData.pCurrentDock), NOTIFICATION_CLICK_ICON, pNthIcon, myData.pCurrentDock, iModifierType);
 		cd_do_simulate_click (CAIRO_CONTAINER (myData.pCurrentDock), pNthIcon, iModifierType);
 
-		cairo_dock_start_icon_animation (pNthIcon, myData.pCurrentDock);
+		gldi_icon_start_animation (pNthIcon);
 		myData.bIgnoreIconState = FALSE;
 		if (pNthIcon == myData.pCurrentIcon)
 			myData.pCurrentIcon = NULL;  // sinon on va interrompre l'animation en fermant la session.
@@ -161,10 +156,10 @@ static void _activate_nth_icon (guint iKeyVal, guint iModifierType)  // iKeyVal
 	}
 }
 
-gboolean cd_do_key_pressed (gpointer pUserData, CairoContainer *pContainer, guint iKeyVal, guint iModifierType, const gchar *string, int iKeyCode)
+gboolean cd_do_key_pressed (gpointer pUserData, GldiContainer *pContainer, guint iKeyVal, guint iModifierType, const gchar *string, int iKeyCode)
 {
-	g_return_val_if_fail (cd_do_session_is_running (), CAIRO_DOCK_LET_PASS_NOTIFICATION);
-	g_return_val_if_fail (myData.pCurrentDock != NULL, CAIRO_DOCK_LET_PASS_NOTIFICATION);
+	g_return_val_if_fail (cd_do_session_is_running (), GLDI_NOTIFICATION_LET_PASS);
+	g_return_val_if_fail (myData.pCurrentDock != NULL, GLDI_NOTIFICATION_LET_PASS);
 	
 	const gchar *cKeyName = gdk_keyval_name (iKeyVal);
 	guint32 iUnicodeChar = gdk_keyval_to_unicode (iKeyVal);
@@ -184,7 +179,7 @@ gboolean cd_do_key_pressed (gpointer pUserData, CairoContainer *pContainer, guin
 		for (i = 0; i < n_entries; i ++)
 		{
 			iKeyVal2 = keyvals[i];
-			if ((iKeyVal2 >= GDK_0 && iKeyVal2 <= GDK_9) || (iKeyVal2 >= GDK_KP_0 && iKeyVal2 <= GDK_KP_9))
+			if ((iKeyVal2 >= GDK_KEY_0 && iKeyVal2 <= GDK_KEY_9) || (iKeyVal2 >= GDK_KEY_KP_0 && iKeyVal2 <= GDK_KEY_KP_9))
 			{
 				iKeyVal = iKeyVal2;
 				break;
@@ -194,36 +189,36 @@ gboolean cd_do_key_pressed (gpointer pUserData, CairoContainer *pContainer, guin
 		g_free (keyvals);
 	}
 	
-	if (iKeyVal == GDK_Escape)  // on clot la session.
+	if (iKeyVal == GDK_KEY_Escape)  // on clot la session.
 	{
 		// give the focus back to the window that had it before the user opened this session.
-		if (myData.iPreviouslyActiveWindow != 0)
+		if (myData.pPreviouslyActiveWindow != NULL)
 		{
-			cairo_dock_show_xwindow (myData.iPreviouslyActiveWindow);
+			gldi_window_show (myData.pPreviouslyActiveWindow);
 		}
 		cd_do_close_session ();
 	}
-	else if (iKeyVal == GDK_space && myData.sCurrentText->len == 0)  // pas d'espace en debut de chaine.
+	else if (iKeyVal == GDK_KEY_space && myData.sCurrentText->len == 0)  // pas d'espace en debut de chaine.
 	{
 		// on rejette.
 	}
-	else if (iKeyVal >= GDK_Shift_L && iKeyVal <= GDK_Hyper_R)  // on n'ecrit pas les modificateurs.
+	else if (iKeyVal >= GDK_KEY_Shift_L && iKeyVal <= GDK_KEY_Hyper_R)  // on n'ecrit pas les modificateurs.
 	{
 		// on rejette.
 	}
-	else if (iKeyVal == GDK_Menu)  // emulation du clic droit.
+	else if (iKeyVal == GDK_KEY_Menu)  // emulation du clic droit.
 	{
 		if (myData.pCurrentIcon != NULL)
 		{
 			myData.bIgnoreIconState = TRUE;
-			cairo_dock_stop_icon_animation (myData.pCurrentIcon);  // car on va perdre le focus.
+			gldi_icon_stop_animation (myData.pCurrentIcon);  // car on va perdre le focus.
 			myData.bIgnoreIconState = FALSE;
 			
-			GtkWidget *menu = cairo_dock_build_menu (myData.pCurrentIcon, CAIRO_CONTAINER (myData.pCurrentDock));
-			cairo_dock_popup_menu_on_icon (menu, myData.pCurrentIcon, CAIRO_CONTAINER (myData.pCurrentDock));
+			GtkWidget *menu = gldi_container_build_menu (CAIRO_CONTAINER (myData.pCurrentDock), myData.pCurrentIcon);
+			gldi_menu_popup (menu);
 		}
 	}
-	else if (iKeyVal == GDK_BackSpace)  // on efface la derniere lettre.
+	else if (iKeyVal == GDK_KEY_BackSpace)  // on efface la derniere lettre.
 	{
 		if (myData.sCurrentText->len > 0)
 		{
@@ -236,7 +231,7 @@ gboolean cd_do_key_pressed (gpointer pUserData, CairoContainer *pContainer, guin
 				cd_do_search_current_icon (FALSE);
 		}
 	}
-	else if (iKeyVal == GDK_Tab)  // jump to next icon.
+	else if (iKeyVal == GDK_KEY_Tab)  // jump to next icon.
 	{
 		if (myData.sCurrentText->len > 0)
 		{
@@ -245,7 +240,7 @@ gboolean cd_do_key_pressed (gpointer pUserData, CairoContainer *pContainer, guin
 			cd_do_search_current_icon (TRUE);  // pCurrentIcon peut etre NULL si elle s'est faite detruire pendant la recherche, auquel cas on cherchera juste normalement.
 		}
 	}
-	else if (iKeyVal == GDK_Return)
+	else if (iKeyVal == GDK_KEY_Return)
 	{
 		if (myData.pCurrentIcon != NULL)
 		{
@@ -255,35 +250,33 @@ gboolean cd_do_key_pressed (gpointer pUserData, CairoContainer *pContainer, guin
 			if (iModifierType & GDK_MOD1_MASK)  // ALT
 			{
 				myData.bIgnoreIconState = TRUE;
-				cairo_dock_stop_icon_animation (myData.pCurrentIcon);  // car aucune animation ne va la remplacer.
+				gldi_icon_stop_animation (myData.pCurrentIcon);  // car aucune animation ne va la remplacer.
 				myData.bIgnoreIconState = FALSE;
-				///cairo_dock_notify_on_object (&myContainersMgr, NOTIFICATION_MIDDLE_CLICK_ICON, myData.pCurrentIcon, myData.pCurrentDock);
-				cairo_dock_notify_on_object (CAIRO_CONTAINER (myData.pCurrentDock), NOTIFICATION_MIDDLE_CLICK_ICON, myData.pCurrentIcon, myData.pCurrentDock);
+				gldi_object_notify (CAIRO_CONTAINER (myData.pCurrentDock), NOTIFICATION_MIDDLE_CLICK_ICON, myData.pCurrentIcon, myData.pCurrentDock);
 			}
 			else if (iModifierType & GDK_CONTROL_MASK)  // CTRL
 			{
 				myData.bIgnoreIconState = TRUE;
-				cairo_dock_stop_icon_animation (myData.pCurrentIcon);  // car on va perdre le focus.
+				gldi_icon_stop_animation (myData.pCurrentIcon);  // car on va perdre le focus.
 				myData.bIgnoreIconState = FALSE;
 				
-				GtkWidget *menu = cairo_dock_build_menu (myData.pCurrentIcon, CAIRO_CONTAINER (myData.pCurrentDock));
-				cairo_dock_popup_menu_on_icon (menu, myData.pCurrentIcon, CAIRO_CONTAINER (myData.pCurrentDock));
+				GtkWidget *menu = gldi_container_build_menu (CAIRO_CONTAINER (myData.pCurrentDock), myData.pCurrentIcon);
+				gldi_menu_popup (menu);
 			}
 			else
 			{
-				///cairo_dock_notify_on_object (CAIRO_CONTAINER (myData.pCurrentDock), NOTIFICATION_CLICK_ICON, myData.pCurrentIcon, myData.pCurrentDock, iModifierType);
 				cd_do_simulate_click (CAIRO_CONTAINER (myData.pCurrentDock), myData.pCurrentIcon, iModifierType);
 			}
-			cairo_dock_start_icon_animation (myData.pCurrentIcon, myData.pCurrentDock);
+			gldi_icon_start_animation (myData.pCurrentIcon);
 			myData.bIgnoreIconState = FALSE;
 			myData.pCurrentIcon = NULL;  // sinon on va interrompre l'animation en fermant la session.
 		}
 		cd_do_close_session ();
 	}
-	else if (iKeyVal == GDK_Left || iKeyVal == GDK_Right || iKeyVal == GDK_Up || iKeyVal == GDK_Down)
+	else if (iKeyVal == GDK_KEY_Left || iKeyVal == GDK_KEY_Right || iKeyVal == GDK_KEY_Up || iKeyVal == GDK_KEY_Down)
 	{
 		iKeyVal = _orient_arrow (pContainer, iKeyVal);
-		if (iKeyVal == GDK_Up)
+		if (iKeyVal == GDK_KEY_Up)
 		{
 			if (myData.pCurrentIcon != NULL && myData.pCurrentIcon->pSubDock != NULL)
 			{
@@ -292,7 +285,7 @@ gboolean cd_do_key_pressed (gpointer pUserData, CairoContainer *pContainer, guin
 				cd_do_change_current_icon (pIcon, myData.pCurrentIcon->pSubDock);
 			}
 		}
-		else if (iKeyVal == GDK_Down)
+		else if (iKeyVal == GDK_KEY_Down)
 		{
 			if (myData.pCurrentDock->iRefCount > 0)
 			{
@@ -305,7 +298,7 @@ gboolean cd_do_key_pressed (gpointer pUserData, CairoContainer *pContainer, guin
 				}
 			}
 		}
-		else if (iKeyVal == GDK_Left)
+		else if (iKeyVal == GDK_KEY_Left)
 		{
 			if (myData.pCurrentDock->icons != NULL)
 			{
@@ -338,12 +331,12 @@ gboolean cd_do_key_pressed (gpointer pUserData, CairoContainer *pContainer, guin
 			}
 		}
 	}
-	else if (iKeyVal == GDK_Page_Down || iKeyVal == GDK_Page_Up || iKeyVal == GDK_Home || iKeyVal == GDK_End)
+	else if (iKeyVal == GDK_KEY_Page_Down || iKeyVal == GDK_KEY_Page_Up || iKeyVal == GDK_KEY_Home || iKeyVal == GDK_KEY_End)
 	{
 		if (iModifierType & GDK_CONTROL_MASK)  // changement de dock principal
 		{
 			gpointer data[4] = {myData.pCurrentDock, NULL, GINT_TO_POINTER (FALSE), NULL};
-			cairo_dock_foreach_root_docks ((GFunc) _find_next_dock, data);
+			gldi_docks_foreach_root ((GFunc) _find_next_dock, data);
 			CairoDock *pNextDock = data[1];
 			if (pNextDock == NULL)
 				pNextDock = data[3];
@@ -361,11 +354,11 @@ gboolean cd_do_key_pressed (gpointer pUserData, CairoContainer *pContainer, guin
 			}
 		}
 		
-		Icon *pIcon = (iKeyVal == GDK_Page_Up || iKeyVal == GDK_Home ? cairo_dock_get_first_icon (myData.pCurrentDock->icons) : cairo_dock_get_last_icon (myData.pCurrentDock->icons));
+		Icon *pIcon = (iKeyVal == GDK_KEY_Page_Up || iKeyVal == GDK_KEY_Home ? cairo_dock_get_first_icon (myData.pCurrentDock->icons) : cairo_dock_get_last_icon (myData.pCurrentDock->icons));
 		cd_debug ("on se deplace a l'extremite sur %s", pIcon ? pIcon->cName : "none");
 		cd_do_change_current_icon (pIcon, myData.pCurrentDock);
 	}
-	else if ( ((iKeyVal >= GDK_0 && iKeyVal <= GDK_9) || (iKeyVal >= GDK_KP_0 && iKeyVal <= GDK_KP_9))
+	else if ( ((iKeyVal >= GDK_KEY_0 && iKeyVal <= GDK_KEY_9) || (iKeyVal >= GDK_KEY_KP_0 && iKeyVal <= GDK_KEY_KP_9))
 	&& myData.sCurrentText->len == 0)
 	{
 		_activate_nth_icon (iKeyVal, iModifierType);
@@ -378,7 +371,7 @@ gboolean cd_do_key_pressed (gpointer pUserData, CairoContainer *pContainer, guin
 		cd_do_search_current_icon (FALSE);
 	}
 	
-	return CAIRO_DOCK_INTERCEPT_NOTIFICATION;
+	return GLDI_NOTIFICATION_INTERCEPT;
 }
 
 
@@ -391,18 +384,18 @@ void cd_do_on_shortkey_nav (const char *keystring, gpointer data)
 	else
 	{
 		// give the focus back to the window that had it before the user opened this session.
-		if (myData.iPreviouslyActiveWindow != 0)
+		if (myData.pPreviouslyActiveWindow != NULL)
 		{
-			cairo_dock_show_xwindow (myData.iPreviouslyActiveWindow);
+			gldi_window_show (myData.pPreviouslyActiveWindow);
 		}
 		cd_do_close_session ();
 	}
 }
 
 
-gboolean cd_do_update_container (gpointer pUserData, CairoContainer *pContainer, gboolean *bContinueAnimation)
+gboolean cd_do_update_container (gpointer pUserData, GldiContainer *pContainer, gboolean *bContinueAnimation)
 {
-	g_return_val_if_fail (!cd_do_session_is_off (), CAIRO_DOCK_LET_PASS_NOTIFICATION);
+	g_return_val_if_fail (!cd_do_session_is_off (), GLDI_NOTIFICATION_LET_PASS);
 	
 	if (myData.iMotionCount != 0)
 	{
@@ -434,7 +427,7 @@ gboolean cd_do_update_container (gpointer pUserData, CairoContainer *pContainer,
 		cairo_dock_redraw_container (pContainer);
 	}
 	
-	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+	return GLDI_NOTIFICATION_LET_PASS;
 }
 
 
@@ -460,37 +453,33 @@ gboolean cd_do_check_icon_destroyed (gpointer pUserData, Icon *pIcon)
 			cd_do_exit_session ();
 	}
 	
-	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+	return GLDI_NOTIFICATION_LET_PASS;
 }
 
 
-static void _check_dock_is_active (gchar *cDockName, CairoDock *pDock, Window *data)
+static void _check_dock_is_active (gchar *cDockName, CairoDock *pDock, gboolean *data)
 {
-	Window xActiveWindow = data[0];
-	if (gldi_container_get_Xid (CAIRO_CONTAINER (pDock)) == xActiveWindow)
-		data[1] = 1;
+	if (gldi_container_is_active (CAIRO_CONTAINER (pDock)))
+		*data = TRUE;
 }
-gboolean cd_do_check_active_dock (gpointer pUserData, Window *XActiveWindow)
+gboolean cd_do_check_active_dock (gpointer pUserData, GldiWindowActor *actor)
 {
 	if (! cd_do_session_is_running ())
-		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
-	if (XActiveWindow == NULL)
-		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+		return GLDI_NOTIFICATION_LET_PASS;
 	
 	// check if a dock has the focus (the user has switched to either another dock, or another window)
-	Window data[2] = {*XActiveWindow, 0};
-	cairo_dock_foreach_docks ((GHFunc) _check_dock_is_active, data);
+	gboolean bDockIsActive = FALSE;
+	gldi_docks_foreach ((GHFunc) _check_dock_is_active, &bDockIsActive);
 	
-	if (data[1] == 0)  // no dock is active, so the current dock has lost the focus.
+	if (! bDockIsActive)  // the user has switched to another window -> close the session
 	{
 		cd_do_close_session ();
-		///gtk_window_present (GTK_WINDOW (myData.pCurrentDock->container.pWidget));
 	}
-	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+	return GLDI_NOTIFICATION_LET_PASS;
 }
 
 
-static void _render_cairo (CairoContainer *pContainer, cairo_t *pCairoContext)
+static void _render_cairo (GldiContainer *pContainer, cairo_t *pCairoContext)
 {
 	double fAlpha;
 	if (myData.iCloseTime != 0) // animation de fin
@@ -530,7 +519,7 @@ static void _render_cairo (CairoContainer *pContainer, cairo_t *pCairoContext)
 	}
 }
 
-static void _render_opengl (CairoContainer *pContainer)
+static void _render_opengl (GldiContainer *pContainer)
 {
 	double fAlpha;
 	if (myData.iCloseTime != 0) // animation de fin
@@ -572,9 +561,9 @@ static void _render_opengl (CairoContainer *pContainer)
 	}
 }
 
-gboolean cd_do_render (gpointer pUserData, CairoContainer *pContainer, cairo_t *pCairoContext)
+gboolean cd_do_render (gpointer pUserData, GldiContainer *pContainer, cairo_t *pCairoContext)
 {
-	g_return_val_if_fail (!cd_do_session_is_off (), CAIRO_DOCK_LET_PASS_NOTIFICATION);
+	g_return_val_if_fail (!cd_do_session_is_off (), GLDI_NOTIFICATION_LET_PASS);
 	
 	if (pCairoContext != NULL)
 	{
@@ -585,16 +574,16 @@ gboolean cd_do_render (gpointer pUserData, CairoContainer *pContainer, cairo_t *
 		_render_opengl (pContainer);
 	}
 	
-	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+	return GLDI_NOTIFICATION_LET_PASS;
 }
 
-gboolean cd_do_on_click (gpointer pUserData, Icon *icon, CairoContainer *pContainer)
+gboolean cd_do_on_click (gpointer pUserData, Icon *icon, GldiContainer *pContainer)
 {
-	g_return_val_if_fail (!cd_do_session_is_off (), CAIRO_DOCK_LET_PASS_NOTIFICATION);
+	g_return_val_if_fail (!cd_do_session_is_off (), GLDI_NOTIFICATION_LET_PASS);
 	
 	if (! myData.bIgnoreClick)
 		cd_do_close_session ();
 	
-	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+	return GLDI_NOTIFICATION_LET_PASS;
 }
 
