@@ -43,7 +43,6 @@
 #define  CD_INDICATOR_SERVICE_INTERFACE "org.ayatana.indicator.service"
 #define  CD_INDICATOR_SERVICE_OBJECT "/org/ayatana/indicator/service"
 
-#define CD_INDICATOR_APPLICATION_ITEM_OBJ "/org/ayatana/NotificationItem"
 
 static DBusGProxyCall *s_pDetectIASCall = NULL;
 
@@ -276,7 +275,7 @@ const gchar *cTitle,
 #endif
 #endif
 #endif
-CairoDockModuleInstance *myApplet)
+GldiModuleInstance *myApplet)
 {
 	CD_APPLET_ENTER;
 	cd_debug ("=== %s (%s, %s, %s, %s, %d)", __func__, cAddress, cObjectPath, cIconName, cIconThemePath, iPosition);
@@ -322,7 +321,7 @@ CairoDockModuleInstance *myApplet)
 	CD_APPLET_LEAVE ();
 }
 
-static void on_removed_application (DBusGProxy *proxy_watcher, gint iPosition, CairoDockModuleInstance *myApplet)
+static void on_removed_application (DBusGProxy *proxy_watcher, gint iPosition, GldiModuleInstance *myApplet)
 {
 	CD_APPLET_ENTER;
 	cd_debug ("=== %s (%d)", __func__, iPosition);
@@ -345,7 +344,7 @@ static void on_removed_application (DBusGProxy *proxy_watcher, gint iPosition, C
 	CD_APPLET_LEAVE ();
 }
 
-static void on_application_icon_changed (DBusGProxy *proxy_watcher, gint iPosition, const gchar *cIconName, const gchar *cIconDesc, CairoDockModuleInstance *myApplet)
+static void on_application_icon_changed (DBusGProxy *proxy_watcher, gint iPosition, const gchar *cIconName, const gchar *cIconDesc, GldiModuleInstance *myApplet)
 {
 	CD_APPLET_ENTER;
 	cd_debug ("=== %s (%d, %s, %s)", __func__, iPosition, cIconName, cIconDesc);
@@ -368,7 +367,7 @@ static void on_application_icon_changed (DBusGProxy *proxy_watcher, gint iPositi
 	CD_APPLET_LEAVE ();
 }
 
-static void on_application_icon_theme_path_changed (DBusGProxy *proxy_watcher, gint iPosition, const gchar *cIconThemePath, CairoDockModuleInstance *myApplet)
+static void on_application_icon_theme_path_changed (DBusGProxy *proxy_watcher, gint iPosition, const gchar *cIconThemePath, GldiModuleInstance *myApplet)
 {
 	CD_APPLET_ENTER;
 	cd_debug ("=== %s (%d, %s)", __func__, iPosition, cIconThemePath);
@@ -393,7 +392,7 @@ static void on_application_icon_theme_path_changed (DBusGProxy *proxy_watcher, g
 	CD_APPLET_LEAVE ();
 }
 
-static void on_application_label_changed (DBusGProxy *proxy_watcher, gint iPosition, const gchar *cLabel, const gchar *cLabelGuide, CairoDockModuleInstance *myApplet)
+static void on_application_label_changed (DBusGProxy *proxy_watcher, gint iPosition, const gchar *cLabel, const gchar *cLabelGuide, GldiModuleInstance *myApplet)
 {
 	CD_APPLET_ENTER;
 	cd_debug ("=== %s (%d, %s, %s)", __func__, iPosition, cLabel, cLabelGuide);
@@ -409,7 +408,7 @@ static void on_application_label_changed (DBusGProxy *proxy_watcher, gint iPosit
 	CD_APPLET_LEAVE ();
 }
 
-static void on_application_title_changed (DBusGProxy *proxy_watcher, gint iPosition, const gchar *cTitle, CairoDockModuleInstance *myApplet)
+static void on_application_title_changed (DBusGProxy *proxy_watcher, gint iPosition, const gchar *cTitle, GldiModuleInstance *myApplet)
 {
 	CD_APPLET_ENTER;
 	cd_debug ("=== %s (%d, %s)", __func__, iPosition, cTitle);
@@ -430,7 +429,7 @@ static void on_application_title_changed (DBusGProxy *proxy_watcher, gint iPosit
  /// Get Items ///
 /////////////////
 
-static void _on_get_applications_from_service (DBusGProxy *proxy, DBusGProxyCall *call_id, CairoDockModuleInstance *myApplet)
+static void _on_get_applications_from_service (DBusGProxy *proxy, DBusGProxyCall *call_id, GldiModuleInstance *myApplet)
 {
 	cd_debug ("=== %s ()", __func__);
 	CD_APPLET_ENTER;
@@ -513,14 +512,6 @@ static void _on_get_applications_from_service (DBusGProxy *proxy, DBusGProxyCall
 		if (v && G_VALUE_HOLDS (v, DBUS_TYPE_G_OBJECT_PATH))
 			cObjectPath = (gchar*)g_value_get_boxed (v);
 
-		/*cd_debug ("=== cObjectPath : %s", cObjectPath);
-		if (cObjectPath != NULL && strncmp (cObjectPath, CD_INDICATOR_APPLICATION_ITEM_OBJ, strlen (CD_INDICATOR_APPLICATION_ITEM_OBJ)) == 0)
-		{
-			gchar *str = strrchr (cObjectPath, '/');  // I think this is because this path is actually the menu path, and fortunately it's just under the item object's path.
-			if (str)
-				*str = '\0';
-		}*/ // => we will do that in cd_satus_notifier_create_item because this function is also called when a new application is added => host.c
-
 		v = g_value_array_get_nth (va, 4);
 		if (v && G_VALUE_HOLDS_STRING (v))
 			cIconThemePath = g_value_get_string (v);
@@ -586,7 +577,6 @@ static void _on_get_applications_from_service (DBusGProxy *proxy, DBusGProxyCall
 			                          cLabel && *cLabel != '\0' ? cLabel :
 			                          cTitle && *cTitle != '\0' ? cTitle :
 			                          NULL);  // don't use cId as a fallback, because it often has cryptic names (nm-applet ; dropbox-xxxx). If the appli doesn't provide a title, it's its fault.
-		myData.pItems = g_list_prepend (myData.pItems, pItem);
 	}
 	
 	if (myConfig.bCompactMode)
@@ -743,6 +733,20 @@ static void _on_watch_service (DBusGProxy *proxy, DBusGProxyCall *call, gpointer
 		G_TYPE_UINT, &service_api_version,
 		G_TYPE_UINT, &this_service_version,
 		G_TYPE_INVALID);
+	if (error != NULL)
+	{
+		cd_debug ("Unable to watch the service: %s", error->message);
+		g_error_free (error);
+		/* Note: Not a big deal, let start getting items: it seems that the
+		 * service is no longer available and *no longer needed* on Ubuntu 14.04
+		 *  https://bazaar.launchpad.net/~indicator-applet-developers/indicator-application/trunk.14.04/revision/246
+		 *  https://bugs.launchpad.net/bugs/1303731
+		 * TODO: remove this ugly hack...
+		 */
+		#if (INDICATOR_OLD_NAMES == 0)
+		service_api_version = 1;
+		#endif
+	}
 	cd_debug ("=== got indicator service (API: %d, service: %d, broken watcher: %d)", service_api_version, this_service_version, myData.bBrokenWatcher);
 	
 	if (service_api_version > 0)  /// shouldn't the 2 versions be equal ?...
