@@ -112,7 +112,7 @@ static CDToolTip *_make_tooltip_from_dbus_struct (GValueArray *pToolTipTab)
 static void _show_item_tooltip (Icon *pIcon, CDStatusNotifierItem *pItem)
 {
 	gchar *cText = g_strdup_printf ("<b>%s</b>\n%s", pItem->pToolTip->cTitle, pItem->pToolTip->cMessage);
-	cairo_dock_show_temporary_dialog_with_icon (cText, pIcon, CAIRO_CONTAINER (myIcon->pSubDock), 4000, pItem->pToolTip->cIconName);
+	gldi_dialog_show_temporary_with_icon (cText, pIcon, CAIRO_CONTAINER (myIcon->pSubDock), 4000, pItem->pToolTip->cIconName);
 	g_free (cText);
 }
 */
@@ -122,18 +122,18 @@ static void _show_item_tooltip (Icon *pIcon, CDStatusNotifierItem *pItem)
 	{
 		case CD_STATUS_PASSIVE :
 			pIcon->fAlpha = 0.5;
-			cairo_dock_stop_icon_attention (pIcon, myIcon->pSubDock);
+			gldi_icon_stop_attention (pIcon, myIcon->pSubDock);
 			cairo_dock_redraw_icon (pIcon, CAIRO_CONTAINER (myIcon->pSubDock));
 		break;
 		case CD_STATUS_ACTIVE :
 		default:
 			pIcon->fAlpha = 1.;
-			cairo_dock_stop_icon_attention (pIcon, myIcon->pSubDock);
+			gldi_icon_stop_attention (pIcon, myIcon->pSubDock);
 			cairo_dock_redraw_icon (pIcon, CAIRO_CONTAINER (myIcon->pSubDock));
 		break;
 		case CD_STATUS_NEEDS_ATTENTION:
 			pIcon->fAlpha = 1.;
-			cairo_dock_request_icon_attention (pIcon, myIcon->pSubDock, "rotate", 60);
+			gldi_icon_request_attention (pIcon, "rotate", 60);
 		break;
 	}
 }*/
@@ -256,7 +256,7 @@ static void on_new_item_title (DBusGProxy *proxy_item, CDStatusNotifierItem *pIt
 	pItem->cTitle = cairo_dock_dbus_get_property_as_string (pItem->pProxyProps, CD_STATUS_NOTIFIER_ITEM_IFACE, "Title");
 	cd_debug ("===  new title : %s", pItem->cTitle);
 	
-	//cairo_dock_set_icon_name (cTitle, pIcon, CAIRO_CONTAINER (myIcon->pSubDock));
+	//gldi_icon_set_name (pIcon, cTitle);
 	
 	CD_APPLET_LEAVE ();
 }
@@ -298,7 +298,7 @@ static void on_new_item_tooltip (DBusGProxy *proxy_item, CDStatusNotifierItem *p
 	cd_free_tooltip (pItem->pToolTip);
 	pItem->pToolTip = NULL;
 	
-	//cairo_dock_remove_dialog_if_any (pIcon);
+	//gldi_dialogs_remove_on_icon (pIcon);
 	
 	GValueArray *pToolTipTab = cairo_dock_dbus_get_property_as_boxed (pItem->pProxyProps, CD_STATUS_NOTIFIER_ITEM_IFACE, "ToolTip");
 	if (pToolTipTab)
@@ -319,7 +319,7 @@ static void _on_item_proxy_destroyed (DBusGProxy *proxy_item, CDStatusNotifierIt
 	CD_APPLET_ENTER;
 	//g_print ("=== this item (%s) was suddenly removed\n", __func__, pItem->cService);
 	
-	myData.pItems = g_list_remove (myData.pItems, pItem);
+	cd_status_notifier_remove_item_in_list (pItem);
 	
 	if (myConfig.bCompactMode)
 	{
@@ -655,7 +655,10 @@ CDStatusNotifierItem *cd_satus_notifier_create_item (const gchar *cService, cons
 		cd_satus_notifier_add_theme_path (pItem->cIconThemePath);
 	}
 	
-	// build the dbusmenu right now, so that the menu is complete when the user first click on the item (otherwise, the menu is not placed correctly).
+	// add it in the list already (must be done before we build its dbusmenu, otherwise the applet's icon might be hidden if it's the first item (=> not in its container), which prevents from initializing the menu correctly
+	cd_status_notifier_add_item_in_list (pItem);
+	
+	// build the dbusmenu right now, so that the menu is complete when the user first clicks on the item (otherwise, the menu is not placed correctly).
 	cd_satus_notifier_build_item_dbusmenu (pItem);
 	
 	//\_________________ track any changes in the item.
@@ -825,6 +828,7 @@ void cd_satus_notifier_build_item_dbusmenu (CDStatusNotifierItem *pItem)
 			pItem->pMenu = dbusmenu_gtkmenu_new ((gchar *)pItem->cService, (gchar *)pItem->cMenuPath);
 			if (g_object_is_floating (pItem->pMenu))  // claim ownership on the menu.
 				g_object_ref_sink (pItem->pMenu);
+			gldi_menu_init (GTK_WIDGET(pItem->pMenu), myIcon);
 			/* Position of the menu: GTK doesn't do its job :-/
 			 * e.g. with Dropbox: the menu is out of the screen every time
 			 * something has changed in this menu (it displays 'connecting',
@@ -832,15 +836,11 @@ void cd_satus_notifier_build_item_dbusmenu (CDStatusNotifierItem *pItem)
 			 * (maybe it's due to a delay because Python and DBus are slower...)
 			 * We can't watch the 'configure' event (which should be triggered
 			 * each time the menu is resized) because it seems this notification
-			 * is not send...
+			 * is not sent...
 			 * This is why we need to watch the 'draw' event...
 			 */
 			g_signal_connect (G_OBJECT (pItem->pMenu),
-				#if (GTK_MAJOR_VERSION < 3)
-				"expose-event",
-				#else
 				"draw",
-				#endif
 				G_CALLBACK (_on_draw_menu_reposition),
 				pItem);
 		}
