@@ -1,4 +1,4 @@
-/**
+	/**
 * This file is a part of the Cairo-Dock project
 *
 * Copyright : (C) see the 'copyright' file.
@@ -33,7 +33,7 @@ static gboolean _xf86vidmode_supported (void)
 		return s_bUseXf86VidMode;
 
 	int event_base, error_base;
-	Display *dpy = cairo_dock_get_Xdisplay ();
+	Display *dpy = gdk_x11_get_default_xdisplay ();
 	if (! XF86VidModeQueryExtension (dpy, &event_base, &error_base))  // on regarde si le serveur X supporte l'extension.
 	{
 		cd_warning ("XF86VidMode extension not available.");
@@ -82,7 +82,7 @@ void xgamma_add_gamma (XF86VidModeGamma *pGamma, gint iNbSteps)
 double xgamma_get_gamma (XF86VidModeGamma *pGamma)
 {
 	g_return_val_if_fail (pGamma != NULL, 1);
-	Display *dpy = cairo_dock_get_Xdisplay ();
+	Display *dpy = gdk_x11_get_default_xdisplay ();
 	
 	g_return_val_if_fail (_xf86vidmode_supported (), 1.);
 	if (!XF86VidModeGetGamma (dpy, DefaultScreen (dpy), pGamma))
@@ -100,7 +100,7 @@ double xgamma_get_gamma (XF86VidModeGamma *pGamma)
 void xgamma_set_gamma (XF86VidModeGamma *pGamma)
 {
 	g_return_if_fail (pGamma != NULL);
-	Display *dpy = cairo_dock_get_Xdisplay ();
+	Display *dpy = gdk_x11_get_default_xdisplay ();
 	
 	g_return_if_fail (_xf86vidmode_supported ());
 	if (!XF86VidModeSetGamma(dpy, DefaultScreen (dpy), pGamma))
@@ -180,30 +180,17 @@ static GtkWidget *_xgamma_add_channel_widget (GtkWidget *pInteractiveWidget, con
 	else
 	{
 		gtk_label_set_text (GTK_LABEL (pLabel), cLabel);
-		cairo_dock_set_dialog_widget_text_color (pLabel); // default colour
+		gldi_dialog_set_widget_text_color (pLabel); // default colour
 	}
 
-	#if GTK_CHECK_VERSION (3, 4, 0)
 	gtk_grid_attach (GTK_GRID (pInteractiveWidget),
 		pLabel,
 		1,
 		iChannelNumber+1,
 		1,
 		1);
-	#else
-	gtk_table_attach_defaults (GTK_TABLE (pInteractiveWidget),
-		pLabel,
-		0,
-		1,
-		iChannelNumber,
-		iChannelNumber+1);
-	#endif
 
-	#if (GTK_MAJOR_VERSION < 3)
-	GtkWidget *pHScale = gtk_hscale_new_with_range (GAMMA_MIN, GAMMA_MAX, .02);
-	#else
 	GtkWidget *pHScale = gtk_scale_new_with_range (GTK_ORIENTATION_HORIZONTAL, GAMMA_MIN, GAMMA_MAX, .02);
-	#endif
 	gtk_scale_set_digits (GTK_SCALE (pHScale), 2);
 	gtk_range_set_value (GTK_RANGE (pHScale), fChannelGamma);
 	g_object_set (pHScale, "width-request", 150, NULL);
@@ -212,40 +199,27 @@ static GtkWidget *_xgamma_add_channel_widget (GtkWidget *pInteractiveWidget, con
 		"value-changed",
 		G_CALLBACK (on_scale_value_changed),
 		GINT_TO_POINTER (iChannelNumber));
-	#if GTK_CHECK_VERSION (3, 4, 0)
 	gtk_grid_attach (GTK_GRID (pInteractiveWidget),
 		pHScale,
 		2,
 		iChannelNumber+1,
 		1,
 		1);
-	#else
-	gtk_table_attach_defaults (GTK_TABLE (pInteractiveWidget),
-		pHScale,
-		1,
-		2,
-		iChannelNumber,
-		iChannelNumber+1);
-	#endif
-	
+
 	return pHScale;
 }
 void xgamma_create_scales_widget (double fGamma, XF86VidModeGamma *pGamma)
 {
-	#if GTK_CHECK_VERSION (3, 4, 0)
 	myData.pWidget = gtk_grid_new ();
-	#else
-	myData.pWidget = gtk_table_new (4, 2, FALSE);
-	#endif
-	
+
 	myData.pGlobalScale = _xgamma_add_channel_widget (myData.pWidget, D_("Gamma :"), NULL, 0, &myData.iGloalScaleSignalID, fGamma);
-	
+
 	myData.pRedScale = _xgamma_add_channel_widget (myData.pWidget, D_("Red :"), "red", 1, &myData.iRedScaleSignalID, pGamma->red);
-	
+
 	myData.pGreenScale = _xgamma_add_channel_widget (myData.pWidget, D_("Green :"), "green", 2, &myData.iGreenScaleSignalID, pGamma->green);
-	
+
 	myData.pBlueScale = _xgamma_add_channel_widget (myData.pWidget, D_("Blue :"), "blue", 3, &myData.iBlueScaleSignalID, pGamma->blue);
-	
+
 	gtk_widget_show_all (myData.pWidget);
 }
 
@@ -262,21 +236,23 @@ static void _xgamma_apply_values (int iClickedButton, GtkWidget *pWidget, gpoint
 		myData.Xgamma = myData.XoldGamma;
 		xgamma_set_gamma (&myData.Xgamma);
 	}
-	cairo_dock_hide_dialog (myData.pDialog);
-	cairo_dock_dialog_reference (myData.pDialog);  // pour garder notre dialogue en vie.
+	gldi_dialog_hide (myData.pDialog);
+	gldi_object_ref (GLDI_OBJECT(myData.pDialog));  // pour garder notre dialogue en vie.
 	
 }
 CairoDialog *xgamma_build_dialog (void)
 {
-	CairoDialogAttribute attr;
-	memset (&attr, 0, sizeof (CairoDialogAttribute));
+	CairoDialogAttr attr;
+	memset (&attr, 0, sizeof (CairoDialogAttr));
 	attr.cText = D_("Set up gamma:");
 	attr.pInteractiveWidget = myData.pWidget;
 	const gchar *cButtons[3] = {"ok", "cancel", NULL};
 	attr.cButtonsImage = cButtons;
 	attr.pActionFunc = (CairoDockActionOnAnswerFunc) _xgamma_apply_values;
 	attr.pUserData = myApplet;
-	return cairo_dock_build_dialog (&attr, myIcon, myContainer);
+	attr.pIcon = myIcon;
+	attr.pContainer = myContainer;
+	return gldi_dialog_new (&attr);
 }
 
 void xgamma_build_and_show_widget (void)
@@ -292,7 +268,7 @@ void xgamma_build_and_show_widget (void)
 	}
 	else
 	{
-		cairo_dock_add_interactive_widget_to_desklet (myData.pWidget, myDesklet);
+		gldi_desklet_add_interactive_widget (myDesklet, myData.pWidget);
 		CD_APPLET_SET_DESKLET_RENDERER (NULL);  // pour empecher le clignotement du au double-buffer.
 		CD_APPLET_SET_STATIC_DESKLET;
 	}
@@ -328,14 +304,10 @@ CairoDialog *xgamma_build_dialog_simple (void)
 	double fGammaPercent = _gamma_to_percent (fGamma);
 	myData.XoldGamma = myData.Xgamma;
 	
-	CairoDialogAttribute attr;
-	memset (&attr, 0, sizeof (CairoDialogAttribute));
+	CairoDialogAttr attr;
+	memset (&attr, 0, sizeof (CairoDialogAttr));
 
-	#if (GTK_MAJOR_VERSION < 3)
-	GtkWidget *pHScale = gtk_hscale_new_with_range (0, 100., 1.);
-	#else
 	GtkWidget *pHScale = gtk_scale_new_with_range (GTK_ORIENTATION_HORIZONTAL, 0, 100., 1.);
-	#endif
 	gtk_scale_set_digits (GTK_SCALE (pHScale), 0);
 	gtk_range_set_value (GTK_RANGE (pHScale), fGammaPercent);
 	g_object_set (pHScale, "width-request", 150, NULL);
@@ -343,7 +315,7 @@ CairoDialog *xgamma_build_dialog_simple (void)
 		"value-changed",
 		G_CALLBACK (on_scale_value_changed_simple),
 		NULL);
-	cairo_dock_set_dialog_widget_text_color (pHScale);
+	gldi_dialog_set_widget_text_color (pHScale);
 	
 	attr.cText = D_("Set up gamma:");
 	attr.pInteractiveWidget = pHScale;
@@ -351,7 +323,9 @@ CairoDialog *xgamma_build_dialog_simple (void)
 	attr.cButtonsImage = cButtons;
 	attr.pActionFunc = (CairoDockActionOnAnswerFunc) _xgamma_apply_value_simple;
 	attr.pUserData = myApplet;
-	return cairo_dock_build_dialog (&attr, myIcon, myContainer);
+	attr.pIcon = myIcon;
+	attr.pContainer = myContainer;
+	return gldi_dialog_new (&attr);
 }
 
 
@@ -359,6 +333,6 @@ void cd_gamma_display_gamma_on_label (double fGamma)
 {
 	double fGammaPercent = _gamma_to_percent (fGamma);
 	gchar *cLabel = g_strdup_printf ("%s: %d%%", D_("Luminosity"), (int)fGammaPercent);
-	cairo_dock_set_icon_name (cLabel, myIcon, myContainer);
+	gldi_icon_set_name (myIcon, cLabel);
 	g_free (cLabel);
 }
