@@ -77,7 +77,11 @@ CD_APPLET_GET_CONFIG_BEGIN
 	#ifdef INDICATOR_SOUNDMENU_WITH_IND3
 	myConfig.cIndicatorName = CD_CONFIG_GET_STRING ("Configuration", "indicator name");  // we take it from the config just in case the name changes, it's not a visible option.
 	if (myConfig.cIndicatorName == NULL)
+		#ifdef IS_INDICATOR_NG
+		myConfig.cIndicatorName = g_strdup ("com.canonical.indicator.sound");
+		#else
 		myConfig.cIndicatorName = g_strdup ("libsoundmenu.so");
+		#endif
 	#endif
 CD_APPLET_GET_CONFIG_END
 
@@ -104,11 +108,11 @@ CD_APPLET_RESET_DATA_BEGIN
 		gtk_widget_destroy (myData.pScale);
 		myData.pScale = NULL;
 	}
-	cairo_dock_dialog_unreference (myData.pDialog);
+	gldi_object_unref (GLDI_OBJECT(myData.pDialog));
 CD_APPLET_RESET_DATA_END
 
 
-void cd_mixer_load_custom_widget (CairoDockModuleInstance *myApplet, GKeyFile* pKeyFile, GSList *pWidgetList)  // myApplet can be NULL
+void cd_mixer_load_custom_widget (GldiModuleInstance *myApplet, GKeyFile* pKeyFile, GSList *pWidgetList)  // myApplet can be NULL
 {
 	//\____________ build the list of available sound cards.
 	GList *pList = mixer_get_cards_list ();
