@@ -22,8 +22,6 @@
 #define __USE_POSIX
 #include <signal.h>
 
-#include <gdk/gdkkeysyms.h> // needed for 'GDK_Escape'
-
 #include "applet-struct.h"
 #include "applet-calendar.h"
 #include "applet-task-editor.h"
@@ -44,7 +42,7 @@ typedef enum _CDClockTaskColumns
 } CDClockTaskColumns;
 
 
-static gboolean on_delete_task_window (GtkWidget *pWidget, CairoDockModuleInstance *myApplet)
+static gboolean on_delete_task_window (GtkWidget *pWidget, GldiModuleInstance *myApplet)
 {
 	//g_print ("%s ()\n", __func__);
 	/// get day
@@ -60,7 +58,7 @@ static gboolean on_delete_task_window (GtkWidget *pWidget, CairoDockModuleInstan
 	return FALSE;  // detruit la fenetre.
 }
 
-static GtkListStore *_cd_clock_create_model_for_current_day (guint iDay, guint iMonth, guint iYear, CairoDockModuleInstance *myApplet)
+static GtkListStore *_cd_clock_create_model_for_current_day (guint iDay, guint iMonth, guint iYear, GldiModuleInstance *myApplet)
 {
 	//g_print ("%s (%d/%d/%d)\n", __func__, iDay, iMonth, iYear);
 	//\______________ On cree le modele.
@@ -109,7 +107,7 @@ static GtkListStore *_cd_clock_create_model_for_current_day (guint iDay, guint i
 	return pModel;
 }
 
-static void _cd_clock_add_new_task (GtkMenuItem *pMenuItem, CairoDockModuleInstance *myApplet)
+static void _cd_clock_add_new_task (GtkMenuItem *pMenuItem, GldiModuleInstance *myApplet)
 {
 	//g_print ("%s ()\n", __func__);
 	CDClockTask *pTask = g_new0 (CDClockTask, 1);
@@ -133,7 +131,7 @@ static void _cd_clock_add_new_task (GtkMenuItem *pMenuItem, CairoDockModuleInsta
 static void _cd_clock_delete_task (GtkMenuItem *pMenuItem, gpointer *data)
 {
 	cd_debug ("%s ()", __func__);
-	CairoDockModuleInstance *myApplet = data[0];
+	GldiModuleInstance *myApplet = data[0];
 	CDClockTask *pTask = data[1];
 	gboolean bDeleted = myData.pBackend->delete_task (pTask, myApplet);
 	
@@ -148,13 +146,13 @@ static void _cd_clock_delete_task (GtkMenuItem *pMenuItem, gpointer *data)
 		cd_clock_update_calendar_marks (myApplet);
 	}
 }
-static gboolean _on_click_tree_view (GtkTreeView *pTreeView, GdkEventButton* pButton, CairoDockModuleInstance *myApplet)
+static gboolean _on_click_tree_view (GtkTreeView *pTreeView, GdkEventButton* pButton, GldiModuleInstance *myApplet)
 {
 	static gpointer *data = NULL;
 	if (pButton->button == 3 && pButton->type == GDK_BUTTON_RELEASE)
 	{
-		GtkWidget *pMenu = gtk_menu_new ();
-		cairo_dock_add_in_menu_with_stock_and_data (D_("Add a new task"), GTK_STOCK_ADD, G_CALLBACK (_cd_clock_add_new_task), pMenu, myApplet);
+		GtkWidget *pMenu = gldi_menu_new (NULL);
+		cairo_dock_add_in_menu_with_stock_and_data (D_("Add a new task"), GLDI_ICON_NAME_ADD, G_CALLBACK (_cd_clock_add_new_task), pMenu, myApplet);
 		
 		GtkTreeSelection *pSelection = gtk_tree_view_get_selection (pTreeView);
 		GtkTreeModel *pModel;
@@ -175,7 +173,7 @@ static gboolean _on_click_tree_view (GtkTreeView *pTreeView, GdkEventButton* pBu
 				data[0] = myApplet;
 				data[1] = pTask;
 				data[2] = pModel;
-				cairo_dock_add_in_menu_with_stock_and_data (D_("Delete this task"), GTK_STOCK_REMOVE, G_CALLBACK (_cd_clock_delete_task), pMenu, data);
+				cairo_dock_add_in_menu_with_stock_and_data (D_("Delete this task"), GLDI_ICON_NAME_REMOVE, G_CALLBACK (_cd_clock_delete_task), pMenu, data);
 			}
 		}
 		gtk_widget_show_all (pMenu);
@@ -190,7 +188,7 @@ static gboolean _on_click_tree_view (GtkTreeView *pTreeView, GdkEventButton* pBu
 	return FALSE;
 }
 
-static gboolean _cd_clock_select_one_item_in_tree (GtkTreeSelection * selection, GtkTreeModel * model, GtkTreePath * path, gboolean path_currently_selected, CairoDockModuleInstance *myApplet)
+static gboolean _cd_clock_select_one_item_in_tree (GtkTreeSelection * selection, GtkTreeModel * model, GtkTreePath * path, gboolean path_currently_selected, GldiModuleInstance *myApplet)
 {
 	if (path_currently_selected)
 		return TRUE;
@@ -241,7 +239,7 @@ static GtkListStore *_make_frequency_list_store (void)
 	g_free (cID);\
 	g_return_if_fail (pTask != NULL);
 	
-static void _on_change_title (GtkCellRendererText * cell, gchar * path_string, gchar * new_text, CairoDockModuleInstance *myApplet)
+static void _on_change_title (GtkCellRendererText * cell, gchar * path_string, gchar * new_text, GldiModuleInstance *myApplet)
 {
 	if (new_text == NULL || *new_text == '\0')\
 		return;
@@ -256,7 +254,7 @@ static void _on_change_title (GtkCellRendererText * cell, gchar * path_string, g
 	}
 }
 
-static void _on_change_text (GtkCellRendererText * cell, gchar * path_string, gchar * new_text, CairoDockModuleInstance *myApplet)
+static void _on_change_text (GtkCellRendererText * cell, gchar * path_string, gchar * new_text, GldiModuleInstance *myApplet)
 {
 	_get_task_from_path (new_text, path_string);
 	
@@ -269,7 +267,7 @@ static void _on_change_text (GtkCellRendererText * cell, gchar * path_string, gc
 	}
 }
 
-static void _on_change_tags (GtkCellRendererText * cell, gchar * path_string, gchar * new_text, CairoDockModuleInstance *myApplet)
+static void _on_change_tags (GtkCellRendererText * cell, gchar * path_string, gchar * new_text, GldiModuleInstance *myApplet)
 {
 	_get_task_from_path (new_text, path_string);
 	
@@ -282,7 +280,7 @@ static void _on_change_tags (GtkCellRendererText * cell, gchar * path_string, gc
 	}
 }
 
-static void _on_change_time (GtkCellRendererText * cell, gchar * path_string, gchar * new_text, CairoDockModuleInstance *myApplet)
+static void _on_change_time (GtkCellRendererText * cell, gchar * path_string, gchar * new_text, GldiModuleInstance *myApplet)
 {
 	_get_task_from_path(new_text, path_string);
 	
@@ -314,7 +312,7 @@ static gboolean _search_frequency (GtkTreeModel * model, GtkTreePath * path, Gtk
 	}
 	return FALSE;
 }
-static void _on_change_frequency (GtkCellRendererText * cell, gchar * path_string, gchar * new_text, CairoDockModuleInstance *myApplet)
+static void _on_change_frequency (GtkCellRendererText * cell, gchar * path_string, gchar * new_text, GldiModuleInstance *myApplet)
 {
 	_get_task_from_path(new_text, path_string);
 	
@@ -336,7 +334,7 @@ static void _on_change_frequency (GtkCellRendererText * cell, gchar * path_strin
 	}
 }
 
-static void _cd_clock_render_frequency (GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, GtkTreeModel *model,GtkTreeIter *iter, CairoDockModuleInstance *myApplet)
+static void _cd_clock_render_frequency (GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, GtkTreeModel *model,GtkTreeIter *iter, GldiModuleInstance *myApplet)
 {
 	int iFrequency;
 	gtk_tree_model_get (model, iter, CD_TASK_FREQ, &iFrequency, -1);
@@ -356,7 +354,7 @@ static void _cd_clock_render_frequency (GtkTreeViewColumn *tree_column, GtkCellR
 	}
 }
 
-static void _cd_clock_render_time (GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, GtkTreeModel *model,GtkTreeIter *iter, CairoDockModuleInstance *myApplet)
+static void _cd_clock_render_time (GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, GtkTreeModel *model,GtkTreeIter *iter, GldiModuleInstance *myApplet)
 {
 	int iTime;
 	gtk_tree_model_get (model, iter, CD_TASK_TIME, &iTime, -1);
@@ -371,9 +369,9 @@ static void _cd_clock_render_time (GtkTreeViewColumn *tree_column, GtkCellRender
 
 gboolean _on_key_press (G_GNUC_UNUSED GtkWidget *pWidget,
 	GdkEventKey *pKey,
-	CairoDockModuleInstance *myApplet)
+	GldiModuleInstance *myApplet)
 {
-	if (pKey->type == GDK_KEY_PRESS && pKey->keyval == GLDI_KEY(Escape))
+	if (pKey->type == GDK_KEY_PRESS && pKey->keyval == GDK_KEY_Escape)
 	{
 		gtk_widget_destroy (myData.pTaskWindow);
 		return TRUE;
@@ -381,7 +379,7 @@ gboolean _on_key_press (G_GNUC_UNUSED GtkWidget *pWidget,
 	return FALSE;
 }
 
-void cd_clock_build_task_editor (guint iDay, guint iMonth, guint iYear, CairoDockModuleInstance *myApplet)
+void cd_clock_build_task_editor (guint iDay, guint iMonth, guint iYear, GldiModuleInstance *myApplet)
 {
 	//\______________ On remplit le modele avec la date courante.
 	GtkListStore *pModel = _cd_clock_create_model_for_current_day (iDay, iMonth, iYear, myApplet);
@@ -462,7 +460,11 @@ void cd_clock_build_task_editor (guint iDay, guint iMonth, guint iYear, CairoDoc
 		//\______________ On l'ajoute a la fenetre.
 		GtkWidget *pScrolledWindow = gtk_scrolled_window_new (NULL, NULL);
 		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (pScrolledWindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+		#if GTK_CHECK_VERSION (3, 8, 0)
+		gtk_container_add (GTK_CONTAINER (pScrolledWindow), pTreeView);
+		#else
 		gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (pScrolledWindow), pTreeView);
+		#endif
 		gtk_container_add (GTK_CONTAINER (myData.pTaskWindow), pScrolledWindow);
 		//gtk_box_pack_start (GTK_BOX (pVBox), pScrolledWindow, FALSE, FALSE, 0);
 		
