@@ -43,18 +43,14 @@ static void _set_warning_repetition (int iClickedButton, GtkWidget *pInteractive
 static gboolean _task_warning (CDClockTask *pTask, const gchar *cMessage)
 {
 	cd_debug ("%s (%s)", __func__, cMessage);
-	CairoDockModuleInstance *myApplet = pTask->pApplet;
+	GldiModuleInstance *myApplet = pTask->pApplet;
 
-	#if (GTK_MAJOR_VERSION < 3)
-	GtkWidget *pScale = gtk_hscale_new_with_range (1, 60, 1);  // 1mn-60mn et 1 cran/mn.
-	#else
 	GtkWidget *pScale = gtk_scale_new_with_range (GTK_ORIENTATION_HORIZONTAL, 1, 60, 1);  // 1mn-60mn et 1 cran/mn.
-	#endif
 	gtk_scale_set_digits (GTK_SCALE (pScale), 0);
 	gtk_range_set_value (GTK_RANGE (pScale), pTask->iWarningDelay != 0 ? pTask->iWarningDelay : 15);  // 15mn par defaut.
 	g_object_set (pScale, "width-request", CAIRO_DIALOG_MIN_SCALE_WIDTH, NULL);
 
-	GtkWidget *pExtendedWidget = _gtk_hbox_new (0);
+	GtkWidget *pExtendedWidget = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	GtkWidget *label = gtk_label_new (D_("1mn"));
 	GtkWidget *pAlign = gtk_alignment_new (1., 1., 0., 0.);
 	gtk_container_add (GTK_CONTAINER (pAlign), label);
@@ -65,10 +61,10 @@ static gboolean _task_warning (CDClockTask *pTask, const gchar *cMessage)
 	gtk_container_add (GTK_CONTAINER (pAlign), label);
 	gtk_box_pack_start (GTK_BOX (pExtendedWidget), pAlign, FALSE, FALSE, 0);
 	
-	cairo_dock_dialog_unreference (pTask->pWarningDialog);
+	gldi_object_unref (GLDI_OBJECT(pTask->pWarningDialog));
 	
-	CairoDialogAttribute attr;
-	memset (&attr, 0, sizeof (CairoDialogAttribute));
+	CairoDialogAttr attr;
+	memset (&attr, 0, sizeof (CairoDialogAttr));
 	attr.cText = (gchar *)cMessage;
 	attr.bUseMarkup = TRUE;
 	attr.cImageFilePath = (gchar *)MY_APPLET_SHARE_DATA_DIR"/icon-task.png";
@@ -78,15 +74,9 @@ static gboolean _task_warning (CDClockTask *pTask, const gchar *cMessage)
 	attr.iTimeLength = (pTask->iWarningDelay != 0 ? MIN (pTask->iWarningDelay-.1, 15.) : 15) * 60e3;  // on laisse le dialogue visible le plus longtemps possible, jusqu'a 15mn.
 	const gchar *cDefaultActionButtons[3] = {"ok", "cancel", NULL};
 	attr.cButtonsImage = cDefaultActionButtons;
-	pTask->pWarningDialog = cairo_dock_build_dialog (&attr, myIcon, myContainer);
-	/**pTask->pWarningDialog = cairo_dock_show_dialog_full (cMessage,
-		myIcon, myContainer,
-		(pTask->iWarningDelay != 0 ? MIN (pTask->iWarningDelay-.1, 15.) : 15) * 60e3,  // on laisse le dialogue visible le plus longtemps possible, jusqu'a 15mn.
-		MY_APPLET_SHARE_DATA_DIR"/icon-task.png",
-		pExtendedWidget,
-		(CairoDockActionOnAnswerFunc) _set_warning_repetition,
-		pTask,
-		NULL);*/
+	attr.pIcon = myIcon;
+	attr.pContainer = myContainer;
+	pTask->pWarningDialog = gldi_dialog_new (&attr);
 	
 	CD_APPLET_DEMANDS_ATTENTION (NULL, 3600);  // ~ 1h, pour si on loupe le dialogue.
 	return TRUE;
@@ -133,11 +123,11 @@ static void _set_warning_repetition (int iClickedButton, GtkWidget *pInteractive
 		}
 	}
 	pTask->pWarningDialog = NULL;
-	CairoDockModuleInstance *myApplet = pTask->pApplet;
+	GldiModuleInstance *myApplet = pTask->pApplet;
 	CD_APPLET_STOP_DEMANDING_ATTENTION;
 }
 
-static inline void _get_current_time (time_t epoch, CairoDockModuleInstance *myApplet)
+static inline void _get_current_time (time_t epoch, GldiModuleInstance *myApplet)
 {
 	if (myConfig.cLocation != NULL)
 	{
@@ -154,13 +144,13 @@ static inline void _get_current_time (time_t epoch, CairoDockModuleInstance *myA
 	}
 }
 
-void cd_clock_init_time (CairoDockModuleInstance *myApplet)
+void cd_clock_init_time (GldiModuleInstance *myApplet)
 {
 	time_t epoch = (time_t) time (NULL);
 	_get_current_time (epoch, myApplet);
 }
 
-static gchar *_make_missed_task_message (CDClockTask *pTask, CairoDockModuleInstance *myApplet)
+static gchar *_make_missed_task_message (CDClockTask *pTask, GldiModuleInstance *myApplet)
 {
 	//g_print ("%s (%s)\n", __func__, pTask->cID);
 	struct tm st;
@@ -186,7 +176,7 @@ static gchar *_make_missed_task_message (CDClockTask *pTask, CairoDockModuleInst
 		pTask->cTitle?pTask->cTitle:D_("No title"),
 		pTask->cText?pTask->cText:"");
 }
-static void _on_next_missed_task (int iClickedButton, GtkWidget *pInteractiveWidget, CairoDockModuleInstance *myApplet, CairoDialog *pDialog)
+static void _on_next_missed_task (int iClickedButton, GtkWidget *pInteractiveWidget, GldiModuleInstance *myApplet, CairoDialog *pDialog)
 {
 	g_return_if_fail (myData.pMissedTasks != NULL);
 	//g_print ("%s ()\n", __func__);
@@ -206,7 +196,7 @@ static void _on_next_missed_task (int iClickedButton, GtkWidget *pInteractiveWid
 			pTask = myData.pMissedTasks->data;
 			//g_print ("display task '%s'\n", pTask->cID);
 			gchar *cMessage = _make_missed_task_message (pTask, myApplet);
-			cairo_dock_set_dialog_message (pDialog, cMessage);
+			gldi_dialog_set_message (pDialog, cMessage);
 			g_free (cMessage);
 			
 			// remove 'next' button if no more task will follow.
@@ -234,7 +224,7 @@ static void _on_next_missed_task (int iClickedButton, GtkWidget *pInteractiveWid
 				i = 0;
 				pDialog->pButtons[i].iDefaultType = 1;
 			}
-			cairo_dock_dialog_reference (pDialog);  // keep the dialog alive.
+			gldi_object_ref (GLDI_OBJECT(pDialog));  // keep the dialog alive.
 		}
 	}
 	else  // dismiss next missed tasks and let the dialog close itself.
@@ -244,7 +234,7 @@ static void _on_next_missed_task (int iClickedButton, GtkWidget *pInteractiveWid
 	}
 }
 
-gboolean cd_clock_update_with_time (CairoDockModuleInstance *myApplet)
+gboolean cd_clock_update_with_time (GldiModuleInstance *myApplet)
 {
 	CD_APPLET_ENTER;
 	//\________________ On recupere l'heure courante.
@@ -270,19 +260,14 @@ gboolean cd_clock_update_with_time (CairoDockModuleInstance *myApplet)
 				_cairo_dock_delete_texture (myData.iDateTexture);
 			
 			double fScale = (double) iWidth / (double) myData.DimensionData.width;
-			CairoDockLabelDescription labelDescription;
-			memset (&labelDescription, 0, sizeof (CairoDockLabelDescription));
-			labelDescription.iSize = 10;
-			labelDescription.cFont = (gchar*)"Sans";  // on peut caster car on ne liberera rien.
-			labelDescription.iWeight = cairo_dock_get_pango_weight_from_1_9 (5);
-			labelDescription.iStyle = PANGO_STYLE_NORMAL;
-			labelDescription.fColorStart[0] = myConfig.fDateColor[0];
-			labelDescription.fColorStart[1] = myConfig.fDateColor[1];
-			labelDescription.fColorStart[2] = myConfig.fDateColor[2];
-			memcpy (&labelDescription.fColorStop[0], &labelDescription.fColorStart[0], sizeof (labelDescription.fColorStop));
-			labelDescription.fBackgroundColor[3] = 0;
-			labelDescription.bOutlined = FALSE;
-			labelDescription.iMargin = 0;
+			GldiTextDescription labelDescription;
+			memset (&labelDescription, 0, sizeof (GldiTextDescription));
+			gldi_text_description_set_font (&labelDescription, (gchar*)"Sans 8");  // casted and then set to null
+			labelDescription.fColorStart.rgba.red = myConfig.fDateColor[0];
+			labelDescription.fColorStart.rgba.green = myConfig.fDateColor[1];
+			labelDescription.fColorStart.rgba.blue = myConfig.fDateColor[2];
+			labelDescription.fColorStart.rgba.alpha = 1.;
+			labelDescription.bNoDecorations = TRUE;
 			cairo_surface_t *pDateSurface = cairo_dock_create_surface_from_text_full (s_cDateBuffer,
 				&labelDescription,
 				fScale,
@@ -291,6 +276,8 @@ gboolean cd_clock_update_with_time (CairoDockModuleInstance *myApplet)
 			//g_print ("date : %dx%d\n", myData.iDateWidth, myData.iDateHeight);
 			myData.iDateTexture = cairo_dock_create_texture_from_surface (pDateSurface);
 			cairo_surface_destroy (pDateSurface);
+			labelDescription.cFont = NULL;
+			gldi_text_description_reset (&labelDescription);
 		}
 	}
 	if (bNewDate && myConfig.iShowDate == CAIRO_DOCK_INFO_ON_LABEL)
@@ -356,7 +343,7 @@ gboolean cd_clock_update_with_time (CairoDockModuleInstance *myApplet)
 				if (bShowAlarm)
 				{
 					cd_message ("Dring ! %s", pAlarm->cMessage);
-					cairo_dock_show_temporary_dialog (pAlarm->cMessage, myIcon, myContainer, 60e3);
+					gldi_dialog_show_temporary (pAlarm->cMessage, myIcon, myContainer, 60e3);
 					if (pAlarm->cCommand != NULL)
 					{
 						if (myData.iAlarmPID > 0)
@@ -405,8 +392,8 @@ gboolean cd_clock_update_with_time (CairoDockModuleInstance *myApplet)
 		{
 			CDClockTask *pTask = myData.pMissedTasks->data;
 			gchar *cMessage = _make_missed_task_message (pTask, myApplet);
-			CairoDialogAttribute attr;
-			memset (&attr, 0, sizeof (CairoDialogAttribute));
+			CairoDialogAttr attr;
+			memset (&attr, 0, sizeof (CairoDialogAttr));
 			attr.cText = cMessage;
 			attr.bUseMarkup = TRUE;
 			attr.cImageFilePath = (gchar *)MY_APPLET_SHARE_DATA_DIR"/icon-task.png";
@@ -421,7 +408,10 @@ gboolean cd_clock_update_with_time (CairoDockModuleInstance *myApplet)
 			attr.pUserData = myApplet;
 			attr.pFreeDataFunc = NULL;
 			attr.iTimeLength = 0;
-			cairo_dock_build_dialog (&attr, myIcon, myContainer);
+			attr.pIcon = myIcon;
+			attr.pContainer = myContainer;
+			gldi_dialog_new (&attr);
+			
 			g_free (cMessage);
 		}
 		
@@ -475,20 +465,15 @@ gboolean cd_clock_update_with_time (CairoDockModuleInstance *myApplet)
 						myData.pNextTask->cTitle?myData.pNextTask->cTitle:D_("No title"),
 						myData.pNextTask->cText?myData.pNextTask->cText:"");
 					
-					CairoDialogAttribute attr;
-					memset (&attr, 0, sizeof (CairoDialogAttribute));
+					CairoDialogAttr attr;
+					memset (&attr, 0, sizeof (CairoDialogAttr));
 					attr.cText = (gchar *)cText;
 					attr.cImageFilePath = (gchar *)MY_APPLET_SHARE_DATA_DIR"/icon-task.png";
 					attr.iTimeLength = 60e3;
 					attr.bUseMarkup = TRUE;
-					cairo_dock_build_dialog (&attr, myIcon, myContainer);
-					/**cairo_dock_show_temporary_dialog_with_icon_printf ("%s\n<b>%s</b>\n %s",
-						myIcon, myContainer,
-						60e3,
-						MY_APPLET_SHARE_DATA_DIR"/icon-task.png",
-						D_("This task will begin in 15 minutes:"),
-						myData.pNextTask->cTitle?myData.pNextTask->cTitle:D_("No title"),
-						myData.pNextTask->cText?myData.pNextTask->cText:"");*/
+					attr.pIcon = myIcon;
+					attr.pContainer = myContainer;
+					gldi_dialog_new (&attr);
 					CD_APPLET_DEMANDS_ATTENTION (NULL, 60);
 				}
 			}
