@@ -38,19 +38,41 @@ void cd_dnd2share_free_uploaded_item (CDUploadedItem *pItem)
 }
 
 
+static gchar * _get_short_text_for_menu (const gchar *cInitText)
+{
+	if (cInitText == NULL) // the backend should not allow that!
+		return g_strdup (D_("No text"));
+
+	// remove extras withespaces first
+	gchar *cLongText = g_strstrip (g_strdup (cInitText));
+	// then print only the first line => no, like Clipper
+	/*gchar *str = strchr (cLongText, '\n');
+	if (str)
+		*str = '\0';*/
+	gchar *cShortText = cairo_dock_cut_string (cLongText, 40);
+
+	// With 'Text' label, it's different than filename
+	gchar *cResult = g_strdup_printf ("%s %s", D_("Text:"), cShortText);
+
+	g_free (cLongText);
+	g_free (cShortText);
+
+	return cResult;
+}
+
 void cd_dnd2share_build_history (void)
 {
 	gchar *cConfFilePath = g_strdup_printf ("%s/%s", myData.cWorkingDirPath, "history.conf");
 	GKeyFile *pKeyFile = cairo_dock_open_key_file (cConfFilePath);
 	g_free (cConfFilePath);
-	if (pKeyFile == NULL)  // pas encore d'historique.
+	if (pKeyFile == NULL)  // no history yet.
 		return ;
-	
+
 	gsize length = 0;
 	gchar **pGroupList = g_key_file_get_groups (pKeyFile, &length);
 	if (pGroupList == NULL)
 		return ;
-	
+
 	CDUploadedItem *pItem;
 	int iSiteID, iFileType;
 	gchar *cItemName;
@@ -69,7 +91,7 @@ void cd_dnd2share_build_history (void)
 			g_free (cItemName);
 			continue;
 		}
-		if (iSiteID >= CD_NB_SITES)
+		if (iSiteID >= CD_NB_SITES_MAX)
 		{
 			cd_warning ("dnd2share : this backend doesn't exist !");
 			g_free (cItemName);
@@ -90,7 +112,7 @@ void cd_dnd2share_build_history (void)
 			g_free (cItemName);
 			continue;
 		}
-		
+
 		pItem = g_new0 (CDUploadedItem, 1);
 		pItem->cItemName = cItemName;
 		pItem->iSiteID = iSiteID;
@@ -99,17 +121,20 @@ void cd_dnd2share_build_history (void)
 		for (j = 0; j < myData.backends[iFileType][iSiteID].iNbUrls; j ++)
 		{
 			g_string_printf (sUrlKey, "url%d", j);
-			pItem->cDistantUrls[j] = g_key_file_get_string (pKeyFile, cItemName, sUrlKey->str, NULL);  // NULL si cette URL n'avait pas ete sauvegardee avant.
+			pItem->cDistantUrls[j] = g_key_file_get_string (pKeyFile, cItemName, sUrlKey->str, NULL);  // NULL if this URL has not been saved before.
 		}
-		pItem->iDate = g_key_file_get_integer (pKeyFile, cItemName, "date", NULL);  /// un 'int' est-ce que ca suffit ?...
-		
+		pItem->iDate = g_key_file_get_integer (pKeyFile, cItemName, "date", NULL);
+
 		pItem->cLocalPath = g_key_file_get_string (pKeyFile, cItemName, "local path", NULL);
-		pItem->cFileName = g_path_get_basename (pItem->cLocalPath);
-		
+		if (pItem->iFileType == CD_TYPE_TEXT)
+			pItem->cFileName = _get_short_text_for_menu (pItem->cLocalPath);
+		else
+			pItem->cFileName = g_path_get_basename (pItem->cLocalPath);
+
 		myData.pUpoadedItems = g_list_prepend (myData.pUpoadedItems, pItem);
 	}
 	g_string_free (sUrlKey, TRUE);
-	g_free (pGroupList);  // le contenu a ete pris par la liste.
+	g_free (pGroupList);  // the content has been added in the list.
 	g_key_file_free (pKeyFile);
 }
 
@@ -125,11 +150,11 @@ void cd_dnd2share_clear_history (void)
 static void _cd_dnd2share_threaded_upload (CDSharedMemory *pSharedMemory)
 {
 	gchar *cFilePath = pSharedMemory->cCurrentFilePath;
-	
+
 	pSharedMemory->cResultUrls = g_new0 (gchar *, pSharedMemory->iNbUrls+1);  // NULL-terminated
-	pSharedMemory->upload (cFilePath, pSharedMemory->cDropboxDir, pSharedMemory->bAnonymous, pSharedMemory->iLimitRate, pSharedMemory->cResultUrls);
-	
-	if (pSharedMemory->cResultUrls[0] && pSharedMemory->iTinyURLService != 0)  // on en fait une tiny-url.
+	pSharedMemory->upload (cFilePath, pSharedMemory->cLocalDir, pSharedMemory->bAnonymous, pSharedMemory->iLimitRate, pSharedMemory->cResultUrls, &pSharedMemory->pError);
+
+	if (pSharedMemory->cResultUrls[0] && pSharedMemory->iTinyURLService != 0)  // tiny-url.
 	{
 		gchar *Command = NULL;
 		switch (pSharedMemory->iTinyURLService)
@@ -155,29 +180,36 @@ static void _cd_dnd2share_threaded_upload (CDSharedMemory *pSharedMemory)
 		g_free (Command);
 	}
 }
+
+static void _cd_dnd2share_show_error_dialog (const gchar *cError)
+{
+	gldi_dialogs_remove_on_icon (myIcon);
+
+	gldi_dialog_show_temporary_with_icon (cError,
+		myIcon,
+		myContainer,
+		myConfig.dTimeDialogs * 2,
+		MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE);
+}
+
 static gboolean _cd_dnd2share_update_from_result (CDSharedMemory *pSharedMemory)
 {
 	CD_APPLET_ENTER;
 	gchar *cFilePath = pSharedMemory->cCurrentFilePath;
-	if (pSharedMemory->cResultUrls == NULL || pSharedMemory->cResultUrls[0] == NULL)  // une erreur s'est produite.
-	{
-		cairo_dock_remove_dialog_if_any (myIcon);
-		cairo_dock_show_temporary_dialog_with_icon (D_("Couldn't upload the file, check that your internet connection is active."),
-			myIcon,
-			myContainer,
-			myConfig.dTimeDialogs,
-			MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE);
-	}
+	if (pSharedMemory->pError != NULL)
+		_cd_dnd2share_show_error_dialog (pSharedMemory->pError->message);
+	else if (pSharedMemory->cResultUrls == NULL || pSharedMemory->cResultUrls[0] == NULL) // just to be sure
+		_cd_dnd2share_show_error_dialog (DND2SHARE_GENERIC_ERROR_MSG);
 	else
 	{
 		CDSiteBackend *pCurrentBackend = myData.pCurrentBackend[pSharedMemory->iCurrentFileType];
-		// On rajoute l'item a l'historique.
+		// we add it in the history.
 		if (myConfig.iNbItems != 0)
 		{
-			// On ouvre le fichier de l'historique.
+			// open the file which contains the history
 			gchar *cConfFilePath = g_strdup_printf ("%s/%s", myData.cWorkingDirPath, "history.conf");
 			GKeyFile *pKeyFile;
-			if (! g_file_test (cConfFilePath, G_FILE_TEST_EXISTS))  // pas encore d'historique.
+			if (! g_file_test (cConfFilePath, G_FILE_TEST_EXISTS))  // no history yet.
 				pKeyFile = g_key_file_new ();
 			else
 				pKeyFile = cairo_dock_open_key_file (cConfFilePath);
@@ -187,13 +219,13 @@ static gboolean _cd_dnd2share_update_from_result (CDSharedMemory *pSharedMemory)
 			}
 			else
 			{
-				// On regarde si on n'a pas atteint la limite de taille de l'historique.
+				// we check the size limit
 				gsize length = 0;
 				gchar **pGroupList = g_key_file_get_groups (pKeyFile, &length);
-				if (length == myConfig.iNbItems)  // il faut supprimer le 1er item.
+				if (length == myConfig.iNbItems)  // if yes, we remove the first entry
 				{
 					g_key_file_remove_group (pKeyFile, pGroupList[0], NULL);
-					if (myData.pUpoadedItems != NULL)  // il est en dernier dans la liste.
+					if (myData.pUpoadedItems != NULL)  // which is the last one in the list
 					{
 						GList *it = g_list_last (myData.pUpoadedItems);
 						if (it->prev != NULL)
@@ -204,13 +236,13 @@ static gboolean _cd_dnd2share_update_from_result (CDSharedMemory *pSharedMemory)
 					}
 				}
 				g_strfreev (pGroupList);
-				
-				// on rajoute le nouvel item en fin de fichier.
+
+				// we add the new item at the end of the file
 				time_t iDate = time (NULL);
 				gchar *cItemName = g_strdup_printf ("item_%ld", iDate);
-				
+
 				g_key_file_set_integer (pKeyFile, cItemName, "site", myConfig.iPreferedSite[pSharedMemory->iCurrentFileType]);
-				g_key_file_set_integer (pKeyFile, cItemName, "date", iDate);  // idem que precedemment sur l'integer.
+				g_key_file_set_integer (pKeyFile, cItemName, "date", iDate);
 				g_key_file_set_integer (pKeyFile, cItemName, "type", pSharedMemory->iCurrentFileType);
 				GString *sUrlKey = g_string_new ("");
 				int j;
@@ -220,8 +252,8 @@ static gboolean _cd_dnd2share_update_from_result (CDSharedMemory *pSharedMemory)
 					g_key_file_set_string (pKeyFile, cItemName, sUrlKey->str, pSharedMemory->cResultUrls[j]);
 				}
 				g_key_file_set_string (pKeyFile, cItemName, "local path", cFilePath);
-				
-				// et en debut de liste aussi.
+
+				// and at the beginning of the list
 				CDUploadedItem *pItem = g_new0 (CDUploadedItem, 1);
 				pItem->cItemName = cItemName;
 				pItem->iSiteID = myConfig.iPreferedSite[pSharedMemory->iCurrentFileType];
@@ -233,15 +265,18 @@ static gboolean _cd_dnd2share_update_from_result (CDSharedMemory *pSharedMemory)
 				}
 				pItem->iDate = iDate;
 				pItem->cLocalPath = g_strdup (cFilePath);
-				pItem->cFileName = g_path_get_basename (cFilePath);
+				if (pItem->iFileType == CD_TYPE_TEXT)
+					pItem->cFileName = _get_short_text_for_menu (cFilePath);
+				else
+					pItem->cFileName = g_path_get_basename (cFilePath);
 				myData.pUpoadedItems = g_list_prepend (myData.pUpoadedItems, pItem);
-				
-				// On ecrit tout.
+
+				// We flush the file.
 				cairo_dock_write_keys_to_file (pKeyFile, cConfFilePath);
 				g_key_file_free (pKeyFile);
 				g_string_free (sUrlKey, TRUE);
-				
-				// On garde une copie du fichier (si c'est une image).
+
+				// we keep a copy if it's an image
 				if (myConfig.bkeepCopy && pSharedMemory->iCurrentFileType == CD_TYPE_IMAGE)
 				{
 					gchar *cCommand = g_strdup_printf ("cp '%s' '%s/%s'", cFilePath, myData.cWorkingDirPath, cItemName);
@@ -253,8 +288,8 @@ static gboolean _cd_dnd2share_update_from_result (CDSharedMemory *pSharedMemory)
 			}
 			g_free (cConfFilePath);
 		}
-		
-		// On copie l'URL dans le clipboard.
+
+		// We copy the url to the clipboard
 		gchar *cURL = NULL;
 		if (myConfig.bUseTinyAsDefault)
 			cURL = pSharedMemory->cResultUrls[pCurrentBackend->iNbUrls-1];
@@ -269,24 +304,24 @@ static gboolean _cd_dnd2share_update_from_result (CDSharedMemory *pSharedMemory)
 			}
 		}
 		cd_dnd2share_copy_url_to_clipboard (cURL);
-		
-		// On garde en memoire la derniere URL au cas ou on n'aurait pas/plus d'historique.
+
+		// we keep the last URL if we don't want the history.
 		g_free (myData.cLastURL);
 		myData.cLastURL = g_strdup (cURL);
 		myData.iCurrentItemNum = 0;
-		
-		// On signale par un dialogue la fin de l'upload.
+
+		// we can now display a dialogue.
 		if (myConfig.bEnableDialogs || myDesklet)
 		{
-			cairo_dock_remove_dialog_if_any (myIcon);
-			cairo_dock_show_temporary_dialog_with_icon (D_("File has been uploaded.\nJust press CTRL+v to paste its URL anywhere."),
+			gldi_dialogs_remove_on_icon (myIcon);
+			gldi_dialog_show_temporary_with_icon (D_("File has been uploaded.\nJust press CTRL+v to paste its URL anywhere."),
 				myIcon,
 				myContainer,
 				myConfig.dTimeDialogs,
 				MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE);
 		}
-		
-		// on met l'image correspondante sur l'icone.
+
+		// and set the image on the icon.
 		if (myConfig.bDisplayLastImage)
 		{
 			if (pSharedMemory->iCurrentFileType == CD_TYPE_IMAGE)
@@ -295,32 +330,34 @@ static gboolean _cd_dnd2share_update_from_result (CDSharedMemory *pSharedMemory)
 				CD_APPLET_SET_IMAGE_ON_MY_ICON (MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE);
 		}
 	}
-	
+
 	// stop the animation.
 	CD_APPLET_STOP_DEMANDING_ATTENTION;
-	
+
 	// delete the file if it was a temporary one.
 	if (pSharedMemory->bTempFile)
 	{
 		g_remove (pSharedMemory->cCurrentFilePath);
 	}
-	
+
 	if (myData.cTmpFilePath != NULL)
 	{
 		g_remove (myData.cTmpFilePath);
 		g_free (myData.cTmpFilePath);
 		myData.cTmpFilePath = NULL;
 	}
-	
-	cairo_dock_discard_task (myData.pTask);
+
+	gldi_task_discard (myData.pTask);
 	myData.pTask = NULL;
 	CD_APPLET_LEAVE (FALSE);
 }
 static void _free_shared_memory (CDSharedMemory *pSharedMemory)
 {
-	g_free (pSharedMemory->cDropboxDir);
+	g_free (pSharedMemory->cLocalDir);
 	g_free (pSharedMemory->cCurrentFilePath);
 	g_strfreev (pSharedMemory->cResultUrls);
+	if (pSharedMemory->pError != NULL)
+		g_error_free (pSharedMemory->pError);
 	g_free (pSharedMemory);
 }
 #define CD_BUFFER_LENGTH 50
@@ -329,21 +366,21 @@ void cd_dnd2share_launch_upload (const gchar *cFilePath, CDFileType iFileType)
 	if (myData.pTask != NULL)
 	{
 		cd_warning ("Please wait the current upload is finished before starting a new one.");
-		cairo_dock_remove_dialog_if_any (myIcon);
-		cairo_dock_show_temporary_dialog_with_icon (D_("Please wait for the current upload to finish before starting a new one."),
+		gldi_dialogs_remove_on_icon (myIcon);
+		gldi_dialog_show_temporary_with_icon (D_("Please wait for the current upload to finish before starting a new one."),
 			myIcon,
 			myContainer,
 			myConfig.dTimeDialogs,
 			MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE);
 		return ;
 	}
-	
+
 	if (myData.pCurrentBackend[iFileType]->upload == NULL)
 	{
 		cd_warning ("sorry, it's still not possible to upload this type of file");
 		return ;
 	}
-	
+
 	// launch the task.
 	CDSharedMemory *pSharedMemory = g_new0 (CDSharedMemory, 1);
 	gboolean bIsPath = FALSE; // we can receive text or a text file
@@ -368,13 +405,13 @@ void cd_dnd2share_launch_upload (const gchar *cFilePath, CDFileType iFileType)
 			struct tm currentTime;
 			localtime_r (&epoch, &currentTime);
 			strftime (cTmpFile, CD_BUFFER_LENGTH, "/tmp/cd-%F__%H-%M-%S.txt", &currentTime);
-			
+
 			// write the text inside.
 			g_file_set_contents (cTmpFile,
 				cFilePath,
 				-1,
 				NULL);
-			
+
 			// upload this file
 			cFilePath = cTmpFile;
 			pSharedMemory->bTempFile = TRUE;
@@ -397,8 +434,8 @@ void cd_dnd2share_launch_upload (const gchar *cFilePath, CDFileType iFileType)
 		if (cContents == NULL)  // file was not readable, abort.
 		{
 			cd_warning ("file not readable !");
-			cairo_dock_remove_dialog_if_any (myIcon);
-			cairo_dock_show_temporary_dialog_with_icon (D_("This file is not readable."),
+			gldi_dialogs_remove_on_icon (myIcon);
+			gldi_dialog_show_temporary_with_icon (D_("This file is not readable."),
 				myIcon,
 				myContainer,
 				myConfig.dTimeDialogs,
@@ -411,27 +448,26 @@ void cd_dnd2share_launch_upload (const gchar *cFilePath, CDFileType iFileType)
 		pSharedMemory->cCurrentFilePath = g_strdup (cFilePath);
 
 	g_free (cTmpFile);
-	
+
 	pSharedMemory->iTinyURLService = myConfig.iTinyURLService;
-	pSharedMemory->cDropboxDir = g_strdup (myConfig.cDropboxDir);
+	pSharedMemory->cLocalDir = g_strdup (myConfig.cLocalDir);
 	pSharedMemory->bAnonymous = myConfig.bAnonymous;
 	pSharedMemory->iLimitRate = myConfig.iLimitRate;
-	
+
 	CDSiteBackend *pCurrentBackend = myData.pCurrentBackend[pSharedMemory->iCurrentFileType];
 	g_return_if_fail (pCurrentBackend != NULL);
 	pSharedMemory->upload = pCurrentBackend->upload;
 	pSharedMemory->iNbUrls = pCurrentBackend->iNbUrls;
-	
-	myData.pTask = cairo_dock_new_task_full (0,  // 1 shot task.
-		(CairoDockGetDataAsyncFunc) _cd_dnd2share_threaded_upload,
-		(CairoDockUpdateSyncFunc) _cd_dnd2share_update_from_result,
+
+	myData.pTask = gldi_task_new_full (0,  // 1 shot task.
+		(GldiGetDataAsyncFunc) _cd_dnd2share_threaded_upload,
+		(GldiUpdateSyncFunc) _cd_dnd2share_update_from_result,
 		(GFreeFunc) _free_shared_memory,
 		pSharedMemory);
-	
-	cairo_dock_launch_task (myData.pTask);
-	
-	// On lance une animation.
-	CD_APPLET_DEMANDS_ATTENTION (myConfig.cIconAnimation, 1e6);  // on l'interrompra nous-memes a la fin de l'upload.
+
+	gldi_task_launch (myData.pTask);
+
+	CD_APPLET_DEMANDS_ATTENTION (myConfig.cIconAnimation, 1e6);  // we'll stop it later, at the end of the upload.
 }
 
 
@@ -444,11 +480,11 @@ void cd_dnd2share_clear_working_directory (void)
 	if (r < 0)
 		cd_warning ("Not able to launch this command: %s", cCommand);
 	g_free (cCommand);
-	
+
 	gchar *cConfFilePath = g_strdup_printf ("%s/%s", myData.cWorkingDirPath, "history.conf");
 	g_file_set_contents (cConfFilePath, "#dnd2share's history\n\n", -1, NULL);
 	g_free (cConfFilePath);
-	
+
 	if (myConfig.bDisplayLastImage)
 	{
 		CD_APPLET_SET_IMAGE_ON_MY_ICON (MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE);
@@ -470,12 +506,12 @@ void cd_dnd2share_set_working_directory_size (guint iNbItems)
 {
 	gchar *cConfFilePath = g_strdup_printf ("%s/%s", myData.cWorkingDirPath, "history.conf");
 	GKeyFile *pKeyFile = cairo_dock_open_key_file (cConfFilePath);
-	if (pKeyFile == NULL)  // pas encore d'historique.
+	if (pKeyFile == NULL)  // no history yet
 	{
 		g_free (cConfFilePath);
 		return ;
 	}
-	
+
 	gsize length = 0;
 	gchar **pGroupList = g_key_file_get_groups (pKeyFile, &length);
 	if (length > iNbItems)
@@ -483,7 +519,7 @@ void cd_dnd2share_set_working_directory_size (guint iNbItems)
 		gchar *cItemName;
 		GString *sPreviewPath = g_string_new ("");
 		guint i;
-		for (i = 0; pGroupList[i] != NULL && i < length - iNbItems; i ++)  // on supprime les n premiers groupes en trop, ainsi que leurs eventuelles prevues.
+		for (i = 0; pGroupList[i] != NULL && i < length - iNbItems; i ++)  // we remove all extras groups and the preview
 		{
 			cItemName = pGroupList[i];
 			g_string_printf (sPreviewPath, "%s/%s", myData.cWorkingDirPath, cItemName);
@@ -493,7 +529,7 @@ void cd_dnd2share_set_working_directory_size (guint iNbItems)
 		cairo_dock_write_keys_to_file (pKeyFile, cConfFilePath);
 		g_string_free (sPreviewPath, TRUE);
 	}
-	
+
 	g_strfreev (pGroupList);
 	g_key_file_free (pKeyFile);
 	g_free (cConfFilePath);
@@ -501,15 +537,15 @@ void cd_dnd2share_set_working_directory_size (guint iNbItems)
 
 void cd_dnd2share_clean_working_directory (void)
 {
-	if (myConfig.iNbItems == 0)  // on ne veut plus d'historique => vidons le repertoire.
+	if (myConfig.iNbItems == 0)  // no more history => clean the working directory.
 	{
 		cd_debug ("DND2SHARE : Pas d'historique -> On efface le contenu de '%s'", myData.cWorkingDirPath);
 		cd_dnd2share_clear_working_directory ();
 	}
 	else
 	{
-		cd_dnd2share_set_working_directory_size (myConfig.iNbItems);  // on efface les items en trop.
-		if (! myConfig.bkeepCopy)  // on veut bien un historique mais sans les sauvegardes locales des images => nettoyons le repertoire.
+		cd_dnd2share_set_working_directory_size (myConfig.iNbItems);  // we remove extras items.
+		if (! myConfig.bkeepCopy)  // we don't want a copy of the images
 		{
 			cd_debug ("DND2SHARE : Pas de copies locales -> On efface les images de '%s'", myData.cWorkingDirPath);
 			cd_dnd2share_clear_copies_in_working_directory ();
@@ -556,7 +592,7 @@ void cd_dnd2share_set_current_url_from_item (CDUploadedItem *pItem)
 	gchar *cURL = cd_dnd2share_get_prefered_url_from_item (pItem);
 	g_free (myData.cLastURL);
 	myData.cLastURL = g_strdup (cURL);
-	
+
 	int i = 0;
 	GList *it;
 	for (it = myData.pUpoadedItems; it != NULL; it = it->next)
@@ -572,30 +608,30 @@ void cd_dnd2share_set_current_url_from_item (CDUploadedItem *pItem)
 void cd_dnd2share_remove_one_item (CDUploadedItem *pItem)
 {
 	g_return_if_fail (pItem != NULL);
-	
-	// On enleve le groupe correspondant dans le fichier de l'historique.
+
+	// we remove the corresponding group in the history file
 	gchar *cConfFilePath = g_strdup_printf ("%s/%s", myData.cWorkingDirPath, "history.conf");
-	if (! g_file_test (cConfFilePath, G_FILE_TEST_EXISTS))  // pas encore d'historique.
+	if (! g_file_test (cConfFilePath, G_FILE_TEST_EXISTS))  // no history yet.
 		return;
-	
+
 	GKeyFile *pKeyFile = cairo_dock_open_key_file (cConfFilePath);
-	if (pKeyFile == NULL)  // probleme de droit ?
+	if (pKeyFile == NULL)  // right problem?
 	{
 		cd_warning ("Couldn't remove this item from history.");
 		return ;
 	}
-	
+
 	g_key_file_remove_group (pKeyFile, pItem->cItemName, NULL);
 	cairo_dock_write_keys_to_file (pKeyFile, cConfFilePath);
 	g_key_file_free (pKeyFile);
 	g_free (cConfFilePath);
-	
-	// On efface sa copie de sauvegarde.
+
+	// we remove the local copy.
 	gchar *cPreviewPath = g_strdup_printf ("%s/%s", myData.cWorkingDirPath, pItem->cItemName);
 	g_remove (cPreviewPath);
 	g_free (cPreviewPath);
-	
-	// Si c'est l'item courant, on pointe vers le suivant.
+
+	// If it's the current item, switch to the next one.
 	if (myData.pUpoadedItems && myData.pUpoadedItems->data == pItem)
 	{
 		g_free (myData.cLastURL);
@@ -608,8 +644,8 @@ void cd_dnd2share_remove_one_item (CDUploadedItem *pItem)
 			myData.cLastURL = g_strdup (cURL);
 		}
 	}
-	
-	// On enleve l'item de la liste.
+
+	// We remove the item from the list
 	myData.pUpoadedItems = g_list_remove (myData.pUpoadedItems, pItem);
 	cd_dnd2share_free_uploaded_item (pItem);
 }
@@ -620,12 +656,12 @@ void cd_dnd2share_register_new_backend (CDFileType iFileType, const gchar *cSite
 	int iNumSite = myData.iNbSitesForType[iFileType];
 	CDSiteBackend *pNewBackend = &myData.backends[iFileType][iNumSite];
 	myData.iNbSitesForType[iFileType] ++;
-	
+
 	pNewBackend->cSiteName = cSiteName;
-	pNewBackend->iNbUrls = iNbUrls + 1;  // +1 pour la tiny-url.
-	pNewBackend->cUrlLabels = g_new0 (gchar *, pNewBackend->iNbUrls+1);  // +1 pour le NULL final.
-	memcpy (pNewBackend->cUrlLabels, cUrlLabels, iNbUrls * sizeof (gchar*));  // on prend les N labels fournis par le backend.
-	pNewBackend->cUrlLabels[iNbUrls] = D_("Tiny URL");  // on rajoute le tiny-url.
+	pNewBackend->iNbUrls = iNbUrls + 1;  // +1 for tiny-url.
+	pNewBackend->cUrlLabels = g_new0 (gchar *, pNewBackend->iNbUrls+1);  // +1 for end NULL.
+	memcpy (pNewBackend->cUrlLabels, cUrlLabels, iNbUrls * sizeof (gchar*));  // we take N first labels given by the backend.
+	pNewBackend->cUrlLabels[iNbUrls] = D_("Tiny URL");  // + tiny-url.
 	pNewBackend->iPreferedUrlType = iPreferedUrlType;
 	pNewBackend->upload = pUploadFunc;
 }
