@@ -31,9 +31,6 @@
 
 extern int iVanishingPointY;
 
-extern CairoDockSpeparatorType my_iDrawSeparator3D;
-extern double my_fSeparatorColor[4];
-
 extern cairo_surface_t *my_pFlatSeparatorSurface[2];
 
 #define _define_parameters(hi, h0, H, l, r, gamma, h, w, dw)\
@@ -51,7 +48,7 @@ static void cd_rendering_calculate_max_dock_size_3D_plane (CairoDock *pDock)
 	//pDock->iMaxDockHeight = (int) ((1 + myIconsParam.fAmplitude) * pDock->iMaxIconHeight + myIconsParam.fReflectSize * pDock->container.fRatio) + myIconsParam.iLabelSize + myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin;
 	
 	_define_parameters (hi, h0, H, l, r, gamma, h, w, dw);
-	double h0max = (1 + myIconsParam.fAmplitude) * pDock->iMaxIconHeight * pDock->container.fRatio + MAX ((pDock->container.bIsHorizontal || !myIconsParam.bTextAlwaysHorizontal ? myIconsParam.iLabelSize : 0), myDocksParam.iFrameMargin + myDocksParam.iDockLineWidth);
+	double h0max = (1 + myIconsParam.fAmplitude) * pDock->iMaxIconHeight * pDock->container.fRatio + MAX ((pDock->container.bIsHorizontal ? myIconsParam.iLabelSize : 0), myDocksParam.iFrameMargin + myDocksParam.iDockLineWidth);
 	pDock->iMaxDockHeight = (int) (hi + h0max + l);
 	
 	// 1ere estimation.
@@ -76,22 +73,26 @@ static void cd_rendering_calculate_max_dock_size_3D_plane (CairoDock *pDock)
 	double g = (-b + sqrt (b * b - 4 * a * c)) / 2  / a;
 	cd_debug ("gamma : %f (=) %f", gamma, g);*/
 	
+	int iMaxDockWidth = ceil (cairo_dock_calculate_max_dock_width (pDock, pDock->fFlatDockWidth, 1., 2 * dw));  // on pourra optimiser, ce qui nous interesse ici c'est les fXMin/fXMax.
+	pDock->iMaxDockWidth = iMaxDockWidth;
+	pDock->iOffsetForExtend = 0;
 	double Ws = cairo_dock_get_max_authorized_dock_width (pDock);
-	if (cairo_dock_is_extended_dock (pDock) && w + 2 * dw < Ws)  // alors on etend.
+	///if (cairo_dock_is_extended_dock (pDock) && w + 2 * dw < Ws)  // alors on etend.
+	if (pDock->iRefCount == 0)
 	{
-		double extra = Ws - w;
-		pDock->iMaxDockWidth = ceil (cairo_dock_calculate_max_dock_width (pDock, pDock->fFlatDockWidth, 1., extra));  // on pourra optimiser, ce qui nous interesse ici c'est les fXMin/fXMax.
-		double W = Ws - 2 * (r + (l+(r==0)*2)*sqrt(1+gamma*gamma));
-		double a = H + hi;
-		double b = H + hi + h0 - W / 2;
-		double c = - W / 2;
-		gamma = (-b + sqrt (b * b - 4 * a * c)) / 2  / a;
-		//g_print ("mode etendu : pDock->iMaxDockWidth : %d, gamma = %f\n", pDock->iMaxDockWidth, gamma);
-		h = hi + h0 / (1 + gamma);
-	}
-	else  // rien d'autre a faire
-	{
-		pDock->iMaxDockWidth = ceil (cairo_dock_calculate_max_dock_width (pDock, pDock->fFlatDockWidth, 1., 2 * dw));  // on pourra optimiser, ce qui nous interesse ici c'est les fXMin/fXMax.
+		if (pDock->iMaxDockWidth < Ws)  // alors on etend.
+		{
+			pDock->iOffsetForExtend = (Ws - pDock->iMaxDockWidth) / 2;
+			double extra = Ws - w;
+			pDock->iMaxDockWidth = ceil (cairo_dock_calculate_max_dock_width (pDock, pDock->fFlatDockWidth, 1., extra));  // on pourra optimiser, ce qui nous interesse ici c'est les fXMin/fXMax.
+			double W = Ws - 2 * (r + (l+(r==0)*2)*sqrt(1+gamma*gamma));
+			double a = H + hi;
+			double b = H + hi + h0 - W / 2;
+			double c = - W / 2;
+			gamma = (-b + sqrt (b * b - 4 * a * c)) / 2  / a;
+			//g_print ("mode etendu : pDock->iMaxDockWidth : %d, gamma = %f\n", pDock->iMaxDockWidth, gamma);
+			h = hi + h0 / (1 + gamma);
+		}
 	}
 	pDock->iDecorationsHeight = h;
 	//g_print ("h : %.2f -> %d\n", h, pDock->iDecorationsHeight);
@@ -107,28 +108,23 @@ static void cd_rendering_calculate_max_dock_size_3D_plane (CairoDock *pDock)
 	//cairo_dock_calculate_extra_width_for_trapeze (pDock->iDecorationsHeight, fInclination, myDocksParam.iDockRadius, myDocksParam.iDockLineWidth);
 	
 	// on charge les separateurs plat.
-	//g_print ("%d / %d\n", my_iDrawSeparator3D, myIconsParam.iSeparatorType);
-	if (my_iDrawSeparator3D != myIconsParam.iSeparatorType || my_fSeparatorColor[0] != myIconsParam.fSeparatorColor[0] || my_fSeparatorColor[1] != myIconsParam.fSeparatorColor[1] || my_fSeparatorColor[2] != myIconsParam.fSeparatorColor[2] || my_fSeparatorColor[3] != myIconsParam.fSeparatorColor[3])
+	//g_print ("%d / %d\n", myIconsParam.iSeparatorType, myIconsParam.iSeparatorType);
+	if (myIconsParam.iSeparatorType == CAIRO_DOCK_FLAT_SEPARATOR)
 	{
-		my_iDrawSeparator3D = myIconsParam.iSeparatorType;
-		memcpy (my_fSeparatorColor, myIconsParam.fSeparatorColor, 4*sizeof(double));
-		if (myIconsParam.iSeparatorType == CAIRO_DOCK_FLAT_SEPARATOR)
-		{
-			cd_rendering_load_flat_separator (CAIRO_CONTAINER (g_pMainDock));
-		}
+		cd_rendering_load_flat_separator (CAIRO_CONTAINER (g_pMainDock));
 	}
 	
 	pDock->iMinDockWidth = MAX (1, pDock->fFlatDockWidth);  // fFlatDockWidth peut etre meme negatif avec un dock vide.
 	
-	pDock->iActiveWidth = pDock->iMaxDockWidth;
+	pDock->iActiveWidth = iMaxDockWidth;
 	pDock->iActiveHeight = pDock->iMaxDockHeight;
-	if (! pDock->container.bIsHorizontal && myIconsParam.bTextAlwaysHorizontal)
+	if (! pDock->container.bIsHorizontal)
 		pDock->iMaxDockHeight += 8*myIconsParam.iLabelSize;  // vertical dock, add some padding to draw the labels.	
 }
 
-static void cd_rendering_calculate_construction_parameters_3D_plane (Icon *icon, int iWidth, int iHeight, int iMaxDockWidth, double fReflectionOffsetY)
+static void cd_rendering_calculate_construction_parameters_3D_plane (Icon *icon, double fOffsetX, double fReflectionOffsetY)
 {
-	icon->fDrawX = icon->fX;
+	icon->fDrawX = icon->fX + fOffsetX;
 	icon->fDrawY = icon->fY + fReflectionOffsetY;
 	icon->fWidthFactor = 1.;
 	icon->fHeightFactor = 1.;
@@ -189,7 +185,7 @@ static void cd_rendering_make_3D_separator (Icon *icon, cairo_t *pCairoContext,
 	cairo_rel_line_to (pCairoContext, - fBigWidth, 0);
 	cairo_rel_line_to (pCairoContext, - fDeltaXLeft, - fHeight);
 	
-	if (my_iDrawSeparator3D == CAIRO_DOCK_FLAT_SEPARATOR)
+	if (myIconsParam.iSeparatorType == CAIRO_DOCK_FLAT_SEPARATOR)
 	{
 		cairo_clip (pCairoContext);
 		cairo_translate (pCairoContext, MIN (0, (fHeight + hi) * fLeftInclination), 0);
@@ -252,9 +248,9 @@ static void cd_rendering_draw_3D_separator (Icon *icon, cairo_t *pCairoContext,
 			cairo_scale (pCairoContext, 1., -1.);
 		}
 	}
-	cd_rendering_make_3D_separator (icon, pCairoContext, pDock, (my_iDrawSeparator3D == CAIRO_DOCK_PHYSICAL_SEPARATOR), bBackGround);
+	cd_rendering_make_3D_separator (icon, pCairoContext, pDock, (myIconsParam.iSeparatorType == CAIRO_DOCK_PHYSICAL_SEPARATOR), bBackGround);
 	
-	if (my_iDrawSeparator3D == CAIRO_DOCK_PHYSICAL_SEPARATOR)
+	if (myIconsParam.iSeparatorType == CAIRO_DOCK_PHYSICAL_SEPARATOR)
 	{
 		cairo_set_operator (pCairoContext, CAIRO_OPERATOR_DEST_OUT);
 		cairo_set_source_rgba (pCairoContext, 0.0, 0.0, 0.0, 1.0);
@@ -266,7 +262,10 @@ static void cd_rendering_draw_3D_separator (Icon *icon, cairo_t *pCairoContext,
 			
 			cairo_set_operator (pCairoContext, CAIRO_OPERATOR_OVER);
 			cairo_set_line_width (pCairoContext, myDocksParam.iDockLineWidth);
-			cairo_set_source_rgba (pCairoContext, myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
+			if (myDocksParam.bUseDefaultColors)
+				gldi_style_colors_set_line_color (pCairoContext);
+			else
+				gldi_color_set_cairo (pCairoContext, &myDocksParam.fLineColor);
 			cairo_stroke (pCairoContext);
 		}
 	}
@@ -311,6 +310,7 @@ static void cd_rendering_render_3D_plane (cairo_t *pCairoContext, CairoDock *pDo
 		h = pDock->iDecorationsHeight;
 		Icon *pFirstIcon = cairo_dock_get_first_icon (pDock->icons);
 		dx = (pFirstIcon != NULL ? pFirstIcon->fX - 0*myDocksParam.iFrameMargin : r);
+		dx += (pDock->iOffsetForExtend * (pDock->fAlign - .5) * 2);
 	}
 	
 	int sens;
@@ -338,7 +338,10 @@ static void cd_rendering_render_3D_plane (cairo_t *pCairoContext, CairoDock *pDo
 	if (l > 0)
 	{
 		cairo_set_line_width (pCairoContext, l);
-		cairo_set_source_rgba (pCairoContext, myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
+		if (myDocksParam.bUseDefaultColors)
+			gldi_style_colors_set_line_color (pCairoContext);
+		else
+			gldi_color_set_cairo (pCairoContext, &myDocksParam.fLineColor);
 		cairo_stroke (pCairoContext);
 	}
 	else
@@ -351,7 +354,7 @@ static void cd_rendering_render_3D_plane (cairo_t *pCairoContext, CairoDock *pDo
 	
 	//\____________________ On dessine la ficelle qui les joint.
 	if (myIconsParam.iStringLineWidth > 0)
-		cairo_dock_draw_string (pCairoContext, pDock, myIconsParam.iStringLineWidth, FALSE, (my_iDrawSeparator3D == CAIRO_DOCK_FLAT_SEPARATOR || my_iDrawSeparator3D == CAIRO_DOCK_PHYSICAL_SEPARATOR));
+		cairo_dock_draw_string (pCairoContext, pDock, myIconsParam.iStringLineWidth, FALSE, (myIconsParam.iSeparatorType == CAIRO_DOCK_FLAT_SEPARATOR || myIconsParam.iSeparatorType == CAIRO_DOCK_PHYSICAL_SEPARATOR));
 	
 	//\____________________ On dessine les icones et les etiquettes, en tenant compte de l'ordre pour dessiner celles en arriere-plan avant celles en avant-plan.
 	GList *pFirstDrawnElement = cairo_dock_get_first_drawn_element_linear (pDock->icons);
@@ -362,7 +365,7 @@ static void cd_rendering_render_3D_plane (cairo_t *pCairoContext, CairoDock *pDo
 	
 	Icon *icon;
 	GList *ic = pFirstDrawnElement;
-	if (my_iDrawSeparator3D == CAIRO_DOCK_FLAT_SEPARATOR || my_iDrawSeparator3D == CAIRO_DOCK_PHYSICAL_SEPARATOR)
+	if (myIconsParam.iSeparatorType == CAIRO_DOCK_FLAT_SEPARATOR || myIconsParam.iSeparatorType == CAIRO_DOCK_PHYSICAL_SEPARATOR)
 	{
 		cairo_set_line_cap (pCairoContext, CAIRO_LINE_CAP_SQUARE);
 		do
@@ -393,7 +396,7 @@ static void cd_rendering_render_3D_plane (cairo_t *pCairoContext, CairoDock *pDo
 			ic = cairo_dock_get_next_element (ic, pDock->icons);
 		} while (ic != pFirstDrawnElement);
 		
-		if (my_iDrawSeparator3D == CAIRO_DOCK_PHYSICAL_SEPARATOR)
+		if (myIconsParam.iSeparatorType == CAIRO_DOCK_PHYSICAL_SEPARATOR)
 		{
 			do
 			{
@@ -582,13 +585,15 @@ static void cd_rendering_render_optimized_3D_plane (cairo_t *pCairoContext, Cair
 	
 	//\____________________ On dessine la partie du cadre qui va bien.
 	cairo_new_path (pCairoContext);
-	
+	cairo_set_line_width (pCairoContext, fLineWidth);
+	if (myDocksParam.bUseDefaultColors)
+		gldi_style_colors_set_line_color (pCairoContext);
+	else
+		gldi_color_set_cairo (pCairoContext, &myDocksParam.fLineColor);
 	if (pDock->container.bIsHorizontal)
 	{
-		cairo_set_line_width (pCairoContext, fLineWidth);
 		cairo_move_to (pCairoContext, fDockOffsetX, fDockOffsetY - 0.5*fLineWidth);
 		cairo_rel_line_to (pCairoContext, pArea->width, 0);
-		cairo_set_source_rgba (pCairoContext, myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
 		cairo_stroke (pCairoContext);
 		
 		cairo_new_path (pCairoContext);
@@ -599,16 +604,12 @@ static void cd_rendering_render_optimized_3D_plane (cairo_t *pCairoContext, Cair
 	{
 		cairo_move_to (pCairoContext, fDockOffsetX - .5*fLineWidth, fDockOffsetY);
 		cairo_rel_line_to (pCairoContext, 0, pArea->height);
-		cairo_set_line_width (pCairoContext, fLineWidth);
-		cairo_set_source_rgba (pCairoContext, myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
 		cairo_stroke (pCairoContext);
 		
 		cairo_new_path (pCairoContext);
 		cairo_move_to (pCairoContext, (pDock->container.bDirectionUp ? iHeight - fLineWidth / 2 : pDock->iDecorationsHeight + 1.5 * fLineWidth), fDockOffsetY);
 		cairo_rel_line_to (pCairoContext, 0, pArea->height);
 	}
-	cairo_set_line_width (pCairoContext, fLineWidth);
-	cairo_set_source_rgba (pCairoContext, myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
 	cairo_stroke (pCairoContext);
 	
 	cairo_restore (pCairoContext);
@@ -623,7 +624,7 @@ static void cd_rendering_render_optimized_3D_plane (cairo_t *pCairoContext, Cair
 		Icon *icon;
 		GList *ic = pFirstDrawnElement;
 		
-		if (my_iDrawSeparator3D == CAIRO_DOCK_FLAT_SEPARATOR || my_iDrawSeparator3D == CAIRO_DOCK_PHYSICAL_SEPARATOR)
+		if (myIconsParam.iSeparatorType == CAIRO_DOCK_FLAT_SEPARATOR || myIconsParam.iSeparatorType == CAIRO_DOCK_PHYSICAL_SEPARATOR)
 		{
 			cairo_set_line_cap (pCairoContext, CAIRO_LINE_CAP_SQUARE);
 			do
@@ -632,7 +633,7 @@ static void cd_rendering_render_optimized_3D_plane (cairo_t *pCairoContext, Cair
 				
 				if (CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (icon) && icon->cFileName == NULL)
 				{
-					if (_cd_separator_is_impacted (icon, pDock, fXMin, fXMax, TRUE, (my_iDrawSeparator3D == CAIRO_DOCK_PHYSICAL_SEPARATOR)))
+					if (_cd_separator_is_impacted (icon, pDock, fXMin, fXMax, TRUE, (myIconsParam.iSeparatorType == CAIRO_DOCK_PHYSICAL_SEPARATOR)))
 					{
 						cairo_save (pCairoContext);
 						cd_rendering_draw_3D_separator (icon, pCairoContext, pDock, pDock->container.bIsHorizontal, TRUE);
@@ -666,7 +667,7 @@ static void cd_rendering_render_optimized_3D_plane (cairo_t *pCairoContext, Cair
 				ic = cairo_dock_get_next_element (ic, pDock->icons);
 			} while (ic != pFirstDrawnElement);
 			
-			if (my_iDrawSeparator3D == CAIRO_DOCK_PHYSICAL_SEPARATOR)
+			if (myIconsParam.iSeparatorType == CAIRO_DOCK_PHYSICAL_SEPARATOR)
 			{
 				do
 				{
@@ -674,7 +675,7 @@ static void cd_rendering_render_optimized_3D_plane (cairo_t *pCairoContext, Cair
 					
 					if (CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (icon) && icon->cFileName == NULL)
 					{
-						if (_cd_separator_is_impacted (icon, pDock, fXMin, fXMax, FALSE, (my_iDrawSeparator3D == CAIRO_DOCK_PHYSICAL_SEPARATOR)))
+						if (_cd_separator_is_impacted (icon, pDock, fXMin, fXMax, FALSE, (myIconsParam.iSeparatorType == CAIRO_DOCK_PHYSICAL_SEPARATOR)))
 						{
 							cairo_save (pCairoContext);
 							cd_rendering_draw_3D_separator (icon, pCairoContext, pDock, pDock->container.bIsHorizontal, FALSE);
@@ -718,12 +719,13 @@ static Icon *cd_rendering_calculate_icons_3D_plane (CairoDock *pDock)
 	
 	//\____________________ On calcule les position/etirements/alpha des icones.
 	double fReflectionOffsetY = (pDock->container.bDirectionUp ? -1 : 1) * /**myIconsParam.fReflectSize*/pDock->iIconSize * myIconsParam.fReflectHeightRatio * pDock->container.fRatio;
+	double offsetx = pDock->iOffsetForExtend * (pDock->fAlign - .5) * 2;
 	Icon* icon;
 	GList* ic;
 	for (ic = pDock->icons; ic != NULL; ic = ic->next)
 	{
 		icon = ic->data;
-		cd_rendering_calculate_construction_parameters_3D_plane (icon, pDock->container.iWidth, pDock->container.iHeight, pDock->iMaxDockWidth, fReflectionOffsetY);
+		cd_rendering_calculate_construction_parameters_3D_plane (icon, offsetx, fReflectionOffsetY);
 	}
 	
 	cairo_dock_check_if_mouse_inside_linear (pDock);
@@ -767,6 +769,7 @@ static void cd_rendering_render_3D_plane_opengl (CairoDock *pDock)
 		h = pDock->iDecorationsHeight;
 		Icon *pFirstIcon = cairo_dock_get_first_icon (pDock->icons);
 		dx = (pFirstIcon != NULL ? pFirstIcon->fX - myDocksParam.iFrameMargin : r);
+		dx += (pDock->iOffsetForExtend * (pDock->fAlign - .5) * 2);
 	}
 	
 	//\_____________ On genere les coordonnees du contour.
@@ -788,7 +791,10 @@ static void cd_rendering_render_3D_plane_opengl (CairoDock *pDock)
 	if (l != 0)
 	{
 		glLineWidth (l);
-		glColor4f (myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
+		if (myDocksParam.bUseDefaultColors)
+			gldi_style_colors_set_line_color (NULL);
+		else
+			gldi_color_set_opengl (&myDocksParam.fLineColor);
 		_cairo_dock_set_blend_alpha ();
 		cairo_dock_stroke_gl_path (pFramePath, TRUE);
 	}
@@ -796,7 +802,7 @@ static void cd_rendering_render_3D_plane_opengl (CairoDock *pDock)
 	
 	//\____________________ On dessine la ficelle qui les joint.
 	if (myIconsParam.iStringLineWidth > 0)
-		cairo_dock_draw_string_opengl (pDock, myIconsParam.iStringLineWidth, FALSE, (my_iDrawSeparator3D == CAIRO_DOCK_FLAT_SEPARATOR || my_iDrawSeparator3D == CAIRO_DOCK_PHYSICAL_SEPARATOR));
+		cairo_dock_draw_string_opengl (pDock, myIconsParam.iStringLineWidth, FALSE, (myIconsParam.iSeparatorType == CAIRO_DOCK_FLAT_SEPARATOR || myIconsParam.iSeparatorType == CAIRO_DOCK_PHYSICAL_SEPARATOR));
 	
 	//\____________________ On dessine les icones et les etiquettes, en tenant compte de l'ordre pour dessiner celles en arriere-plan avant celles en avant-plan.
 	GList *pFirstDrawnElement = cairo_dock_get_first_drawn_element_linear (pDock->icons);
@@ -808,7 +814,7 @@ static void cd_rendering_render_3D_plane_opengl (CairoDock *pDock)
 	GList *ic = pFirstDrawnElement;
 	
 	///glLoadIdentity ();
- 	if (my_iDrawSeparator3D == CAIRO_DOCK_FLAT_SEPARATOR || my_iDrawSeparator3D == CAIRO_DOCK_PHYSICAL_SEPARATOR)
+ 	if (myIconsParam.iSeparatorType == CAIRO_DOCK_FLAT_SEPARATOR || myIconsParam.iSeparatorType == CAIRO_DOCK_PHYSICAL_SEPARATOR)
 	{
 		do
 		{
@@ -817,7 +823,7 @@ static void cd_rendering_render_3D_plane_opengl (CairoDock *pDock)
 			if (icon->cFileName == NULL && CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (icon))
 			{
 				glPushMatrix ();
-				if (my_iDrawSeparator3D == CAIRO_DOCK_FLAT_SEPARATOR)
+				if (myIconsParam.iSeparatorType == CAIRO_DOCK_FLAT_SEPARATOR)
 					cd_rendering_draw_flat_separator_opengl (icon, pDock);
 				else
 					cd_rendering_draw_physical_separator_opengl (icon, pDock, TRUE, NULL, NULL);
@@ -841,7 +847,7 @@ static void cd_rendering_render_3D_plane_opengl (CairoDock *pDock)
 			ic = cairo_dock_get_next_element (ic, pDock->icons);
 		} while (ic != pFirstDrawnElement);
 		
-		if (my_iDrawSeparator3D == CAIRO_DOCK_PHYSICAL_SEPARATOR)
+		if (myIconsParam.iSeparatorType == CAIRO_DOCK_PHYSICAL_SEPARATOR)
 		{
 			do
 			{
