@@ -36,9 +36,6 @@ static double *s_pReferenceCurveX = NULL;
 static double *s_pReferenceCurveY = NULL;
 extern int iVanishingPointY;
 
-extern CairoDockSpeparatorType my_iDrawSeparator3D;
-extern double my_fSeparatorColor[4];
-
 extern gdouble my_fCurveCurvature;
 extern gint my_iCurveAmplitude;
 
@@ -115,7 +112,7 @@ static void cd_rendering_calculate_max_dock_size_curve (CairoDock *pDock)
 	
 	pDock->iDecorationsHeight = myDocksParam.iFrameMargin + my_iCurveAmplitude + .5 * pDock->iMaxIconHeight;  // de bas en haut.
 	
-	pDock->iMaxDockHeight = myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin + my_iCurveAmplitude + (1 + myIconsParam.fAmplitude) * pDock->iMaxIconHeight * pDock->container.fRatio + (pDock->container.bIsHorizontal || !myIconsParam.bTextAlwaysHorizontal ? myIconsParam.iLabelSize : 0);  // de bas en haut.
+	pDock->iMaxDockHeight = myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin + my_iCurveAmplitude + (1 + myIconsParam.fAmplitude) * pDock->iMaxIconHeight * pDock->container.fRatio + (pDock->container.bIsHorizontal ? myIconsParam.iLabelSize : 0);  // de bas en haut.
 	
 	double fRatio = (pDock->iRefCount == 0 && pDock->iVisibility == CAIRO_DOCK_VISI_RESERVE ? 1. : pDock->container.fRatio);  // prevent the dock from resizing itself and all the maximized windows each time an icon is removed/inserted.
 	pDock->iMinDockHeight = myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin + my_iCurveAmplitude + pDock->iMaxIconHeight * fRatio;  // de bas en haut.
@@ -133,34 +130,32 @@ static void cd_rendering_calculate_max_dock_size_curve (CairoDock *pDock)
 	dw += fDeltaTip;
 	//g_print ("dw : %.2f (ratio : %.2f, w : %.2f) -> W = %.2f\n", dw, pDock->container.fRatio, w, w+2*dw);
 	
+	int iMaxDockWidth = ceil (cairo_dock_calculate_max_dock_width (pDock, pDock->fFlatDockWidth, 1., 2 * dw));  // on pourra optimiser, ce qui nous interesse ici c'est les fXMin/fXMax.
+	pDock->iMaxDockWidth = iMaxDockWidth;
 	double Ws = cairo_dock_get_max_authorized_dock_width (pDock);
-	if (cairo_dock_is_extended_dock (pDock) && w + 2 * dw < Ws)  // alors on etend.
+	///if (cairo_dock_is_extended_dock (pDock) && w + 2 * dw < Ws)  // alors on etend.
+	if (pDock->iRefCount == 0)
 	{
-		double extra = Ws - w;
-		pDock->iMaxDockWidth = ceil (cairo_dock_calculate_max_dock_width (pDock, pDock->fFlatDockWidth, 1., extra));  // on pourra optimiser, ce qui nous interesse ici c'est les fXMin/fXMax.
-	}
-	else  // rien d'autre a faire
-	{
-		pDock->iMaxDockWidth = ceil (cairo_dock_calculate_max_dock_width (pDock, pDock->fFlatDockWidth, 1., 2 * dw));  // on pourra optimiser, ce qui nous interesse ici c'est les fXMin/fXMax.
+		if (pDock->iMaxDockWidth < Ws)  // alors on etend.
+		{
+			pDock->iOffsetForExtend = (Ws - pDock->iMaxDockWidth) / 2;
+			double extra = Ws - w;
+			pDock->iMaxDockWidth = ceil (cairo_dock_calculate_max_dock_width (pDock, pDock->fFlatDockWidth, 1., extra));  // on pourra optimiser, ce qui nous interesse ici c'est les fXMin/fXMax.
+		}
 	}
 	
 	pDock->iDecorationsWidth = pDock->iMaxDockWidth - 4 * fDeltaTip;  // 4 car 2*(interieur+exterieur).
 	
-	if (my_iDrawSeparator3D != myIconsParam.iSeparatorType || my_fSeparatorColor[0] != myIconsParam.fSeparatorColor[0] || my_fSeparatorColor[1] != myIconsParam.fSeparatorColor[1] || my_fSeparatorColor[2] != myIconsParam.fSeparatorColor[2] || my_fSeparatorColor[3] != myIconsParam.fSeparatorColor[3])
+	if (myIconsParam.iSeparatorType == CAIRO_DOCK_FLAT_SEPARATOR)
 	{
-		my_iDrawSeparator3D = myIconsParam.iSeparatorType;
-		memcpy (my_fSeparatorColor, myIconsParam.fSeparatorColor, 4*sizeof(double));
-		if (myIconsParam.iSeparatorType == CAIRO_DOCK_FLAT_SEPARATOR)
-		{
-			cd_rendering_load_flat_separator (CAIRO_CONTAINER (g_pMainDock));
-		}
+		cd_rendering_load_flat_separator (CAIRO_CONTAINER (g_pMainDock));
 	}
 	
 	pDock->iMinDockWidth = MAX (1, pDock->fFlatDockWidth);  // fFlatDockWidth peut etre meme negatif avec un dock vide.
 	
-	pDock->iActiveWidth = pDock->iMaxDockWidth;
+	pDock->iActiveWidth = iMaxDockWidth;
 	pDock->iActiveHeight = pDock->iMaxDockHeight;
-	if (! pDock->container.bIsHorizontal && myIconsParam.bTextAlwaysHorizontal)
+	if (! pDock->container.bIsHorizontal)
 		pDock->iMaxDockHeight += 8*myIconsParam.iLabelSize;  // vertical dock, add some padding to draw the labels.	
 }
 
@@ -360,7 +355,7 @@ static void cd_rendering_make_3D_curve_separator (Icon *icon, cairo_t *pCairoCon
 		cairo_rel_line_to (pCairoContext, - fBigWidth, 0);
 		cairo_rel_line_to (pCairoContext, - fDeltaXLeft, - sens * fHeight);
 		
-		if (my_iDrawSeparator3D == CAIRO_DOCK_FLAT_SEPARATOR)
+		if (myIconsParam.iSeparatorType == CAIRO_DOCK_FLAT_SEPARATOR)
 		{
 			if (! pDock->container.bDirectionUp)
 				cairo_scale (pCairoContext, 1, -1);
@@ -382,7 +377,7 @@ static void cd_rendering_make_3D_curve_separator (Icon *icon, cairo_t *pCairoCon
 		cairo_rel_line_to (pCairoContext, 0, - fBigWidth);
 		cairo_rel_line_to (pCairoContext, - sens * fHeight, - fDeltaXLeft);
 		
-		if (my_iDrawSeparator3D == CAIRO_DOCK_FLAT_SEPARATOR)
+		if (myIconsParam.iSeparatorType == CAIRO_DOCK_FLAT_SEPARATOR)
 		{
 			if (! pDock->container.bDirectionUp)
 				cairo_scale (pCairoContext, -1, 1);
@@ -471,9 +466,9 @@ static void cd_rendering_draw_3D_curve_separator_edge (Icon *icon, cairo_t *pCai
 
 static void cd_rendering_draw_3D_curve_separator (Icon *icon, cairo_t *pCairoContext, CairoDock *pDock, gboolean bHorizontal, gboolean bBackGround)
 {
-	cd_rendering_make_3D_curve_separator (icon, pCairoContext, pDock, (my_iDrawSeparator3D == CAIRO_DOCK_PHYSICAL_SEPARATOR), bBackGround);
+	cd_rendering_make_3D_curve_separator (icon, pCairoContext, pDock, (myIconsParam.iSeparatorType == CAIRO_DOCK_PHYSICAL_SEPARATOR), bBackGround);
 	
-	if (my_iDrawSeparator3D == CAIRO_DOCK_PHYSICAL_SEPARATOR)
+	if (myIconsParam.iSeparatorType == CAIRO_DOCK_PHYSICAL_SEPARATOR)
 	{
 		cairo_set_operator (pCairoContext, CAIRO_OPERATOR_DEST_OUT);
 		cairo_set_source_rgba (pCairoContext, 0.0, 0.0, 0.0, 1.0);
@@ -483,7 +478,10 @@ static void cd_rendering_draw_3D_curve_separator (Icon *icon, cairo_t *pCairoCon
 		
 		cairo_set_operator (pCairoContext, CAIRO_OPERATOR_OVER);
 		cairo_set_line_width (pCairoContext, myDocksParam.iDockLineWidth);
-		cairo_set_source_rgba (pCairoContext, myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
+		if (myDocksParam.bUseDefaultColors)
+			gldi_style_colors_set_line_color (pCairoContext);
+		else
+			gldi_color_set_cairo (pCairoContext, &myDocksParam.fLineColor);
 		cairo_stroke (pCairoContext);
 	}
 	else
@@ -507,7 +505,7 @@ static void cairo_dock_draw_curved_frame_horizontal (cairo_t *pCairoContext, dou
 }
 static void cairo_dock_draw_curved_frame_vertical (cairo_t *pCairoContext, double fFrameWidth, double fControlHeight, double fDockOffsetX, double fDockOffsetY, int sens)
 {
-       cairo_move_to (pCairoContext, fDockOffsetY, fDockOffsetX);
+	cairo_move_to (pCairoContext, fDockOffsetY, fDockOffsetX);
 	cairo_rel_curve_to (pCairoContext,
 		-sens * fControlHeight, (1 - my_fCurveCurvature) * fFrameWidth / 2,
 		-sens * fControlHeight, (1 + my_fCurveCurvature) * fFrameWidth / 2,
@@ -544,7 +542,8 @@ static void cd_rendering_render_curve (cairo_t *pCairoContext, CairoDock *pDock)
 	{
 		dw = w * xi / (1 - 2 * xi);
 		Icon *pFirstIcon = cairo_dock_get_first_icon (pDock->icons);
-		dx = (pFirstIcon != NULL ? pFirstIcon->fDrawX - dw : fLineWidth / 2);
+		dx = (pFirstIcon != NULL ? pFirstIcon->fX - dw : fLineWidth / 2);
+		dx += (pDock->iOffsetForExtend * (pDock->fAlign - .5) * 2);
 	}
 	if (pDock->container.bDirectionUp)
 	{
@@ -570,7 +569,10 @@ static void cd_rendering_render_curve (cairo_t *pCairoContext, CairoDock *pDock)
 	if (fLineWidth > 0)
 	{
 		cairo_set_line_width (pCairoContext, fLineWidth);
-		cairo_set_source_rgba (pCairoContext, myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
+		if (myDocksParam.bUseDefaultColors)
+			gldi_style_colors_set_line_color (pCairoContext);
+		else
+			gldi_color_set_cairo (pCairoContext, &myDocksParam.fLineColor);
 		cairo_stroke (pCairoContext);
 	}
 	else
@@ -579,7 +581,7 @@ static void cd_rendering_render_curve (cairo_t *pCairoContext, CairoDock *pDock)
 	
 	//\____________________ On dessine la ficelle qui les joint.
 	if (myIconsParam.iStringLineWidth > 0)
-		cairo_dock_draw_string (pCairoContext, pDock, myIconsParam.iStringLineWidth, FALSE, (my_iDrawSeparator3D == CAIRO_DOCK_FLAT_SEPARATOR || my_iDrawSeparator3D == CAIRO_DOCK_PHYSICAL_SEPARATOR));
+		cairo_dock_draw_string (pCairoContext, pDock, myIconsParam.iStringLineWidth, FALSE, (myIconsParam.iSeparatorType == CAIRO_DOCK_FLAT_SEPARATOR || myIconsParam.iSeparatorType == CAIRO_DOCK_PHYSICAL_SEPARATOR));
 	
 	//\____________________ On dessine les icones et les etiquettes, en tenant compte de l'ordre pour dessiner celles en arriere-plan avant celles en avant-plan.
 	GList *pFirstDrawnElement = cairo_dock_get_first_drawn_element_linear (pDock->icons);
@@ -590,7 +592,7 @@ static void cd_rendering_render_curve (cairo_t *pCairoContext, CairoDock *pDock)
 	Icon *icon;
 	GList *ic = pFirstDrawnElement;
 	
-	if (my_iDrawSeparator3D == CAIRO_DOCK_FLAT_SEPARATOR || my_iDrawSeparator3D == CAIRO_DOCK_PHYSICAL_SEPARATOR)
+	if (myIconsParam.iSeparatorType == CAIRO_DOCK_FLAT_SEPARATOR || myIconsParam.iSeparatorType == CAIRO_DOCK_PHYSICAL_SEPARATOR)
 	{
 		cairo_set_line_cap (pCairoContext, CAIRO_LINE_CAP_BUTT);
 		do
@@ -621,7 +623,7 @@ static void cd_rendering_render_curve (cairo_t *pCairoContext, CairoDock *pDock)
 			ic = cairo_dock_get_next_element (ic, pDock->icons);
 		} while (ic != pFirstDrawnElement);
 		
-		if (my_iDrawSeparator3D == CAIRO_DOCK_PHYSICAL_SEPARATOR)
+		if (myIconsParam.iSeparatorType == CAIRO_DOCK_PHYSICAL_SEPARATOR)
 		{
 			do
 			{
@@ -771,6 +773,7 @@ static void cd_rendering_render_optimized_curve (cairo_t *pCairoContext, CairoDo
 		dw = w * xi / (1 - 2 * xi);
 		Icon *pFirstIcon = cairo_dock_get_first_icon (pDock->icons);
 		dx = (pFirstIcon != NULL ? pFirstIcon->fX - dw : fLineWidth / 2);  // la gauche du cadre suit la 1ere icone.
+		dx += (pDock->iOffsetForExtend * (pDock->fAlign - .5) * 2);
 	}
 	
 	if (pDock->container.bDirectionUp)
@@ -845,7 +848,10 @@ static void cd_rendering_render_optimized_curve (cairo_t *pCairoContext, CairoDo
 	if (fLineWidth > 0)
 	{
 		cairo_set_line_width (pCairoContext, fLineWidth);
-		cairo_set_source_rgba (pCairoContext, myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
+		if (myDocksParam.bUseDefaultColors)
+			gldi_style_colors_set_line_color (pCairoContext);
+		else
+			gldi_color_set_cairo (pCairoContext, &myDocksParam.fLineColor);
 		
 		dy = (pDock->container.bDirectionUp ? pDock->container.iHeight - .5 * fLineWidth : .5 * fLineWidth);
 		
@@ -900,7 +906,7 @@ static void cd_rendering_render_optimized_curve (cairo_t *pCairoContext, CairoDo
 		Icon *icon;
 		GList *ic = pFirstDrawnElement;
 		
-		if (my_iDrawSeparator3D == CAIRO_DOCK_FLAT_SEPARATOR || my_iDrawSeparator3D == CAIRO_DOCK_PHYSICAL_SEPARATOR)
+		if (myIconsParam.iSeparatorType == CAIRO_DOCK_FLAT_SEPARATOR || myIconsParam.iSeparatorType == CAIRO_DOCK_PHYSICAL_SEPARATOR)
 		{
 			cairo_set_line_cap (pCairoContext, CAIRO_LINE_CAP_BUTT);
 			do
@@ -909,7 +915,7 @@ static void cd_rendering_render_optimized_curve (cairo_t *pCairoContext, CairoDo
 				
 				if (CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (icon) && icon->cFileName == NULL)
 				{
-					if (_cd_separator_is_impacted (icon, pDock, fXMin, fXMax, TRUE, (my_iDrawSeparator3D == CAIRO_DOCK_PHYSICAL_SEPARATOR)))
+					if (_cd_separator_is_impacted (icon, pDock, fXMin, fXMax, TRUE, (myIconsParam.iSeparatorType == CAIRO_DOCK_PHYSICAL_SEPARATOR)))
 					{
 						cairo_save (pCairoContext);
 						cd_rendering_draw_3D_curve_separator (icon, pCairoContext, pDock, pDock->container.bIsHorizontal, TRUE);
@@ -942,7 +948,7 @@ static void cd_rendering_render_optimized_curve (cairo_t *pCairoContext, CairoDo
 				ic = cairo_dock_get_next_element (ic, pDock->icons);
 			} while (ic != pFirstDrawnElement);
 			
-			if (my_iDrawSeparator3D == CAIRO_DOCK_PHYSICAL_SEPARATOR)
+			if (myIconsParam.iSeparatorType == CAIRO_DOCK_PHYSICAL_SEPARATOR)
 			{
 				do
 				{
@@ -950,7 +956,7 @@ static void cd_rendering_render_optimized_curve (cairo_t *pCairoContext, CairoDo
 					
 					if (CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (icon) && icon->cFileName == NULL)
 					{
-						if (_cd_separator_is_impacted (icon, pDock, fXMin, fXMax, FALSE, (my_iDrawSeparator3D == CAIRO_DOCK_PHYSICAL_SEPARATOR)))
+						if (_cd_separator_is_impacted (icon, pDock, fXMin, fXMax, FALSE, (myIconsParam.iSeparatorType == CAIRO_DOCK_PHYSICAL_SEPARATOR)))
 						{
 							cairo_save (pCairoContext);
 							cd_rendering_draw_3D_curve_separator (icon, pCairoContext, pDock, pDock->container.bIsHorizontal, FALSE);
@@ -1049,7 +1055,7 @@ Icon *cd_rendering_calculate_icons_curve (CairoDock *pDock)
 		double x = icon->fX;
 		double y = k1*(x-xb)*(x-xc) + k2*(x-xa)*(x-xc) + k3*(x-xa)*(x-xb);
 		
-		icon->fDrawX = icon->fX;
+		icon->fDrawX = icon->fX + (pDock->iOffsetForExtend * (pDock->fAlign - .5) * 2);
 		icon->fDrawY = icon->fY + sens * y;
 		//g_print ("y : %.2f -> fDrawY = %.2f\n", y, icon->fDrawY);
 		icon->fWidthFactor = 1.;
@@ -1108,7 +1114,8 @@ static void cd_rendering_render_curve_opengl (CairoDock *pDock)
 	else
 	{
 		Icon *pFirstIcon = cairo_dock_get_first_icon (pDock->icons);
-		dx = (pFirstIcon != NULL ? pFirstIcon->fDrawX - dw : fLineWidth / 2);
+		dx = (pFirstIcon != NULL ? pFirstIcon->fX - dw : fLineWidth / 2);
+		dx += (pDock->iOffsetForExtend * (pDock->fAlign - .5) * 2);
 	}
 	
 	double fFrameHeight = pDock->iDecorationsHeight + fLineWidth;
@@ -1125,7 +1132,7 @@ static void cd_rendering_render_curve_opengl (CairoDock *pDock)
 	glColorMask (FALSE, FALSE, FALSE, FALSE);  // desactive l'ecriture dans toutes les composantes du Tampon Chromatique.
 	
 	//\_____________ On remplit avec le fond.
-	double fEpsilon = (my_iDrawSeparator3D == CAIRO_DOCK_PHYSICAL_SEPARATOR ? 2. : 0);  // erreur d'arrondi quand tu nous tiens.
+	double fEpsilon = (myIconsParam.iSeparatorType == CAIRO_DOCK_PHYSICAL_SEPARATOR ? 2. : 0);  // erreur d'arrondi quand tu nous tiens.
 	glPushMatrix ();
 	cairo_dock_set_container_orientation_opengl (CAIRO_CONTAINER (pDock));
 	glTranslatef (dx + (w+2*dw)/2,
@@ -1154,7 +1161,10 @@ static void cd_rendering_render_curve_opengl (CairoDock *pDock)
 	if (fLineWidth > 0)
 	{
 		glLineWidth (fLineWidth);
-		glColor4f (myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
+		if (myDocksParam.bUseDefaultColors)
+			gldi_style_colors_set_line_color (NULL);
+		else
+			gldi_color_set_opengl (&myDocksParam.fLineColor);
 		_cairo_dock_set_blend_alpha ();
 		cairo_dock_stroke_gl_path (pFramePath, TRUE);
 	}
@@ -1162,7 +1172,7 @@ static void cd_rendering_render_curve_opengl (CairoDock *pDock)
 	
 	//\____________________ On dessine la ficelle qui les joint.
 	if (myIconsParam.iStringLineWidth > 0)
-		cairo_dock_draw_string_opengl (pDock, myIconsParam.iStringLineWidth, FALSE, (my_iDrawSeparator3D == CAIRO_DOCK_FLAT_SEPARATOR || my_iDrawSeparator3D == CAIRO_DOCK_PHYSICAL_SEPARATOR));
+		cairo_dock_draw_string_opengl (pDock, myIconsParam.iStringLineWidth, FALSE, (myIconsParam.iSeparatorType == CAIRO_DOCK_FLAT_SEPARATOR || myIconsParam.iSeparatorType == CAIRO_DOCK_PHYSICAL_SEPARATOR));
 	
 	//\____________________ On dessine les icones et les etiquettes, en tenant compte de l'ordre pour dessiner celles en arriere-plan avant celles en avant-plan.
 	GList *pFirstDrawnElement = cairo_dock_get_first_drawn_element_linear (pDock->icons);
@@ -1173,7 +1183,7 @@ static void cd_rendering_render_curve_opengl (CairoDock *pDock)
 	Icon *icon;
 	GList *ic = pFirstDrawnElement;
 	
-	if (my_iDrawSeparator3D == CAIRO_DOCK_FLAT_SEPARATOR || my_iDrawSeparator3D == CAIRO_DOCK_PHYSICAL_SEPARATOR)
+	if (myIconsParam.iSeparatorType == CAIRO_DOCK_FLAT_SEPARATOR || myIconsParam.iSeparatorType == CAIRO_DOCK_PHYSICAL_SEPARATOR)
 	{
 		do
 		{
@@ -1186,7 +1196,7 @@ static void cd_rendering_render_curve_opengl (CairoDock *pDock)
 				glStencilOp (GL_KEEP, GL_KEEP, GL_KEEP);
 				
 				glPushMatrix ();
-				if (my_iDrawSeparator3D == CAIRO_DOCK_FLAT_SEPARATOR)
+				if (myIconsParam.iSeparatorType == CAIRO_DOCK_FLAT_SEPARATOR)
 					cd_rendering_draw_flat_separator_opengl (icon, pDock);
 				else
 					cd_rendering_draw_physical_separator_opengl (icon, pDock, TRUE, (ic->prev ? ic->prev->data : NULL), (ic->next ? ic->next->data : NULL));
@@ -1212,7 +1222,7 @@ static void cd_rendering_render_curve_opengl (CairoDock *pDock)
 			ic = cairo_dock_get_next_element (ic, pDock->icons);
 		} while (ic != pFirstDrawnElement);
 		
-		if (my_iDrawSeparator3D == CAIRO_DOCK_PHYSICAL_SEPARATOR)
+		if (myIconsParam.iSeparatorType == CAIRO_DOCK_PHYSICAL_SEPARATOR)
 		{
 			do
 			{
