@@ -51,11 +51,11 @@ static void cd_rendering_calculate_max_dock_size_rainbow (CairoDock *pDock)
 	int iNbIcons = g_list_length (pDock->icons);
 	int iMinRadius = MIN (my_iRainbowNbIconsMin, iNbIcons) * iMaxIconWidth * fMaxScale / fCone;
 	
-	int iNbRows = (int) ceil (sqrt (2 * iNbIcons / fCone / fMaxScale) + .5);  /// approximation, utiliser la formule complete...
+	int iNbRows = (int) ceil (sqrt (2 * iNbIcons / fCone / fMaxScale) + .5);  /// approximation, use complete formula
 	
 	pDock->iMaxDockHeight = iNbRows * (pDock->iMaxIconHeight + my_iSpaceBetweenRows) * fMaxScale + iMinRadius;
 	pDock->iMaxDockWidth = 2 * (pDock->iMaxDockHeight * cos (my_fRainbowConeOffset));
-	cd_debug ("iNbRows : %d => %dx%d (iMaxIconHeight = %d ; iMinRadius = %d ; fMaxScale = %.2f)\n", iNbRows, pDock->iMaxDockWidth, pDock->iMaxDockHeight, pDock->iMaxIconHeight, iMinRadius, fMaxScale);
+	cd_debug ("iNbRows : %d => %dx%d (iMaxIconHeight = %d ; iMinRadius = %d ; fMaxScale = %.2f)", iNbRows, pDock->iMaxDockWidth, pDock->iMaxDockHeight, pDock->iMaxIconHeight, iMinRadius, fMaxScale);
 	
 	pDock->iDecorationsWidth = 0;
 	pDock->iDecorationsHeight = 0;
@@ -87,7 +87,7 @@ static void cd_rendering_render_rainbow (cairo_t *pCairoContext, CairoDock *pDoc
 			cairo_translate (pCairoContext, 0., pDock->container.iHeight);
 			cairo_scale (pCairoContext, 1., -1.);
 		}
-		//\____________________ On fait un clip du cone.
+		//\____________________ We do a clip of the cone.
 		cairo_move_to (pCairoContext, 0., pDock->container.iHeight * (1 - sin (my_fRainbowConeOffset)));
 		cairo_line_to (pCairoContext, pDock->container.iWidth/2, pDock->container.iHeight);
 		cairo_line_to (pCairoContext, pDock->container.iWidth, pDock->container.iHeight * (1 - sin (my_fRainbowConeOffset)));
@@ -96,7 +96,7 @@ static void cd_rendering_render_rainbow (cairo_t *pCairoContext, CairoDock *pDoc
 		cairo_close_path (pCairoContext);
 		cairo_clip (pCairoContext);
 		
-		//\____________________ On dessine chaque rayure dedans.
+		//\____________________ We draw each scratch in it.
 		cairo_pattern_t *pGradationPattern = cairo_pattern_create_radial (pDock->container.iWidth/2,
 			pDock->container.iHeight,
 			0.,
@@ -115,7 +115,6 @@ static void cd_rendering_render_rainbow (cairo_t *pCairoContext, CairoDock *pDoc
 		
 		GList *pFirstDrawnElement = pDock->icons;
 		GList *ic = pFirstDrawnElement;
-		Icon *pFirstIcon = pFirstDrawnElement->data;
 		double fCurrentRadius=0;
 		Icon *icon;
 		do
@@ -124,7 +123,7 @@ static void cd_rendering_render_rainbow (cairo_t *pCairoContext, CairoDock *pDoc
 			fRadius = icon->fX - (pDock->container.bDirectionUp ? pDock->iMaxIconHeight * fMaxScale : 0);
 			if (fRadius != fCurrentRadius)
 			{
-				if (fCurrentRadius == 0)  // 1er coup.
+				if (fCurrentRadius == 0)  // First hit.
 				{
 					cairo_pattern_add_color_stop_rgba (pGradationPattern,
 						(fRadius - my_iSpaceBetweenRows/2)/ pDock->container.iHeight,
@@ -157,7 +156,7 @@ static void cd_rendering_render_rainbow (cairo_t *pCairoContext, CairoDock *pDoc
 		cairo_restore (pCairoContext);
 	}
 	
-	//\____________________ On dessine le cadre.
+	//\____________________ We draw the frame/border.
 	if (fRadius == 0)
 	{
 		Icon *icon = cairo_dock_get_last_icon (pDock->icons);
@@ -192,9 +191,7 @@ static void cd_rendering_render_rainbow (cairo_t *pCairoContext, CairoDock *pDoc
 		cairo_restore (pCairoContext);
 	}
 	
-	//\____________________ On dessine la ficelle qui les joint.
-	
-	//\____________________ On dessine les icones avec leurs etiquettes.
+	//\____________________ We draw the icons with their labels.
 	///cairo_dock_render_icons_linear (pCairoContext, pDock, fRatio);
 	GList *pFirstDrawnElement = cairo_dock_get_first_drawn_element_linear (pDock->icons);
 	if (pFirstDrawnElement == NULL)
@@ -202,8 +199,6 @@ static void cd_rendering_render_rainbow (cairo_t *pCairoContext, CairoDock *pDoc
 
 	double fDockMagnitude = cairo_dock_calculate_magnitude (pDock->iMagnitudeIndex)/** * pDock->fMagnitudeMax*/;
 	Icon *icon;
-	int iWidth = pDock->container.iWidth;
-	gboolean bIsHorizontal = pDock->container.bIsHorizontal;
 	GList *ic = pFirstDrawnElement;
 	do
 	{
@@ -231,7 +226,7 @@ static double _calculate_wave_offset (int x_abs, int iMaxIconHeight, double fMag
 	int iIconNumber = (x_abs + .5*my_iSpaceBetweenRows) / (iMaxIconHeight + my_iSpaceBetweenRows);
 	
 	int x_cumulated = iIconNumber * (iMaxIconHeight + my_iSpaceBetweenRows);
-	cd_debug (" iIconNumber : %d ; x_cumulated : %d\n", iIconNumber, x_cumulated);
+	cd_debug (" iIconNumber : %d ; x_cumulated : %d", iIconNumber, x_cumulated);
 	double fXMiddle = x_cumulated + iMaxIconHeight / 2;
 	double fPhase = (fXMiddle - x_abs) / myIconsParam.iSinusoidWidth / fRatio * G_PI + G_PI / 2;
 	if (fPhase < 0)
@@ -250,7 +245,7 @@ static double _calculate_wave_offset (int x_abs, int iMaxIconHeight, double fMag
 	{
 		iIconNumber --;
 		x_cumulated = iIconNumber * (iMaxIconHeight + my_iSpaceBetweenRows);
-		//cd_debug ("  %d) x_cumulated = %d\n", iIconNumber, x_cumulated);
+		//cd_debug ("  %d) x_cumulated = %d", iIconNumber, x_cumulated);
 		fXMiddle = x_cumulated + iMaxIconHeight / 2;
 		fPhase = (fXMiddle - x_abs) / myIconsParam.iSinusoidWidth / fRatio * G_PI + G_PI / 2;
 		if (fPhase < 0)
@@ -270,7 +265,7 @@ static double _calculate_wave_offset (int x_abs, int iMaxIconHeight, double fMag
 }
 static double cd_rendering_calculate_wave_position (CairoDock *pDock, double fCurvilignAbscisse, double fMagnitude)
 {
-	cd_debug ("%s (%.2f)\n", __func__, fCurvilignAbscisse);
+	cd_debug ("%s (%.2f)", __func__, fCurvilignAbscisse);
 	
 	if (pDock->icons == NULL || fCurvilignAbscisse <= 0)
 		return 0;
@@ -281,7 +276,7 @@ static double cd_rendering_calculate_wave_position (CairoDock *pDock, double fCu
 	
 	do
 	{
-		//cd_debug ("  x_abs : %.2f\n", x_abs);
+		//cd_debug ("  x_abs : %.2f", x_abs);
 		fWaveOffset = _calculate_wave_offset (x_abs, pDock->iMaxIconHeight, fMagnitude, pDock->fFlatDockWidth, pDock->fFlatDockWidth, 0*pDock->fAlign, pDock->fFoldingFactor, fRatio);
 		
 		fWaveExtrema = fWaveOffset + x_abs;
@@ -294,7 +289,7 @@ static double cd_rendering_calculate_wave_position (CairoDock *pDock, double fCu
 			x_abs = (int) pDock->fFlatDockWidth;
 			break ;
 		}
-		//cd_debug ("  -> fWaveOffset : %.2f, fWaveExtrema : %.2f\n", fWaveOffset, fWaveExtrema);
+		//cd_debug ("  -> fWaveOffset : %.2f, fWaveExtrema : %.2f", fWaveOffset, fWaveExtrema);
 		
 		nb_iter ++;
 	}
@@ -305,20 +300,20 @@ static double cd_rendering_calculate_wave_position (CairoDock *pDock, double fCu
 
 static int cd_rendering_calculate_wave_on_each_lines (int x_abs, int iMaxIconHeight, double fMagnitude, double fFlatDockWidth, int iWidth, double fAlign, double fFoldingFactor, double fRatio, int iNbRows, double *pScales)  // (fScale,fX)
 {
-	if (iNbRows == 0)
+	if (iNbRows <= 0)
 		return 0;
-	cd_debug ("%s (%d, %.2f, %.2f, %d)\n", __func__, x_abs, fMagnitude, fFoldingFactor, iNbRows);
-	if (x_abs < 0 && iWidth > 0)  // ces cas limite sont la pour empecher les icones de retrecir trop rapidement quend on sort par les cotes.
+	cd_debug ("%s (%d, %.2f, %.2f, %d)", __func__, x_abs, fMagnitude, fFoldingFactor, iNbRows);
+	if (x_abs < 0 && iWidth > 0)  // These borderline cases are there to avoid having icons which shrink too fast when we go out from the sides.
 		x_abs = -1;
 	else if (x_abs > fFlatDockWidth && iWidth > 0)
 		x_abs = fFlatDockWidth+1;
 	
-	float x_cumulated = 0, fXMiddle, fDeltaExtremum;
+	float x_cumulated = 0, fXMiddle;
 	double fPhase, fX, fScale = 0.0;
 	int iNumRow, iPointedRow=-1;
 	for (iNumRow = 0; iNumRow < iNbRows; iNumRow ++)
 	{
-		//cd_debug (" ligne %d\n", iNumRow);
+		//cd_debug (" ligne %d", iNumRow);
 		fXMiddle = x_cumulated + .5*iMaxIconHeight;
 		
 		fPhase = (fXMiddle - x_abs) / myIconsParam.iSinusoidWidth / fRatio * G_PI + G_PI / 2;
@@ -328,37 +323,37 @@ static int cd_rendering_calculate_wave_on_each_lines (int x_abs, int iMaxIconHei
 			fPhase = G_PI;
 		fScale = 1 + fMagnitude * myIconsParam.fAmplitude * sin (fPhase);
 		pScales[2*iNumRow] = fScale;
-		//cd_debug ("  fScale : %.2f\n", fScale);
+		//cd_debug ("  fScale : %.2f", fScale);
 		
 		if (iPointedRow != -1)
 		{
 			fX = pScales[2*(iNumRow-1)+1] + (iMaxIconHeight + my_iSpaceBetweenRows) * pScales[2*(iNumRow-1)];
 			fX = fAlign * iWidth + (fX - fAlign * iWidth) * (1. - fFoldingFactor);
 			pScales[2*iNumRow+1] = fX;
-			//cd_debug ("  fX : %.2f (prev : %.2f , %.2f)\n", fX, pScales[2*(iNumRow-1)+1], pScales[2*(iNumRow-1)]);
+			//cd_debug ("  fX : %.2f (prev : %.2f , %.2f)", fX, pScales[2*(iNumRow-1)+1], pScales[2*(iNumRow-1)]);
 		}
 		
-		if (x_cumulated + iMaxIconHeight + .5*my_iSpaceBetweenRows >= x_abs && x_cumulated - .5*my_iSpaceBetweenRows <= x_abs && iPointedRow == -1)  // on a trouve la ligne sur laquelle on pointe.
+		if (x_cumulated + iMaxIconHeight + .5*my_iSpaceBetweenRows >= x_abs && x_cumulated - .5*my_iSpaceBetweenRows <= x_abs && iPointedRow == -1)  // We found the line on which the mouse's pointer is over.
 		{
 			iPointedRow = iNumRow;
 			fX = x_cumulated - 0*(fFlatDockWidth - iWidth) / 2 + (1 - fScale) * (x_abs - x_cumulated + .5*my_iSpaceBetweenRows);
 			fX = fAlign * iWidth + (fX - fAlign * iWidth) * (1. - fFoldingFactor);
-			//cd_debug ("  ligne pointee : %d\n", iPointedRow);
+			//cd_debug ("  ligne pointee : %d", iPointedRow);
 			pScales[2*iNumRow+1] = fX;
-			//cd_debug ("  fX : %.2f\n", fX);
+			//cd_debug ("  fX : %.2f", fX);
 		}
 		
 		x_cumulated += iMaxIconHeight;
 	}
 	
-	if (iPointedRow == -1)  // on est en dehors du disque.
+	if (iPointedRow == -1)  // We are out of the disk.
 	{
 		iPointedRow = iNbRows - 1;
 		
 		fX = x_cumulated - (fFlatDockWidth - iWidth) / 2 + (1 - fScale) * (iMaxIconHeight + .5*my_iSpaceBetweenRows);
 		fX = fAlign * iWidth + (fX - fAlign * iWidth) * (1 - fFoldingFactor);
 		pScales[2*iNumRow+1] = fX;
-		//cd_debug ("  fX : %.2f\n", fX);
+		//cd_debug ("  fX : %.2f", fX);
 	}
 	
 	for (iNumRow = iPointedRow-1; iNumRow >= 0; iNumRow --)
@@ -366,7 +361,7 @@ static int cd_rendering_calculate_wave_on_each_lines (int x_abs, int iMaxIconHei
 		fX = pScales[2*(iNumRow+1)+1] - (iMaxIconHeight + my_iSpaceBetweenRows) * pScales[2*iNumRow];
 		fX = fAlign * iWidth + (fX - fAlign * iWidth) * (1. - fFoldingFactor);
 		pScales[2*iNumRow+1] = fX;
-		//cd_debug ("  fX : %.2f\n", fX);
+		//cd_debug ("  fX : %.2f", fX);
 	}
 	
 	fX = pScales[1];
@@ -383,42 +378,39 @@ static Icon *cd_rendering_calculate_icons_rainbow (CairoDock *pDock)
 	if (pDock->icons == NULL)
 		return NULL;
 	
-	//\____________________ On se place en coordonnees polaires.
+	//\____________________ We are using polar coordinates.
 	double fMaxScale =  1. + my_fRainbowMagnitude * myIconsParam.fAmplitude;
 	int iMaxIconWidth = pDock->iMaxIconHeight + my_iSpaceBetweenIcons;
 	double fCone = G_PI - 2 * my_fRainbowConeOffset;
 	int iNbIcons = g_list_length (pDock->icons);
 	int iMinRadius = MIN (my_iRainbowNbIconsMin, iNbIcons) * iMaxIconWidth * fMaxScale / fCone;
 	double fRatio = pDock->container.fRatio;
-	double w = pDock->container.iWidth;
-	double h = pDock->container.iHeight;
 	double fRadius, fTheta;
-	cd_debug (" mouse : (%d ; %d)\n", pDock->container.iMouseX, pDock->container.iMouseY);
+	cd_debug (" mouse : (%d ; %d)", pDock->container.iMouseX, pDock->container.iMouseY);
 	cd_rendering_get_polar_coords (pDock, &fRadius, &fTheta);
-	cd_debug (" polar : (%.2f ; %.2f)\n", fRadius, fTheta/G_PI*180.);
+	cd_debug (" polar : (%.2f ; %.2f)", fRadius, fTheta/G_PI*180.);
 	
 	double fCurvilignAbscisse = (fTheta > -G_PI/2 && fTheta < G_PI/2 ? MAX (0, fRadius - iMinRadius): 0);
 	
-	//\____________________ On en deduit ou appliquer la vague pour que la crete soit a la position du curseur.
+	//\____________________ We deduce or apply the wave in order to have a "ridge" at the position of the cursor.
 	Icon *pPointedIcon = NULL;
 	double fMagnitude = cairo_dock_calculate_magnitude (pDock->iMagnitudeIndex) * pDock->fMagnitudeMax;
 	int x_abs = (int) round (cd_rendering_calculate_wave_position (pDock, fCurvilignAbscisse, fMagnitude));
-	cd_debug (" => x_abs : %d (fMagnitude:%.2f ; fFoldingFactor:%.2f)\n", x_abs, fMagnitude, pDock->fFoldingFactor);
+	cd_debug (" => x_abs : %d (fMagnitude:%.2f ; fFoldingFactor:%.2f)", x_abs, fMagnitude, pDock->fFoldingFactor);
 	
-	//\_______________ On en deduit l'amplitude de chaque ligne.
-	int iNbRows = round ((pDock->iMaxDockHeight- iMinRadius) / ((pDock->iMaxIconHeight + my_iSpaceBetweenRows) * fMaxScale));
-	cd_debug ("iNbRows : %d\n", iNbRows);
+	//\_______________ We deduce the amplitude for each line.
+	int iNbRows = round ((pDock->iMaxDockHeight - iMinRadius) / ((pDock->iMaxIconHeight + my_iSpaceBetweenRows) * fMaxScale));
+	cd_debug ("iNbRows : %d", iNbRows);
 	double fFlatDockWidth = iNbRows * (pDock->iMaxIconHeight + my_iSpaceBetweenRows) * fMaxScale;
 	double *pScales = g_new0 (double, 2*iNbRows+2);
 	cd_rendering_calculate_wave_on_each_lines (x_abs, pDock->iMaxIconHeight, fMagnitude, fFlatDockWidth, fFlatDockWidth, 0*pDock->fAlign, pDock->fFoldingFactor, fRatio, iNbRows, pScales);
 	
-	//\____________________ On en deduit les position/etirements/alpha des icones.
-	Icon* icon, *prev_icon;
+	//\____________________ We deduce the positions/stretching/alpha of all icons.
+	Icon* icon;
 	GList* ic;
 	
 	GList *pFirstDrawnElement = pDock->icons;
 	ic = pFirstDrawnElement;
-	Icon *pFirstIcon = pFirstDrawnElement->data;
 	
 	int iNbRow = -1, iNbIconsOnRow = 0, iNbInsertedIcons = 0;
 	double fCurrentRadius=0, fNormalRadius=0, fCurrentTheta, fThetaStart=0, fDeltaTheta=0, fCurrentScale=1;
@@ -429,7 +421,7 @@ static Icon *cd_rendering_calculate_icons_rainbow (CairoDock *pDock)
 		if (iNbInsertedIcons == iNbIconsOnRow)
 		{
 			iNbRow ++;
-			if (iNbRow == iNbRows)
+			if (iNbRow >= iNbRows)
 				break ;
 			iNbInsertedIcons = 0;
 			fCurrentRadius = iMinRadius * (1 - pDock->fFoldingFactor) + pScales[2*iNbRow+1];
@@ -438,7 +430,7 @@ static Icon *cd_rendering_calculate_icons_rainbow (CairoDock *pDock)
 			fDeltaTheta = 2 * atan (iMaxIconWidth * fMaxScale / 2 / fNormalRadius);
 			iNbIconsOnRow = (int) (fCone / fDeltaTheta);
 			fThetaStart = - G_PI/2 + my_fRainbowConeOffset + (fCone - iNbIconsOnRow * fDeltaTheta) / 2 + fDeltaTheta / 2;
-			cd_debug ("on passe a la ligne %d (%d icones, fThetaStart = %.2fdeg, fCurrentRadius = %.2f(%.2f), fDeltaTheta = %.2f, fCurrentScale = %.2f)\n", iNbRow, iNbIconsOnRow, fThetaStart/G_PI*180, fCurrentRadius, fNormalRadius, fDeltaTheta/G_PI*180, fCurrentScale);
+			cd_debug ("We go to the line %d (%d icons, fThetaStart = %.2fdeg, fCurrentRadius = %.2f(%.2f), fDeltaTheta = %.2f, fCurrentScale = %.2f)", iNbRow, iNbIconsOnRow, fThetaStart/G_PI*180, fCurrentRadius, fNormalRadius, fDeltaTheta/G_PI*180, fCurrentScale);
 		}
 		
 		icon->fX = fCurrentRadius + (pDock->container.bDirectionUp ? pDock->iMaxIconHeight * fCurrentScale : 0);
@@ -453,7 +445,7 @@ static Icon *cd_rendering_calculate_icons_rainbow (CairoDock *pDock)
 		{
 			icon->bPointed = TRUE;
 			pPointedIcon = icon;
-			cd_debug (" POINTED ICON : %s\n", pPointedIcon->cName);
+			cd_debug (" POINTED ICON : %s", pPointedIcon->cName);
 		}
 		else
 			icon->bPointed = FALSE;
@@ -473,15 +465,13 @@ static Icon *cd_rendering_calculate_icons_rainbow (CairoDock *pDock)
 			icon->fDrawY = icon->fX * sin (fCurrentTheta) - icon->fWidth/2 * fCurrentScale * cos (fCurrentTheta) + pDock->container.iHeight / 2;
 		}*/
 		
-		cd_debug (" %.2fdeg ; (%.2f;%.2f)\n", fCurrentTheta/G_PI*180, icon->fDrawX, icon->fDrawY);
+		cd_debug (" %.2fdeg ; (%.2f;%.2f)", fCurrentTheta/G_PI*180, icon->fDrawX, icon->fDrawY);
 		
 		icon->fScale = fCurrentScale;
 		icon->fAlpha = 1;
 		icon->fWidthFactor = 1.;
 		icon->fHeightFactor = 1.;
 		
-		prev_icon = icon;
-		
 		iNbInsertedIcons ++;
 		
 		ic = cairo_dock_get_next_element (ic, pDock->icons);
@@ -491,9 +481,9 @@ static Icon *cd_rendering_calculate_icons_rainbow (CairoDock *pDock)
 	//g_print ("fRadius : %.2f ; limite : %.2f\n", fRadius, fCurrentRadius + pDock->iMaxIconHeight * fCurrentScale);
 	if (! pDock->container.bInside ||
 		fRadius > fCurrentRadius + pDock->iMaxIconHeight * fCurrentScale + myIconsParam.iLabelSize - (pDock->fFoldingFactor > 0 ? 20 : 0) ||
-		(fTheta < - G_PI/2 + my_fRainbowConeOffset || fTheta > G_PI/2 - my_fRainbowConeOffset) && fRadius > iMinRadius + .5 * pDock->iMaxIconHeight * fMaxScale)
+		((fTheta < - G_PI/2 + my_fRainbowConeOffset || fTheta > G_PI/2 - my_fRainbowConeOffset) && fRadius > iMinRadius + .5 * pDock->iMaxIconHeight * fMaxScale))
 	{
-		cd_debug ("<<< on sort du demi-disque >>>\n");
+		cd_debug ("We go out of the semi-disk");
 		pDock->iMousePositionType = CAIRO_DOCK_MOUSE_OUTSIDE;
 		pDock->bCanDrop = FALSE;
 	}
@@ -511,7 +501,7 @@ static Icon *cd_rendering_calculate_icons_rainbow (CairoDock *pDock)
 static void _generate_cos_sin (double fConeOffset, double fDelta, double *pTabValues)
 {
 	int i, n = (int) ceil ((G_PI/2 - fConeOffset) / fDelta);
-	pTabValues[2*n] = 0.;  // point au milieu.
+	pTabValues[2*n] = 0.;  // point at the middle.
 	pTabValues[2*n+1] = 1.;
 	
 	double fTheta;
@@ -570,11 +560,11 @@ static void cd_rendering_render_rainbow_opengl (CairoDock *pDock)
 	double fRadius=0;
 	if (my_fRainbowColor[3] != 0 && pDock->icons != NULL)
 	{
-		//\____________________ On trace le cadre.
-		//\____________________ On dessine les decorations dedans.
+		//\____________________ We draw frame's borders.
+		//\____________________ We draw decorations in it.
 		glEnable (GL_LINE_SMOOTH);
 		glHint (GL_LINE_SMOOTH_HINT, GL_NICEST);
-		///_cairo_dock_set_blend_alpha ();  // qqch cloche ...
+		///_cairo_dock_set_blend_alpha ();  // strange ...
 		_cairo_dock_set_blend_over ();
 		glEnable(GL_BLEND);
 		
@@ -602,7 +592,6 @@ static void cd_rendering_render_rainbow_opengl (CairoDock *pDock)
 		
 		GList *pFirstDrawnElement = pDock->icons;
 		GList *ic = pFirstDrawnElement;
-		Icon *pFirstIcon = pFirstDrawnElement->data;
 		double fCurrentRadius=0;
 		Icon *icon;
 		do
@@ -643,7 +632,7 @@ static void cd_rendering_render_rainbow_opengl (CairoDock *pDock)
 		glDisable(GL_BLEND);
 	}
 	
-	//\____________________ On dessine le cadre.
+	//\____________________ We draw the frame's borders.
 	if (fRadius == 0)
 	{
 		Icon *icon = cairo_dock_get_last_icon (pDock->icons);
@@ -693,15 +682,13 @@ static void cd_rendering_render_rainbow_opengl (CairoDock *pDock)
 		glPopMatrix ();
 	}
 	
-	//\____________________ On dessine les icones.
+	//\____________________ We draw icons.
 	GList *pFirstDrawnElement = cairo_dock_get_first_drawn_element_linear (pDock->icons);
 	if (pFirstDrawnElement == NULL)
 		return;
 
 	double fDockMagnitude = cairo_dock_calculate_magnitude (pDock->iMagnitudeIndex)/** * pDock->fMagnitudeMax*/;
 	Icon *icon;
-	int iWidth = pDock->container.iWidth;
-	gboolean bIsHorizontal = pDock->container.bIsHorizontal;
 	GList *ic = pFirstDrawnElement;
 	do
 	{
