@@ -32,37 +32,31 @@ CD_APPLET_GET_CONFIG_BEGIN
 	myConfig.cEmblemCapsLock = CD_CONFIG_GET_STRING ("Configuration", "emblem capslock");
 	myConfig.iTransitionDuration = CD_CONFIG_GET_INTEGER ("Configuration", "transition");
 	myConfig.fTextRatio = CD_CONFIG_GET_DOUBLE_WITH_DEFAULT ("Configuration", "text ratio", 1.);
-	CD_CONFIG_GET_COLOR_RVB("Configuration", "text color", myConfig.textDescription.fColorStart);
-	CD_CONFIG_GET_COLOR_RVB("Configuration", "text color", myConfig.textDescription.fColorStop);
 	
-	gchar *cFontDescription = CD_CONFIG_GET_STRING ("Configuration", "font");
-	if (cFontDescription == NULL)
+	gboolean bUseDefaultColors = (CD_CONFIG_GET_INTEGER_WITH_DEFAULT ("Configuration", "style", 1) == 0);
+	gboolean bCustomFont = CD_CONFIG_GET_BOOLEAN_WITH_DEFAULT ("Configuration", "custom font", FALSE);  // false by default
+	if (! bUseDefaultColors && bCustomFont)  // custom font
 	{
-		cFontDescription = g_strdup ("Sans");  // sinon fd est NULL.
+		gchar *cFont = CD_CONFIG_GET_STRING ("Configuration", "font");
+		gldi_text_description_set_font (&myConfig.textDescription, cFont);
 	}
-	PangoFontDescription *fd = pango_font_description_from_string (cFontDescription);
-	myConfig.textDescription.cFont = g_strdup (pango_font_description_get_family (fd));
-	myConfig.textDescription.iWeight = pango_font_description_get_weight (fd);
-	myConfig.textDescription.iStyle = pango_font_description_get_style (fd);
-	if (pango_font_description_get_size (fd) == 0)  // anciens parametres de font.
+	else  // use the default font
 	{
-		int iWeight = g_key_file_get_integer (pKeyFile, "Configuration", "text weight", NULL);
-		myConfig.textDescription.iWeight = cairo_dock_get_pango_weight_from_1_9 (iWeight);
-		myConfig.textDescription.iStyle = PANGO_STYLE_NORMAL;
-		
-		pango_font_description_set_size (fd, 12 * PANGO_SCALE);
-		pango_font_description_set_weight (fd, myConfig.textDescription.iWeight);
-		pango_font_description_set_style (fd, myConfig.textDescription.iStyle);
-		g_free (cFontDescription);
-		cFontDescription = pango_font_description_to_string (fd);
-		g_key_file_set_string (pKeyFile, "Configuration", "font", cFontDescription);
+		gldi_text_description_copy (&myConfig.textDescription, &myStyleParam.textDescription);
 	}
-	pango_font_description_free (fd);
-	g_free (cFontDescription);
+	myConfig.textDescription.bNoDecorations = TRUE;
 	
-	myConfig.textDescription.bOutlined = CD_CONFIG_GET_BOOLEAN ("Configuration", "outlined");
+	if (! bUseDefaultColors)  // custom colors
+	{
+		CD_CONFIG_GET_COLOR ("Configuration", "text color", &myConfig.textDescription.fColorStart);
+		myConfig.textDescription.bOutlined = CD_CONFIG_GET_BOOLEAN ("Configuration", "outlined");
+		myConfig.textDescription.bUseDefaultColors = FALSE;
+	}
+	else  // else, no outline and keep default colors
+		myConfig.textDescription.bUseDefaultColors = TRUE;
 	
 	myConfig.cBackgroundImage = CD_CONFIG_GET_STRING ("Configuration", "bg image");
+	myConfig.iNLetters = CD_CONFIG_GET_INTEGER_WITH_DEFAULT ("Configuration", "nLetters", 3);
 CD_APPLET_GET_CONFIG_END
 
 
@@ -71,7 +65,7 @@ CD_APPLET_RESET_CONFIG_BEGIN
 	g_free (myConfig.cBackgroundImage);
 	g_free (myConfig.cEmblemCapsLock);
 	g_free (myConfig.cEmblemNumLock);
-	g_free (myConfig.textDescription.cFont);
+	gldi_text_description_reset (&myConfig.textDescription);
 	g_free (myConfig.cShortkey);
 CD_APPLET_RESET_CONFIG_END
 
@@ -79,14 +73,18 @@ CD_APPLET_RESET_CONFIG_END
 //\_________________ Here you have to free all ressources allocated for myData. This one will be reseted to 0 at the end of this function. This function is called when your applet is stopped, in the very end.
 CD_APPLET_RESET_DATA_BEGIN
 	cairo_dock_unload_image_buffer (&myData.bgImage);
-	if (myData.pOldSurface != NULL)
+	cairo_dock_free_image_buffer (myData.pOldImage);
+	cairo_dock_free_image_buffer (myData.pCurrentImage);
+	/**if (myData.pOldSurface != NULL)
 		cairo_surface_destroy (myData.pOldSurface);
 	if (myData.iOldTexture != 0)
 		_cairo_dock_delete_texture (myData.iOldTexture);
 	if (myData.pCurrentSurface != NULL)
 		cairo_surface_destroy (myData.pCurrentSurface);
 	if (myData.iCurrentTexture != 0)
-		_cairo_dock_delete_texture (myData.iCurrentTexture);
+		_cairo_dock_delete_texture (myData.iCurrentTexture);*/
 	g_free (myData.cEmblemCapsLock);
 	g_free (myData.cEmblemNumLock);
+	g_free (myData.cShortGroupName);
+	g_free (myData.cGroupName);
 CD_APPLET_RESET_DATA_END
