@@ -73,9 +73,8 @@ typedef struct {
 
 struct _AppletData {
 	guint iSidTimer;
-	gchar *cSessionMigrationFileName;
 	// manual capabilities.
-	CairoDockTask *pTask;
+	GldiTask *pTask;
 	gboolean bCapabilitiesChecked;
 	gboolean bCanHibernate;
 	gboolean bCanHybridSleep;
