@@ -27,7 +27,7 @@
 
 #define _add_icon(pMailAccount)\
 	pIcon = cairo_dock_create_dummy_launcher (g_strdup (pMailAccount->name),\
-		g_strdup (myConfig.cNoMailUserImage),\
+		pMailAccount->cIconName ? g_strdup (pMailAccount->cIconName) : g_strdup (myConfig.cNoMailUserImage),\
 		g_strdup (pMailAccount->cMailApp),\
 		g_strdup ("..."),\
 		i);\
@@ -36,7 +36,7 @@
 	pMailAccount->icon = pIcon;
 
 // Translation Hack:
-const char *strings_to_translate[20] = {N_("Server address:"), N_("myHost"), N_("Username:"), N_("Password:"), N_("The password will be crypted."), N_("Port:"), N_("Enter 0 to use the default port. Default ports are 110 for POP3 or APOP and 995 for POP3S."), N_("Enter 0 to use the default port. Default ports are 143 for IMAP4 and 993 for IMAP4 over SSL."), N_("Use a secure connection (SSL)"), N_("Refresh time:"), N_("In minutes."), N_("Specific mail application"), N_("Leave empty to use the default mail application."), N_("Directory on server:"), N_("Path of mbox file:"), N_("Path to Mail directory:"), N_("Address of feed:"), N_("Remove this account"), N_("Don't forget to enable IMAP (or POP) service from settings of your mail account.")};
+const char *strings_to_translate[20] = {N_("Server address:"), N_("myHost"), N_("Username:"), N_("Password:"), N_("The password will be crypted."), N_("Port:"), N_("Enter 0 to use the default port. Default ports are 110 for POP3 or APOP and 995 for POP3S."), N_("Enter 0 to use the default port. Default ports are 143 for IMAP4 and 993 for IMAP4 over SSL."), N_("Use a secure connection (SSL)"), N_("Refresh time:"), N_("In minutes."), N_("Specific mail application"), N_("Leave empty to use the default mail application."), N_("Specific icon file when using multiple accounts"), N_("Directory on server:"), N_("Path of mbox file:"), N_("Path to Mail directory:"), N_("Address of feed:"), N_("Remove this account"), N_("Don't forget to enable IMAP (or POP) service from settings of your mail account.")};
 
 // Default parameters (to not copy these parameters each time)
 void _add_default_create_params( GKeyFile *pKeyFile, const gchar *pMailAccountName )
@@ -52,6 +52,9 @@ void _add_default_create_params( GKeyFile *pKeyFile, const gchar *pMailAccountNa
 
 	g_key_file_set_string (pKeyFile, pMailAccountName, "mail application", "");
 	g_key_file_set_comment (pKeyFile, pMailAccountName, "mail application", "s0 Specific mail application\n{Leave empty to use the default mail application.}", NULL);
+
+	g_key_file_set_string (pKeyFile, pMailAccountName, "icon name", "");
+	g_key_file_set_comment (pKeyFile, pMailAccountName, "icon name", "g0 Specific icon file when using multiple accounts\n{Leave empty to use the default icon.}", NULL);
 }
 
 void _retrieve_user_password (CDMailAccount *mailaccount, GKeyFile *pKeyFile, const gchar *mailbox_name)
@@ -512,30 +515,6 @@ void cd_mail_retrieve_orange_params (CDMailAccount *mailaccount, GKeyFile *pKeyF
 	_retrieve_user_password( mailaccount, pKeyFile, mailbox_name );
 }
 
-void cd_mail_create_uclouvain_params( GKeyFile *pKeyFile, const gchar *pMailAccountName )
-{
-	g_key_file_set_string (pKeyFile, pMailAccountName, "type", "uclouvain");
-	g_key_file_set_comment (pKeyFile, pMailAccountName, "type", ">0 ", NULL);
-
-	_add_default_create_params( pKeyFile, pMailAccountName );
-}
-
-void cd_mail_retrieve_uclouvain_params (CDMailAccount *mailaccount, GKeyFile *pKeyFile, const gchar *mailbox_name)
-{	// IMAP
-	if( !mailaccount || !pKeyFile || !mailbox_name )
-		return;
-
-	mailaccount->driver = IMAP_STORAGE;
-	mailaccount->storage = mailstorage_new(NULL);
-	mailaccount->server = g_strdup("mail.sipr.ucl.ac.be");
-	mailaccount->port = 993;
-	mailaccount->connection_type = CONNECTION_TYPE_TLS;
-	mailaccount->auth_type = IMAP_AUTH_TYPE_PLAIN;
-	mailaccount->path = g_strdup("Inbox");
-	
-	_retrieve_user_password( mailaccount, pKeyFile, mailbox_name );
-}
-
 void cd_mail_create_skynet_params( GKeyFile *pKeyFile, const gchar *pMailAccountName )
 {
 	g_key_file_set_string (pKeyFile, pMailAccountName, "type", "skynet");
@@ -571,7 +550,7 @@ void cd_mail_retrieve_skynet_params (CDMailAccount *mailaccount, GKeyFile *pKeyF
 };*/
 
 
-void cd_mail_init_accounts(CairoDockModuleInstance *myApplet)
+void cd_mail_init_accounts(GldiModuleInstance *myApplet)
 {
 	if (myData.pMailAccounts == NULL)
 		return ;
@@ -581,7 +560,6 @@ void cd_mail_init_accounts(CairoDockModuleInstance *myApplet)
 	CDMailAccount *pMailAccount;
 	GList *pIconList = NULL;
 	Icon *pIcon;
-	CairoContainer *pContainer;
 	int iNbIcons = 0;
 	int r;
 	gboolean bIsGettingMail = FALSE;
@@ -641,31 +619,28 @@ void cd_mail_init_accounts(CairoDockModuleInstance *myApplet)
 		if (myData.pMailAccounts->len == 1)  // 1 seul compte
 		{
 			pIcon = myIcon;
-			pContainer = myContainer;
 		}
 		else
 		{
 			_add_icon (pMailAccount);
-			pContainer = CD_APPLET_MY_ICONS_LIST_CONTAINER;
 		}
 		iNbIcons ++;
 		
 		//  if all is OK, then set a timeout for this mail account
 		if (r == MAIL_NO_ERROR)
 		{
-			cairo_dock_set_quick_info (pIcon, pContainer, "..."); // on the current icon
-			pMailAccount->pAccountMailTimer = cairo_dock_new_task (pMailAccount->timeout * 60,
-				(CairoDockGetDataAsyncFunc) cd_mail_get_folder_data,
-				(CairoDockUpdateSyncFunc) cd_mail_update_account_status,
+			gldi_icon_set_quick_info (pIcon, "..."); // on the current icon
+			pMailAccount->pAccountMailTimer = gldi_task_new (pMailAccount->timeout * 60,
+				(GldiGetDataAsyncFunc) cd_mail_get_folder_data,
+				(GldiUpdateSyncFunc) cd_mail_update_account_status,
 				pMailAccount);
-			cairo_dock_launch_task (pMailAccount->pAccountMailTimer);
+			gldi_task_launch (pMailAccount->pAccountMailTimer);
 			bIsGettingMail = TRUE;
 		}
 		else
 		{
 			cd_warning ("mail : the mail account %s couldn't be initialized !", pMailAccount->name);
-			CairoContainer *pContainer = (myData.pMailAccounts->len == 1 ? myContainer : CD_APPLET_MY_ICONS_LIST_CONTAINER);
-			cairo_dock_set_quick_info (pIcon, pContainer, "N/A");
+			gldi_icon_set_quick_info (pIcon, "N/A");
 		}
 	}
 	
@@ -691,7 +666,7 @@ void cd_mail_free_account (CDMailAccount *pMailAccount)
 	if (pMailAccount == NULL)
 		return ;
 	
-	cairo_dock_free_task( pMailAccount->pAccountMailTimer );
+	gldi_task_free( pMailAccount->pAccountMailTimer );
 	
 	g_free( pMailAccount->name );
 	g_free( pMailAccount->server );
@@ -699,6 +674,7 @@ void cd_mail_free_account (CDMailAccount *pMailAccount)
 	g_free( pMailAccount->password );
 	g_free( pMailAccount->path );
 	g_free( pMailAccount->cMailApp );
+	g_free( pMailAccount->cIconName );
 
 	if( pMailAccount->folder )
 		mailfolder_free(pMailAccount->folder);
@@ -714,7 +690,7 @@ void cd_mail_free_account (CDMailAccount *pMailAccount)
 	g_free( pMailAccount );
 }
 
-void cd_mail_free_all_accounts (CairoDockModuleInstance *myApplet)
+void cd_mail_free_all_accounts (GldiModuleInstance *myApplet)
 {
 	if (myData.pMailAccounts == NULL)
 		return ;
