@@ -58,13 +58,13 @@ CD_APPLET_ON_CLICK_BEGIN
 			gboolean r = cairo_dock_launch_command (cMailAppToLaunch);
 			if (!r)
 			{
-				cd_warning ("when couldn't execute '%s'", cMailAppToLaunch);
-				cairo_dock_show_temporary_dialog_with_icon_printf (D_("A problem occured\nIf '%s' is not your usual mail application,\nyou can change it in the configuration panel of this module"), myIcon, myContainer, 5000, "same icon", cMailAppToLaunch);
+				cd_warning ("couldn't execute '%s'", cMailAppToLaunch);
+				gldi_dialog_show_temporary_with_icon_printf (D_("A problem occured\nIf '%s' is not your usual mail application,\nyou can change it in the configuration panel of this module"), myIcon, myContainer, 5000, "same icon", cMailAppToLaunch);
 			}
 		}
 		else
 		{
-			cairo_dock_show_temporary_dialog_with_icon (D_("No mail application is defined,\nyou can define it in the configuration panel of this module"), myIcon, myContainer, 5000, "same icon");
+			gldi_dialog_show_temporary_with_icon (D_("No mail application is defined,\nyou can define it in the configuration panel of this module"), myIcon, myContainer, 5000, "same icon");
 		}
 	}
 CD_APPLET_ON_CLICK_END
@@ -75,22 +75,21 @@ static void _cd_mail_update_account (GtkMenuItem *menu_item, CDMailAccount *pMai
 {
 	if( pMailAccount )
 	{
-		if (cairo_dock_task_is_running (pMailAccount->pAccountMailTimer))
+		if (gldi_task_is_running (pMailAccount->pAccountMailTimer))
 		{
 			cd_debug ("account is being checked, wait a second\n");
 			return;
 		}
 
-		CairoDockModuleInstance *myApplet = pMailAccount->pAppletInstance;
+		GldiModuleInstance *myApplet = pMailAccount->pAppletInstance;
 		Icon *pIcon = (pMailAccount->icon ? pMailAccount->icon : myIcon);
-		CairoContainer *pContainer = (pMailAccount->icon ? CD_APPLET_MY_ICONS_LIST_CONTAINER : myContainer);
-		cairo_dock_set_quick_info (pIcon, pContainer, "...");
+		gldi_icon_set_quick_info (pIcon, "...");
 		
-		cairo_dock_launch_task(pMailAccount->pAccountMailTimer);
+		gldi_task_launch(pMailAccount->pAccountMailTimer);
 	}
 }
 
-static void _cd_mail_force_update(CairoDockModuleInstance *myApplet)
+static void _cd_mail_force_update(GldiModuleInstance *myApplet)
 {
 	guint i;
 	if (myData.pMailAccounts != NULL)
@@ -106,7 +105,7 @@ static void _cd_mail_force_update(CairoDockModuleInstance *myApplet)
 	}
 }
 
-static void _cd_mail_update_all_accounts (GtkMenuItem *menu_item, CairoDockModuleInstance *myApplet)
+static void _cd_mail_update_all_accounts (GtkMenuItem *menu_item, GldiModuleInstance *myApplet)
 {
 	_cd_mail_force_update (myApplet);
 }
@@ -117,12 +116,12 @@ CD_APPLET_ON_MIDDLE_CLICK_BEGIN
 
 CD_APPLET_ON_MIDDLE_CLICK_END
 
-static void _cd_mail_launch_mail_appli (GtkMenuItem *menu_item, CairoDockModuleInstance *myApplet)
+static void _cd_mail_launch_mail_appli (GtkMenuItem *menu_item, GldiModuleInstance *myApplet)
 {
 	cairo_dock_launch_command (myConfig.cMailApplication);
 }
 
-static void _cd_mail_mark_all_as_read (GtkMenuItem *menu_item, CairoDockModuleInstance *myApplet)
+static void _cd_mail_mark_all_as_read (GtkMenuItem *menu_item, GldiModuleInstance *myApplet)
 {
 	guint i;
 	if (myData.pMailAccounts != NULL)
@@ -144,7 +143,7 @@ CD_APPLET_ON_BUILD_MENU_BEGIN
 		if (myData.pMailAccounts->len > 1)  // many accounts -> list them in a sub-menu
 		{
 			// add a "update account" item for each mailbox
-			GtkWidget *pRefreshAccountSubMenu = CD_APPLET_ADD_SUB_MENU_WITH_IMAGE (D_("Refresh a mail account"), CD_APPLET_MY_MENU, GTK_STOCK_REFRESH);
+			GtkWidget *pRefreshAccountSubMenu = CD_APPLET_ADD_SUB_MENU_WITH_IMAGE (D_("Refresh a mail account"), CD_APPLET_MY_MENU, GLDI_ICON_NAME_REFRESH);
 			guint i;
 			for (i = 0; i < myData.pMailAccounts->len; i ++)
 			{
@@ -152,30 +151,30 @@ CD_APPLET_ON_BUILD_MENU_BEGIN
 				CD_APPLET_ADD_IN_MENU_WITH_DATA (pMailAccount->name, _cd_mail_update_account, pRefreshAccountSubMenu, pMailAccount);
 			}
 			gchar *cLabel = g_strdup_printf ("%s (%s)", D_("Refresh all"), D_("middle-click"));
-			CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (cLabel, GTK_STOCK_REFRESH, _cd_mail_update_all_accounts, CD_APPLET_MY_MENU, myApplet);
+			CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (cLabel, GLDI_ICON_NAME_REFRESH, _cd_mail_update_all_accounts, CD_APPLET_MY_MENU, myApplet);
 			g_free (cLabel);
 		}
 		else  // 1 account -> in main menu
 		{
 			CDMailAccount *pMailAccount = g_ptr_array_index (myData.pMailAccounts, 0);
 			gchar *cLabel = g_strdup_printf (D_("Refresh %s"), pMailAccount->name);
-			CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (cLabel, GTK_STOCK_REFRESH, _cd_mail_update_account, CD_APPLET_MY_MENU, pMailAccount);
+			CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (cLabel, GLDI_ICON_NAME_REFRESH, _cd_mail_update_account, CD_APPLET_MY_MENU, pMailAccount);
 			g_free (cLabel);
 		}
 	}
 	
-	CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Mark all emails as read"), GTK_STOCK_OK, _cd_mail_mark_all_as_read, CD_APPLET_MY_MENU);
+	CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Mark all emails as read"), "mail-mark-read", _cd_mail_mark_all_as_read, CD_APPLET_MY_MENU);
 	if (myConfig.cMailApplication)
 	{
 		gchar *cLabel = g_strdup_printf (D_("Launch %s"), myConfig.cMailApplication);
-		CD_APPLET_ADD_IN_MENU_WITH_STOCK (cLabel, GTK_STOCK_EXECUTE, _cd_mail_launch_mail_appli, CD_APPLET_MY_MENU);
+		CD_APPLET_ADD_IN_MENU_WITH_STOCK (cLabel, GLDI_ICON_NAME_EXECUTE, _cd_mail_launch_mail_appli, CD_APPLET_MY_MENU);
 		g_free (cLabel);
 	}
 CD_APPLET_ON_BUILD_MENU_END
 
 void _cd_mail_show_current_mail(CDMailAccount *pMailAccount)
 {
-	CairoDockModuleInstance *myApplet = pMailAccount->pAppletInstance;
+	GldiModuleInstance *myApplet = pMailAccount->pAppletInstance;
 	GList *l = pMailAccount->pUnseenMessageList;
 	const gchar *cMessage = "";
 	gint i = myData.iCurrentlyShownMail;
@@ -216,7 +215,7 @@ void _cd_mail_show_current_mail(CDMailAccount *pMailAccount)
 
 void _cd_mail_show_prev_mail_cb(GtkWidget *widget, CDMailAccount *pMailAccount)
 {
-	CairoDockModuleInstance *myApplet = pMailAccount->pAppletInstance;
+	GldiModuleInstance *myApplet = pMailAccount->pAppletInstance;
 
 	myData.iCurrentlyShownMail--;
 	_cd_mail_show_current_mail(pMailAccount);
@@ -224,7 +223,7 @@ void _cd_mail_show_prev_mail_cb(GtkWidget *widget, CDMailAccount *pMailAccount)
 
 void _cd_mail_show_next_mail_cb(GtkWidget *widget, CDMailAccount *pMailAccount)
 {
-	CairoDockModuleInstance *myApplet = pMailAccount->pAppletInstance;
+	GldiModuleInstance *myApplet = pMailAccount->pAppletInstance;
 
 	myData.iCurrentlyShownMail++;
 	_cd_mail_show_current_mail(pMailAccount);
@@ -232,18 +231,18 @@ void _cd_mail_show_next_mail_cb(GtkWidget *widget, CDMailAccount *pMailAccount)
 
 void _cd_mail_close_preview_cb(GtkWidget *widget, CDMailAccount *pMailAccount)
 {
-	CairoDockModuleInstance *myApplet = pMailAccount->pAppletInstance;
+	GldiModuleInstance *myApplet = pMailAccount->pAppletInstance;
 
 	if( myData.pMessagesDialog != NULL )
 	{
-		cairo_dock_dialog_unreference (myData.pMessagesDialog);
+		gldi_object_unref (GLDI_OBJECT(myData.pMessagesDialog));
 		myData.pMessagesDialog = NULL;
 	}
 }
 
 GtkWidget *cd_mail_messages_container_new(CDMailAccount *pMailAccount)
 {
-	CairoDockModuleInstance *myApplet = pMailAccount->pAppletInstance;
+	GldiModuleInstance *myApplet = pMailAccount->pAppletInstance;
 
 	/*
 	 * Appearance of the container:
@@ -256,7 +255,7 @@ GtkWidget *cd_mail_messages_container_new(CDMailAccount *pMailAccount)
 	 * | <--       CLOSE       --> |    <---- 3 buttons, attached Left,Center,Right
 	 * -----------------------------
 	 */
-	GtkWidget *vbox = _gtk_vbox_new (0);
+	GtkWidget *vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 
 	GtkWidget *pTextView = gtk_text_view_new();
 	gtk_text_view_set_editable(GTK_TEXT_VIEW(pTextView), FALSE);
@@ -266,15 +265,19 @@ GtkWidget *cd_mail_messages_container_new(CDMailAccount *pMailAccount)
 	myData.pTextBuffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(pTextView));
 
 	GtkWidget* pScrolledWindow = gtk_scrolled_window_new(NULL, NULL);
-	gtk_scrolled_window_add_with_viewport( GTK_SCROLLED_WINDOW(pScrolledWindow), pTextView );
+	#if GTK_CHECK_VERSION (3, 8, 0)
+	gtk_container_add (GTK_CONTAINER (pScrolledWindow), pTextView);
+	#else
+	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (pScrolledWindow), pTextView);
+	#endif
 	gtk_scrolled_window_set_policy( GTK_SCROLLED_WINDOW(pScrolledWindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC );
 	
 	gtk_box_pack_start(GTK_BOX(vbox), pScrolledWindow, TRUE, TRUE, 0);
 
-	GtkWidget *hbox = _gtk_hbox_new(0);
-	myData.pPrevButton = gtk_button_new_from_stock( GTK_STOCK_GO_BACK );
-	GtkWidget *pCloseButton = gtk_button_new_from_stock( GTK_STOCK_CLOSE );
-	myData.pNextButton = gtk_button_new_from_stock( GTK_STOCK_GO_FORWARD );
+	GtkWidget *hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+	myData.pPrevButton = gtk_button_new_from_icon_name( GLDI_ICON_NAME_GO_BACK, GTK_ICON_SIZE_BUTTON );
+	GtkWidget *pCloseButton = gtk_button_new_from_icon_name( GLDI_ICON_NAME_CLOSE, GTK_ICON_SIZE_BUTTON );
+	myData.pNextButton = gtk_button_new_from_icon_name( GLDI_ICON_NAME_GO_FORWARD, GTK_ICON_SIZE_BUTTON );
 
 	gtk_box_pack_start(GTK_BOX(hbox), GTK_WIDGET(myData.pPrevButton), FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), GTK_WIDGET(pCloseButton), TRUE, FALSE, 0);
@@ -306,7 +309,7 @@ GtkWidget *cd_mail_messages_container_new(CDMailAccount *pMailAccount)
 
 CD_APPLET_ON_SCROLL_BEGIN
 	if (myData.pMailAccounts == NULL || !myConfig.bShowMessageContent)
-		CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
+		CD_APPLET_LEAVE (GLDI_NOTIFICATION_LET_PASS);
 
 	CDMailAccount *pMailAccount = NULL;
 	guint i;
@@ -318,12 +321,12 @@ CD_APPLET_ON_SCROLL_BEGIN
 			break ;
 	}
 	if (i == myData.pMailAccounts->len || pMailAccount == NULL)
-		CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
+		CD_APPLET_LEAVE (GLDI_NOTIFICATION_LET_PASS);
 	
-	if (cairo_dock_task_is_running (pMailAccount->pAccountMailTimer))
+	if (gldi_task_is_running (pMailAccount->pAccountMailTimer))
 	{
 		cd_debug ("account is being checked, wait a second\n");
-		CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
+		CD_APPLET_LEAVE (GLDI_NOTIFICATION_LET_PASS);
 	}
 	
 	/* Ensure the connection is alive */
@@ -340,7 +343,7 @@ CD_APPLET_ON_SCROLL_BEGIN
 			cd_debug ( "Displaying messages" );
 			if( pMailAccount->pUnseenMessageList != NULL )
 			{
-				myData.pMessagesDialog = cairo_dock_show_dialog_full (_("Mail"),
+				myData.pMessagesDialog = gldi_dialog_show (D_("Mail"),
 					myIcon, myContainer,
 					0,
 					"same icon",
