@@ -34,7 +34,7 @@ CD_APPLET_DEFINITION (N_("netspeed"),
 	"Middle-click to (de)activate the network (needs NetworManager)"),
 	"parAdOxxx_ZeRo");
 
-static void _set_data_renderer (CairoDockModuleInstance *myApplet, gboolean bReload)
+static void _set_data_renderer (GldiModuleInstance *myApplet, gboolean bReload)
 {
 	if (myConfig.iDisplayType == CD_NETSPEED_BAR)
 		return; /// TODO
@@ -42,6 +42,8 @@ static void _set_data_renderer (CairoDockModuleInstance *myApplet, gboolean bRel
 	CairoDataRendererAttribute *pRenderAttr = NULL;  // attributes for the global data-renderer.
 	CairoGaugeAttribute aGaugeAttr;  // gauge attributes.
 	CairoGraphAttribute aGraphAttr;  // graph attributes.
+	double fHighColor[CD_NETSPEED_NB_MAX_VALUES*3]; // attributes for the graph
+	double fLowColor[CD_NETSPEED_NB_MAX_VALUES*3];  // (but have to be declared here to force GCC to keep data)
 	if (myConfig.iDisplayType == CD_NETSPEED_GAUGE)
 	{
 		memset (&aGaugeAttr, 0, sizeof (CairoGaugeAttribute));
@@ -60,8 +62,6 @@ static void _set_data_renderer (CairoDockModuleInstance *myApplet, gboolean bRel
 		pRenderAttr->iMemorySize = (w > 1 ? w : 32);
 		aGraphAttr.iType = myConfig.iGraphType;
 		aGraphAttr.bMixGraphs = myConfig.bMixGraph;
-		double fHighColor[CD_NETSPEED_NB_MAX_VALUES*3];
-		double fLowColor[CD_NETSPEED_NB_MAX_VALUES*3];
 		int i = 0;
 		memcpy (&fHighColor[3*i], myConfig.fHigholor, 3*sizeof (double));
 		memcpy (&fLowColor[3*i], myConfig.fLowColor, 3*sizeof (double));
@@ -98,12 +98,12 @@ CD_APPLET_INIT_BEGIN
 	
 	// Initialisation de la tache periodique de mesure.
 	myData.pClock = g_timer_new ();
-	myData.pPeriodicTask = cairo_dock_new_task (myConfig.iCheckInterval,
-		(CairoDockGetDataAsyncFunc) cd_netspeed_get_data,
-		(CairoDockUpdateSyncFunc) cd_netspeed_update_from_data,
+	myData.pPeriodicTask = gldi_task_new (myConfig.iCheckInterval,
+		(GldiGetDataAsyncFunc) cd_netspeed_get_data,
+		(GldiUpdateSyncFunc) cd_netspeed_update_from_data,
 		myApplet);
 	myData.bAcquisitionOK = TRUE;
-	cairo_dock_launch_task (myData.pPeriodicTask);
+	gldi_task_launch (myData.pPeriodicTask);
 	
 	CD_APPLET_REGISTER_FOR_CLICK_EVENT;
 	CD_APPLET_REGISTER_FOR_BUILD_MENU_EVENT;
@@ -142,14 +142,14 @@ CD_APPLET_RELOAD_BEGIN
 				CD_APPLET_SET_NAME_FOR_MY_ICON (myApplet->pModule->pVisitCard->cTitle);
 		}
 		
-		cairo_dock_relaunch_task_immediately (myData.pPeriodicTask, myConfig.iCheckInterval);
+		gldi_task_change_frequency_and_relaunch (myData.pPeriodicTask, myConfig.iCheckInterval);
 	}
 	else {  // on redessine juste l'icone.
 		//CD_APPLET_RELOAD_MY_DATA_RENDERER (NULL);
 		if (myConfig.iDisplayType == CD_NETSPEED_GRAPH)
 			CD_APPLET_SET_MY_DATA_RENDERER_HISTORY_TO_MAX;
 		
-		/**if (! cairo_dock_task_is_running (myData.pPeriodicTask))
+		/**if (! gldi_task_is_running (myData.pPeriodicTask))
 			cd_netspeed_update_from_data (myApplet);*/
 	}
 CD_APPLET_RELOAD_END
