@@ -58,7 +58,7 @@ void cd_shortcuts_get_fs_stat (const gchar *cDiskURI, CDDiskUsage *pDiskUsage)
 	}
 }
 
-static void _display_disk_usage (Icon *pIcon, CairoContainer *pContainer, CDDiskUsage *pDiskUsage, CairoDockModuleInstance *myApplet)
+static void _display_disk_usage (Icon *pIcon, GldiContainer *pContainer, CDDiskUsage *pDiskUsage, GldiModuleInstance *myApplet)
 {
 	double fValue;
 	if (pDiskUsage->iTotal != 0 && (pDiskUsage->iPrevAvail == -1 || (double)fabs (pDiskUsage->iPrevAvail - pDiskUsage->iAvail) / pDiskUsage->iTotal > .001))  // .1 % d'ecart ou info encore non renseignee.
@@ -68,19 +68,19 @@ static void _display_disk_usage (Icon *pIcon, CairoContainer *pContainer, CDDisk
 		{
 			case CD_SHOW_FREE_SPACE :
 				fValue = (double) pDiskUsage->iAvail / pDiskUsage->iTotal;
-				cairo_dock_set_size_as_quick_info (pIcon, pContainer, pDiskUsage->iAvail);
+				cairo_dock_set_size_as_quick_info (pIcon, pDiskUsage->iAvail);
 			break ;
 			case CD_SHOW_USED_SPACE :
 				fValue = (double) pDiskUsage->iUsed / pDiskUsage->iTotal;
-				cairo_dock_set_size_as_quick_info (pIcon, pContainer, pDiskUsage->iUsed);
+				cairo_dock_set_size_as_quick_info (pIcon, pDiskUsage->iUsed);
 			break ;
 			case CD_SHOW_FREE_SPACE_PERCENT :
 				fValue = (double) pDiskUsage->iAvail / pDiskUsage->iTotal;
-				cairo_dock_set_quick_info_printf (pIcon, pContainer, "%.1f%%", 100.*fValue);
+				gldi_icon_set_quick_info_printf (pIcon, "%.1f%%", 100.*fValue);
 			break ;
 			case CD_SHOW_USED_SPACE_PERCENT :
 				fValue = (double) pDiskUsage->iUsed / pDiskUsage->iTotal;
-				cairo_dock_set_quick_info_printf (pIcon, pContainer, "%.1f%%", 100.*fValue);
+				gldi_icon_set_quick_info_printf (pIcon, "%.1f%%", 100.*fValue);
 			break ;
 			default:
 				fValue = CAIRO_DATA_RENDERER_UNDEF_VALUE;
@@ -90,23 +90,23 @@ static void _display_disk_usage (Icon *pIcon, CairoContainer *pContainer, CDDisk
 		if (myConfig.bDrawBar)
 			cairo_dock_render_new_data_on_icon (pIcon, pContainer, myDrawContext, &fValue);
 		else  // just trigger the redraw for the quick-info
-			cairo_dock_redraw_icon (pIcon, pContainer);
+			cairo_dock_redraw_icon (pIcon);
 	}
 }
 
-void cd_shortcuts_display_disk_usage (Icon *pIcon, CairoDockModuleInstance *myApplet)
+void cd_shortcuts_display_disk_usage (Icon *pIcon, GldiModuleInstance *myApplet)
 {
-	CairoContainer *pContainer = pIcon->pContainer;
+	GldiContainer *pContainer = pIcon->pContainer;
 	g_return_if_fail (pContainer != NULL);
 	CDDiskUsage *pDiskUsage = CD_APPLET_GET_MY_ICON_DATA (pIcon);
 	g_return_if_fail (pDiskUsage != NULL);
 	_display_disk_usage (pIcon, pContainer, pDiskUsage, myApplet);
 }
 
-static gboolean _cd_shortcuts_update_disk_usage (CairoDockModuleInstance *myApplet)
+static gboolean _cd_shortcuts_update_disk_usage (GldiModuleInstance *myApplet)
 {
 	CD_APPLET_ENTER;
-	CairoContainer *pContainer = CD_APPLET_MY_ICONS_LIST_CONTAINER;
+	GldiContainer *pContainer = CD_APPLET_MY_ICONS_LIST_CONTAINER;
 	CDDiskUsage *pDiskUsage;
 	Icon *pIcon;
 	GList *ic;
@@ -120,7 +120,11 @@ static gboolean _cd_shortcuts_update_disk_usage (CairoDockModuleInstance *myAppl
 			pDiskUsage = CD_APPLET_GET_MY_ICON_DATA (pIcon);
 			if (pDiskUsage == NULL)  // not a drive (eg, network or bookmark)
 			{
-				if (pIcon->iGroup == (CairoDockIconGroup) CD_BOOKMARK_GROUP)  // drives are listed first, and Home is always the first bookmark (and the only one to have disk data), so if we got a bookmark with no disk data, we can quit the loop.
+				/* Drives are listed first, and Home is always the first
+				 * bookmark (and the only one to have disk data), so if we got a
+				 * bookmark with no disk data, we can quit the loop.
+				 */
+				if (pIcon->iGroup >= (CairoDockIconGroup) CD_BOOKMARK_GROUP)
 					break;
 				else
 					continue;
@@ -139,24 +143,24 @@ static gboolean _cd_shortcuts_update_disk_usage (CairoDockModuleInstance *myAppl
 }
 
 
-void cd_shortcuts_launch_disk_periodic_task (CairoDockModuleInstance *myApplet)
+void cd_shortcuts_launch_disk_periodic_task (GldiModuleInstance *myApplet)
 {
 	if (myConfig.iDisplayType != CD_SHOW_NOTHING && myConfig.bListDrives)
 	{
 		if (myData.pDiskTask == NULL)
 		{
-			myData.pDiskTask = cairo_dock_new_task (myConfig.iCheckInterval,
-				(CairoDockGetDataAsyncFunc) NULL,
-				(CairoDockUpdateSyncFunc) _cd_shortcuts_update_disk_usage,
+			myData.pDiskTask = gldi_task_new (myConfig.iCheckInterval,
+				(GldiGetDataAsyncFunc) NULL,
+				(GldiUpdateSyncFunc) _cd_shortcuts_update_disk_usage,
 				myApplet);
 		}
-		cairo_dock_launch_task (myData.pDiskTask);
+		gldi_task_launch (myData.pDiskTask);
 	}
 }
 
-void cd_shortcuts_free_disk_periodic_task (CairoDockModuleInstance *myApplet)
+void cd_shortcuts_free_disk_periodic_task (GldiModuleInstance *myApplet)
 {
-	cairo_dock_free_task (myData.pDiskTask);
+	gldi_task_free (myData.pDiskTask);
 	myData.pDiskTask = NULL;
 }
 
