@@ -45,9 +45,9 @@ struct _AppletConfig {
 struct _AppletData {
 	gboolean bDesktopVisible;
 	gboolean bDeskletsVisible;
-	Window xLastActiveWindow;
+	GldiWindowActor *pLastActiveWindow;
 	gchar *cPendingFile;
-	CairoKeyBinding *cKeyBinding;
+	GldiShortkey *cKeyBinding;
 	} ;
 
 
