@@ -55,7 +55,7 @@ static void cd_slider_free_images_list (GList *pList) {
 }
 
 
-static void _cd_slider_load_image (CairoDockModuleInstance *myApplet)
+static void _cd_slider_load_image (GldiModuleInstance *myApplet)
 {
 	g_return_if_fail (myData.pElement != NULL);
 	SliderImage *pImage = myData.pElement->data;
@@ -98,7 +98,7 @@ static void _cd_slider_load_image (CairoDockModuleInstance *myApplet)
 	cd_debug ("  %s loaded", cImagePath);
 }
 
-static gboolean _cd_slider_display_image (CairoDockModuleInstance *myApplet)
+static gboolean _cd_slider_display_image (GldiModuleInstance *myApplet)
 {
 	CD_APPLET_ENTER;
 	//\_______________ On cree la texture (en-dehors du thread).
@@ -134,7 +134,7 @@ static gboolean _cd_slider_display_image (CairoDockModuleInstance *myApplet)
 	CD_APPLET_LEAVE (FALSE);
 }
 
-void cd_slider_jump_to_next_slide (CairoDockModuleInstance *myApplet)
+void cd_slider_jump_to_next_slide (GldiModuleInstance *myApplet)
 {
 	//\___________________________ stop any pending action.
 	if (myData.iTimerID != 0)
@@ -142,7 +142,7 @@ void cd_slider_jump_to_next_slide (CairoDockModuleInstance *myApplet)
 		g_source_remove (myData.iTimerID);
 		myData.iTimerID = 0;
 	}
-	cairo_dock_stop_task (myData.pMeasureImage);
+	gldi_task_stop (myData.pMeasureImage);
 	
 	//\___________________________ On recupere la nouvelle image a afficher.
 	if (myData.pElement == NULL)  // debut
@@ -196,7 +196,7 @@ void cd_slider_jump_to_next_slide (CairoDockModuleInstance *myApplet)
 		|| (pImage->iFormat == SLIDER_XPM && pImage->iSize > 100e3)) )
 	{
 		cd_debug ("Slider - launch thread");
-		cairo_dock_launch_task (myData.pMeasureImage);
+		gldi_task_launch (myData.pMeasureImage);
 	}
 	else
 	{
@@ -206,7 +206,7 @@ void cd_slider_jump_to_next_slide (CairoDockModuleInstance *myApplet)
 }
 
 
-static gboolean _next_slide (CairoDockModuleInstance *myApplet)
+static gboolean _next_slide (GldiModuleInstance *myApplet)
 {
 	CD_APPLET_ENTER;
 	
@@ -219,7 +219,7 @@ static gboolean _next_slide (CairoDockModuleInstance *myApplet)
 	
 	CD_APPLET_LEAVE (FALSE);
 }
-void cd_slider_schedule_next_slide (CairoDockModuleInstance *myApplet)
+void cd_slider_schedule_next_slide (GldiModuleInstance *myApplet)
 {
 	if (myData.iTimerID == 0)
 		myData.iTimerID = g_timeout_add_seconds (myConfig.iSlideTime, (GSourceFunc) _next_slide, (gpointer) myApplet);
@@ -258,7 +258,7 @@ static void _cd_slider_get_exif_props (SliderImage *pImage)
 	pImage->bGotExifData = TRUE;
 }
 
-static gboolean _cd_slider_get_exif_props_idle (CairoDockModuleInstance *myApplet)
+static gboolean _cd_slider_get_exif_props_idle (GldiModuleInstance *myApplet)
 {
 #ifdef HAVE_EXIF
 	if (myData.pExifElement == NULL)
@@ -289,7 +289,7 @@ typedef struct {
 	gboolean bSubDirs;
 	gboolean bRandom;
 	GList *pList;  // the result
-	CairoDockModuleInstance *pApplet;
+	GldiModuleInstance *pApplet;
 	} CDListSharedMemory;
 
 static void _free_shared_memory (CDListSharedMemory *pSharedMemory)
@@ -398,7 +398,7 @@ static void cd_slider_get_files_from_dir (CDListSharedMemory *pSharedMemory)
 static gboolean cd_slider_start_slide (CDListSharedMemory *pSharedMemory)
 {
 	// grab the result
-	CairoDockModuleInstance *myApplet = pSharedMemory->pApplet;
+	GldiModuleInstance *myApplet = pSharedMemory->pApplet;
 	myData.pList = pSharedMemory->pList;
 	
 	// if needed, get the EXIF data now
@@ -412,9 +412,9 @@ static gboolean cd_slider_start_slide (CDListSharedMemory *pSharedMemory)
 	}
 	
 	// create the loading task that will be used later
-	myData.pMeasureImage = cairo_dock_new_task (0,
-		(CairoDockGetDataAsyncFunc) _cd_slider_load_image,
-		(CairoDockUpdateSyncFunc) _cd_slider_display_image,
+	myData.pMeasureImage = gldi_task_new (0,
+		(GldiGetDataAsyncFunc) _cd_slider_load_image,
+		(GldiUpdateSyncFunc) _cd_slider_display_image,
 		myApplet);  // 0 <=> one shot task.
 	
 	// display the first slide.
@@ -425,15 +425,15 @@ static gboolean cd_slider_start_slide (CDListSharedMemory *pSharedMemory)
 	}
 	else  // no images found or folder not defined => no need to launch the loop, display a 'missing' icon
 	{
-		CD_APPLET_SET_IMAGE_ON_MY_ICON (GTK_STOCK_MISSING_IMAGE);
+		CD_APPLET_SET_IMAGE_ON_MY_ICON (GLDI_ICON_NAME_MISSING_IMAGE);
 	}
 	return FALSE;
 }
 
 
-void cd_slider_start (CairoDockModuleInstance *myApplet, gboolean bDelay)
+void cd_slider_start (GldiModuleInstance *myApplet, gboolean bDelay)
 {
-	cairo_dock_discard_task (myData.pMeasureDirectory);
+	gldi_task_discard (myData.pMeasureDirectory);
 	
 	// remember the current params.
 	g_free (myData.cDirectory);
@@ -449,25 +449,25 @@ void cd_slider_start (CairoDockModuleInstance *myApplet, gboolean bDelay)
 	pSharedMemory->pApplet = myApplet;
 	
 	CD_APPLET_SET_QUICK_INFO_ON_MY_ICON ("...");  // Note: we could launch a 'busy' animation, but it's maybe not a good idea to add more CPU load (anyway, the animation should be launched with a g_idle_add, because animations may not be inited yet).
-	myData.pMeasureDirectory = cairo_dock_new_task_full (0,
-		(CairoDockGetDataAsyncFunc) cd_slider_get_files_from_dir,
-		(CairoDockUpdateSyncFunc) cd_slider_start_slide,
+	myData.pMeasureDirectory = gldi_task_new_full (0,
+		(GldiGetDataAsyncFunc) cd_slider_get_files_from_dir,
+		(GldiUpdateSyncFunc) cd_slider_start_slide,
 		(GFreeFunc) _free_shared_memory,
 		pSharedMemory); // 0 <=> one shot task.
 	
 	// launch the parsing.
 	if (bDelay)
-		cairo_dock_launch_task_delayed (myData.pMeasureDirectory, cairo_dock_is_loading () ? 1500. : 0.);  // launch with a delay or just in the next main loop event.
+		gldi_task_launch_delayed (myData.pMeasureDirectory, cairo_dock_is_loading () ? 1500. : 0.);  // launch with a delay or just in the next main loop event.
 	else
-		cairo_dock_launch_task (myData.pMeasureDirectory);
+		gldi_task_launch (myData.pMeasureDirectory);
 }
 
-void cd_slider_stop (CairoDockModuleInstance *myApplet)
+void cd_slider_stop (GldiModuleInstance *myApplet)
 {
 	//Stop all processes
-	cairo_dock_free_task (myData.pMeasureImage);  // since it needs a cairo context, we can't let it live.
+	gldi_task_free (myData.pMeasureImage);  // since it needs a cairo context, we can't let it live.
 	myData.pMeasureImage = NULL;
-	cairo_dock_discard_task (myData.pMeasureDirectory);
+	gldi_task_discard (myData.pMeasureDirectory);
 	myData.pMeasureDirectory = NULL;
 	if (myData.iSidExifIdle != 0)
 	{
