@@ -39,7 +39,8 @@ static void _cd_switcher_draw_windows_on_viewport (Icon *pIcon, CDSwitcherDeskto
 {
 	if (pIcon == NULL || pIcon->fInsertRemoveFactor > 0)
 		return ;
-	if (pIcon->bIsHidden && ! myConfig.bDisplayHiddenWindows)
+	GldiWindowActor *actor = pIcon->pAppli;
+	if (actor->bIsHidden && ! myConfig.bDisplayHiddenWindows)
 		return ;
 	int iNumDesktop = data->iNumDesktop;
 	int iNumViewportX = data->iNumViewportX;
@@ -49,19 +50,19 @@ static void _cd_switcher_draw_windows_on_viewport (Icon *pIcon, CDSwitcherDeskto
 	cairo_t *pCairoContext = data->pCairoContext;
 	
 	// On calcule les coordonnees en repere absolu.
-	int x = pIcon->windowGeometry.x;  // par rapport au viewport courant.
+	int x = actor->windowGeometry.x;  // par rapport au viewport courant.
 	x += myData.switcher.iCurrentViewportX * g_desktopGeometry.Xscreen.width;  // repere absolu
 	if (x < 0)
 		x += g_desktopGeometry.iNbViewportX * g_desktopGeometry.Xscreen.width;
-	int y = pIcon->windowGeometry.y;
+	int y = actor->windowGeometry.y;
 	y += myData.switcher.iCurrentViewportY * g_desktopGeometry.Xscreen.height;
 	if (y < 0)
 		y += g_desktopGeometry.iNbViewportY * g_desktopGeometry.Xscreen.height;
-	int w = pIcon->windowGeometry.width, h = pIcon->windowGeometry.height;
+	int w = actor->windowGeometry.width, h = actor->windowGeometry.height;
 	
 	// test d'intersection avec le viewport donne.
 	//g_print (" %s : (%d;%d) %dx%d\n", pIcon->cName, x, y, w, h);
-	if ((pIcon->iNumDesktop != -1 && pIcon->iNumDesktop != iNumDesktop) ||
+	if ((actor->iNumDesktop != -1 && actor->iNumDesktop != iNumDesktop) ||
 		x + w <= iNumViewportX * g_desktopGeometry.Xscreen.width ||
 		x >= (iNumViewportX + 1) * g_desktopGeometry.Xscreen.width ||
 		y + h <= iNumViewportY * g_desktopGeometry.Xscreen.height ||
@@ -71,19 +72,24 @@ static void _cd_switcher_draw_windows_on_viewport (Icon *pIcon, CDSwitcherDeskto
 	// on dessine ses traits.
 	cairo_save (pCairoContext);
 
-	Window iActiveWindow = cairo_dock_get_current_active_window ();
-
-	if (myConfig.bFillAllWindows && pIcon->Xid != iActiveWindow)
+	GldiWindowActor *pActiveWindow = gldi_windows_get_active ();
+	
+	if (myConfig.bFillAllWindows && actor != pActiveWindow)
 		cairo_set_source_rgba (pCairoContext, myConfig.RGBWFillColors[0], myConfig.RGBWFillColors[1], myConfig.RGBWFillColors[2], myConfig.RGBWFillColors[3]);
 	else
-		cairo_set_source_rgba (pCairoContext, myConfig.RGBWLineColors[0], myConfig.RGBWLineColors[1], myConfig.RGBWLineColors[2], myConfig.RGBWLineColors[3]);
+	{
+		if (myConfig.bUseDefaultColors)
+			gldi_style_colors_set_line_color (myDrawContext);
+		else
+			cairo_set_source_rgba (pCairoContext, myConfig.RGBWLineColors[0], myConfig.RGBWLineColors[1], myConfig.RGBWLineColors[2], myConfig.RGBWLineColors[3]);
+	}
 	cairo_rectangle (pCairoContext,
 		(1.*x/g_desktopGeometry.Xscreen.width - iNumViewportX)*iOneViewportWidth,
 		(1.*y/g_desktopGeometry.Xscreen.height - iNumViewportY)*iOneViewportHeight,
 		1.*w/g_desktopGeometry.Xscreen.width*iOneViewportWidth,
 		1.*h/g_desktopGeometry.Xscreen.height*iOneViewportHeight);
 
-	if (myConfig.bFillAllWindows || pIcon->Xid == iActiveWindow)
+	if (myConfig.bFillAllWindows || actor == pActiveWindow)
 	{
 		//g_print (" %s est la fenetre active\n", pIcon->cName);
 		cairo_fill (pCairoContext);
@@ -95,7 +101,7 @@ static void _cd_switcher_draw_windows_on_viewport (Icon *pIcon, CDSwitcherDeskto
 	
 	if (myConfig.bDrawIcons)
 	{
-		const CairoDockImageBuffer *pImage = cairo_dock_appli_get_image_buffer (pIcon);
+		const CairoDockImageBuffer *pImage = gldi_appli_icon_get_image_buffer (pIcon);
 		if (pImage && pImage->pSurface)
 		{
 			double fZoomX = (double) w/g_desktopGeometry.Xscreen.width*iOneViewportWidth / pImage->iWidth;
@@ -126,7 +132,7 @@ static int _compare_icons_stack_order (Icon *icon1, Icon *icon2)
 		return 1;
 	if (icon2 == NULL)
 		return -1;
-	if (icon1->iStackOrder < icon2->iStackOrder)  // ordre petit => dessus => dessinee en dernier.
+	if (icon1->pAppli->iStackOrder < icon2->pAppli->iStackOrder)  // ordre petit => dessus => dessinee en dernier.
 		return -1;
 	else
 		return 1;
@@ -187,7 +193,10 @@ void cd_switcher_draw_main_icon_compact_mode (void)
 	
 	// cadre exterieur.
 	cairo_set_line_width (myDrawContext,myConfig.iLineSize);
-	cairo_set_source_rgba(myDrawContext,myConfig.RGBLineColors[0],myConfig.RGBLineColors[1],myConfig.RGBLineColors[2],myConfig.RGBLineColors[3]);
+	if (myConfig.bUseDefaultColors)
+		gldi_style_colors_set_line_color (myDrawContext);
+	else
+		cairo_set_source_rgba(myDrawContext,myConfig.RGBLineColors[0],myConfig.RGBLineColors[1],myConfig.RGBLineColors[2],myConfig.RGBLineColors[3]);
 	cairo_rectangle(myDrawContext,
 		.5*myConfig.iLineSize,
 		.5*myConfig.iLineSize,
@@ -198,7 +207,10 @@ void cd_switcher_draw_main_icon_compact_mode (void)
 	
 	// lignes interieures.
 	cairo_set_line_width (myDrawContext,myConfig.iInLineSize);
-	cairo_set_source_rgba(myDrawContext,myConfig.RGBInLineColors[0],myConfig.RGBInLineColors[1],myConfig.RGBInLineColors[2],myConfig.RGBInLineColors[3]);
+	if (myConfig.bUseDefaultColors)
+		gldi_style_colors_set_line_color (myDrawContext);
+	else
+		cairo_set_source_rgba (myDrawContext,myConfig.RGBInLineColors[0],myConfig.RGBInLineColors[1],myConfig.RGBInLineColors[2],myConfig.RGBInLineColors[3]);
 	double xi, yj;
 	int i, j;
 	for (i = 1; i < myData.switcher.iNbColumns; i ++)  // lignes verticales.
@@ -250,11 +262,15 @@ void cd_switcher_draw_main_icon_compact_mode (void)
 			
 			cairo_restore (myDrawContext);
 			
-			if (myConfig.iDrawCurrentDesktopMode == SWICTHER_FILL_INVERTED && (i != myData.switcher.iCurrentColumn || j != myData.switcher.iCurrentLine))
+			if ((myConfig.iDrawCurrentDesktopMode == SWICTHER_FILL_INVERTED && (i != myData.switcher.iCurrentColumn || j != myData.switcher.iCurrentLine))
+			|| (myConfig.iDrawCurrentDesktopMode == SWICTHER_FILL && (i == myData.switcher.iCurrentColumn && j == myData.switcher.iCurrentLine)))
 			{
 				cairo_save (myDrawContext);
 				
-				cairo_set_source_rgba (myDrawContext, myConfig.RGBIndColors[0], myConfig.RGBIndColors[1], myConfig.RGBIndColors[2], myConfig.RGBIndColors[3]);
+				if (myConfig.bUseDefaultColors)
+					gldi_style_colors_set_selected_bg_color (myDrawContext);
+				else
+					cairo_set_source_rgba (myDrawContext, myConfig.RGBIndColors[0], myConfig.RGBIndColors[1], myConfig.RGBIndColors[2], myConfig.RGBIndColors[3]);
 				cairo_rectangle(myDrawContext,
 					xi - .5*myConfig.iLineSize,
 					yj - .5*myConfig.iLineSize,
@@ -303,7 +319,7 @@ void cd_switcher_draw_main_icon_compact_mode (void)
 	}
 	
 	// dessin de l'indicateur sur le bureau courant (on le fait maintenant car dans le cas ou la ligne interieure est plus petite que la ligne de l'indicateur, les surfaces suivantes recouvreraient en partie la ligne.
-	if (myConfig.iDrawCurrentDesktopMode != SWICTHER_FILL_INVERTED)
+	if (myConfig.iDrawCurrentDesktopMode == SWICTHER_DRAW_FRAME)
 	{
 		i = myData.switcher.iCurrentColumn;
 		j = myData.switcher.iCurrentLine;
@@ -311,7 +327,10 @@ void cd_switcher_draw_main_icon_compact_mode (void)
 		yj = myConfig.iLineSize + j * (myData.switcher.fOneViewportHeight + myConfig.iInLineSize);
 		
 		cairo_set_line_width (myDrawContext,myConfig.iLineSize);
-		cairo_set_source_rgba (myDrawContext,myConfig.RGBIndColors[0],myConfig.RGBIndColors[1],myConfig.RGBIndColors[2],myConfig.RGBIndColors[3]);
+		if (myConfig.bUseDefaultColors)
+			gldi_style_colors_set_selected_bg_color (myDrawContext);
+		else
+			cairo_set_source_rgba (myDrawContext,myConfig.RGBIndColors[0],myConfig.RGBIndColors[1],myConfig.RGBIndColors[2],myConfig.RGBIndColors[3]);
 		cairo_rectangle(myDrawContext,
 			xi - .5*myConfig.iLineSize,
 			yj - .5*myConfig.iLineSize,
@@ -319,17 +338,18 @@ void cd_switcher_draw_main_icon_compact_mode (void)
 			myData.switcher.fOneViewportHeight + myConfig.iLineSize);
 		
 		if (myConfig.iDrawCurrentDesktopMode == SWICTHER_FILL)
-			cairo_fill (myDrawContext);
+			cairo_fill (myDrawContext);  // maybe we need to fill it with an alpha pattern in case we use the global style color ?...
 		else
+		{
+			cairo_set_line_width (myDrawContext, MIN (4, 2*myConfig.iLineSize));
 			cairo_stroke(myDrawContext);
+		}
 	}
 	
 	cairo_restore (myDrawContext);
 	g_list_free (pWindowList);  // le contenu appartient a la hash table, mais pas la liste.
 	
 	CD_APPLET_FINISH_DRAWING_MY_ICON_CAIRO;
-	///if (CD_APPLET_MY_CONTAINER_IS_OPENGL)
-	///	cairo_dock_update_icon_texture (myIcon);
 }
 
 
@@ -370,8 +390,6 @@ void cd_switcher_draw_main_icon_expanded_mode (void)
 
 			if (CD_APPLET_MY_CONTAINER_IS_OPENGL)
 				cairo_dock_update_icon_texture (myIcon);
-			/**else
-				CD_APPLET_UPDATE_REFLECT_ON_MY_ICON;*/
 		}
 		else
 		{
@@ -397,7 +415,10 @@ void cd_switcher_draw_main_icon_expanded_mode (void)
 			
 			pCairoContext = cairo_create (pIcon->image.pSurface);
 			cairo_set_line_width (pCairoContext, 1.);
-			cairo_set_source_rgba (pCairoContext, myConfig.RGBWLineColors[0], myConfig.RGBWLineColors[1], myConfig.RGBWLineColors[2], myConfig.RGBWLineColors[3]);
+			if (myConfig.bUseDefaultColors)
+				gldi_style_colors_set_line_color (myDrawContext);
+			else
+				cairo_set_source_rgba (pCairoContext, myConfig.RGBWLineColors[0], myConfig.RGBWLineColors[1], myConfig.RGBWLineColors[2], myConfig.RGBWLineColors[3]);
 			
 			data.iNumDesktop = iNumDesktop;
 			data.iNumViewportX = iNumViewportX;
@@ -503,7 +524,7 @@ void cd_switcher_extract_viewport_coords_from_picked_object (CairoDesklet *pDesk
 static void _show_window (GtkMenuItem *menu_item, Icon *pIcon)
 {
 	CD_APPLET_ENTER;
-	cairo_dock_show_xwindow (pIcon->Xid);
+	gldi_window_show (pIcon->pAppli);
 	CD_APPLET_LEAVE ();
 }
 
@@ -513,13 +534,14 @@ static void _show_desktop (GtkMenuItem *menu_item, gpointer data)
 	int iIndex = GPOINTER_TO_INT (data);
 	int iNumDesktop, iNumViewportX, iNumViewportY;
 	cd_switcher_compute_desktop_from_index (iIndex, &iNumDesktop, &iNumViewportX, &iNumViewportY);
-	if (iNumDesktop != myData.switcher.iCurrentDesktop)
-		cairo_dock_set_current_desktop (iNumDesktop);
-	if (iNumViewportX != myData.switcher.iCurrentViewportX || iNumViewportY != myData.switcher.iCurrentViewportY)
-		cairo_dock_set_current_viewport (iNumViewportX, iNumViewportY);
+	
+	if (iNumViewportX != myData.switcher.iCurrentViewportX
+	|| iNumViewportY != myData.switcher.iCurrentViewportY
+	|| iNumDesktop != myData.switcher.iCurrentDesktop)
+		gldi_desktop_set_current (iNumDesktop, iNumViewportX, iNumViewportY);
 	CD_APPLET_LEAVE ();
 }
-static void _cd_switcher_list_window_on_viewport (Icon *pIcon, int iNumDesktop, int iNumViewportX, int iNumViewportY, GtkWidget *pMenu)
+static void _cd_switcher_add_window_on_viewport (Icon *pIcon, int iNumDesktop, int iNumViewportX, int iNumViewportY, GtkWidget *pMenu)
 {
 	//g_print (" + %s\n", pIcon->cName);
 	
@@ -541,16 +563,15 @@ static void _cd_switcher_list_window_on_viewport (Icon *pIcon, int iNumDesktop,
 	
 	// on ajoute une entree au menu avec le pixbuf.
 	gchar *cLabel = cairo_dock_cut_string (pIcon->cName, 50);
-	GtkWidget *pMenuItem = gtk_image_menu_item_new_with_label (cLabel);
+	GtkWidget *pMenuItem = gldi_menu_add_item (pMenu, cLabel, "", G_CALLBACK (_show_window), pIcon);
 	g_free (cLabel);
+	
 	if (pixbuf)
 	{
 		GtkWidget *image = gtk_image_new_from_pixbuf (pixbuf);
-		_gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (pMenuItem), image);
+		gldi_menu_item_set_image (pMenuItem, image);
 		g_object_unref (pixbuf);
 	}
-	gtk_menu_shell_append  (GTK_MENU_SHELL (pMenu), pMenuItem);
-	g_signal_connect (G_OBJECT (pMenuItem), "activate", G_CALLBACK (_show_window), pIcon);
 }
 void cd_switcher_build_windows_list (GtkWidget *pMenu)
 {
@@ -586,14 +607,11 @@ void cd_switcher_build_windows_list (GtkWidget *pMenu)
 					g_string_printf (sDesktopName, "<b>%s %d (%s)</b>", D_("Desktop"), k+1, D_("Current"));
 				else
 					g_string_printf (sDesktopName, "<b>%s %d</b>", D_("Desktop"), k+1);
-			}  // les noms des bureaux : _NET_DESKTOP_NAMES, UTF8_STRING
-			pMenuItem = gtk_menu_item_new ();
-			GtkWidget *pLabel = gtk_label_new (sDesktopName->str);
+			}
+			pMenuItem = gldi_menu_add_item (pMenu, sDesktopName->str, NULL, G_CALLBACK (_show_desktop), GINT_TO_POINTER (k));
+			GtkWidget *pLabel = gtk_bin_get_child (GTK_BIN(pMenuItem));
 			gtk_label_set_use_markup (GTK_LABEL (pLabel), TRUE);
 			gtk_misc_set_alignment (GTK_MISC (pLabel), .5, .5);
-			gtk_container_add (GTK_CONTAINER (pMenuItem), pLabel);
-			gtk_menu_shell_append  (GTK_MENU_SHELL (pMenu), pMenuItem);
-			g_signal_connect (G_OBJECT (pMenuItem), "activate", G_CALLBACK (_show_desktop), GINT_TO_POINTER (k));
 			
 			pMenuItem = gtk_separator_menu_item_new ();
 			gtk_menu_shell_append(GTK_MENU_SHELL (pMenu), pMenuItem);
@@ -604,7 +622,7 @@ void cd_switcher_build_windows_list (GtkWidget *pMenu)
 			cd_switcher_foreach_window_on_viewport (iNumDesktop,
 				iNumViewportX,
 				iNumViewportY,
-				(CDSwitcherActionOnViewportFunc) _cd_switcher_list_window_on_viewport,
+				(CDSwitcherActionOnViewportFunc) _cd_switcher_add_window_on_viewport,
 				pMenu);
 			
 			// on passe au viewport suivant.
@@ -635,7 +653,7 @@ static void _cd_switcher_move_window_to_viewport (Icon *pIcon, int iNumDesktop,
 	int iDestNumViewportX = data[1];
 	int iDestNumViewportY = data[2];
 	
-	cairo_dock_move_xwindow_to_nth_desktop (pIcon->Xid,
+	gldi_window_move_to_desktop (pIcon->pAppli,
 		iDestNumDesktop,
 		(iDestNumViewportX - myData.switcher.iCurrentViewportX) * g_desktopGeometry.Xscreen.width,
 		(iDestNumViewportY - myData.switcher.iCurrentViewportY) * g_desktopGeometry.Xscreen.height);
