@@ -39,7 +39,7 @@ struct _AppletConfig {
 struct _AppletData {
 	CairoDialog *dialog;
 	NaTray *tray;
-	CairoKeyBinding *cKeyBinding;
+	GldiShortkey *cKeyBinding;
 } ;
 
 
