@@ -28,9 +28,9 @@ CD_APPLET_CONFIG_H
 
 void cd_weather_free_location_list (void);
 
-void cd_weather_reset_all_datas (CairoDockModuleInstance *myApplet);
+void cd_weather_reset_all_datas (GldiModuleInstance *myApplet);
 
-void cd_weather_load_custom_widget (CairoDockModuleInstance *myApplet, GKeyFile* pKeyFile, GSList *pWidgetList);
+void cd_weather_load_custom_widget (GldiModuleInstance *myApplet, GKeyFile* pKeyFile, GSList *pWidgetList);
 
 
 #endif
