@@ -42,7 +42,7 @@ const char *cMonthsWeeks[19] = { N_("Monday") , N_("Tuesday") , N_("Wednesday")
 		pIconList = g_list_append (pIconList, pIcon);\
 	}
 
-static GList * _list_icons (CairoDockModuleInstance *myApplet)
+static GList * _list_icons (GldiModuleInstance *myApplet)
 {
 	GList *pIconList = NULL;
 	
@@ -62,7 +62,7 @@ static GList * _list_icons (CairoDockModuleInstance *myApplet)
 }
 
 
-static void _weather_draw_current_conditions (CairoDockModuleInstance *myApplet)
+static void _weather_draw_current_conditions (GldiModuleInstance *myApplet)
 {
 	if (myConfig.bCurrentConditions || myData.bErrorRetrievingData)
 	{
@@ -112,14 +112,14 @@ static void _weather_draw_current_conditions (CairoDockModuleInstance *myApplet)
 
 gboolean cd_weather_update_from_data (CDSharedMemory *pSharedMemory)
 {
-	CairoDockModuleInstance *myApplet = pSharedMemory->pApplet;
+	GldiModuleInstance *myApplet = pSharedMemory->pApplet;
 	g_return_val_if_fail (myIcon != NULL, FALSE);  // paranoia
 	CD_APPLET_ENTER;
 	
 	if (myData.bBusy)
 	{
 		myData.bBusy = FALSE;
-		cairo_dock_request_icon_animation (myIcon, myContainer, NULL, 0);
+		CD_APPLET_STOP_ANIMATING_MY_ICON;
 	}
 	
 	//\_______________________ in case an error occured, keep the current data, and just redraw the main icon.
@@ -135,7 +135,7 @@ gboolean cd_weather_update_from_data (CDSharedMemory *pSharedMemory)
 			if (myData.pTask->iPeriod > 20)
 			{
 				cd_message ("no data, will re-try in 20s");
-				cairo_dock_change_task_frequency (myData.pTask, 20);
+				gldi_task_change_frequency (myData.pTask, 20);
 			}
 			
 		}
@@ -180,7 +180,7 @@ gboolean cd_weather_update_from_data (CDSharedMemory *pSharedMemory)
 	}
 	else if (myDock)  // sinon on ne veut pas du sous-dock vide.
 	{
-		cairo_dock_destroy_dock (myIcon->pSubDock, myIcon->cName);
+		gldi_object_unref (GLDI_OBJECT(myIcon->pSubDock));
 		myIcon->pSubDock = NULL;
 	}
 	if (myDesklet)
@@ -193,7 +193,7 @@ gboolean cd_weather_update_from_data (CDSharedMemory *pSharedMemory)
 	if (myData.pTask->iPeriod != myConfig.iCheckInterval)
 	{
 		cd_message ("revert to normal frequency");
-		cairo_dock_change_task_frequency (myData.pTask, myConfig.iCheckInterval);
+		gldi_task_change_frequency (myData.pTask, myConfig.iCheckInterval);
 	}
 	
 	CD_APPLET_LEAVE (TRUE);
