@@ -39,9 +39,9 @@ CD_APPLET_GET_CONFIG_BEGIN
 	myConfig.cGThemePath = CD_CONFIG_GET_GAUGE_THEME ("Configuration", "theme");
 	
 	myConfig.iGraphType = CD_CONFIG_GET_INTEGER ("Configuration", "graphic type");
-	CD_CONFIG_GET_COLOR_RVB ("Configuration", "low color", myConfig.fLowColor);
-	CD_CONFIG_GET_COLOR_RVB ("Configuration", "high color", myConfig.fHigholor);
-	CD_CONFIG_GET_COLOR ("Configuration", "bg color", myConfig.fBgColor);
+	CD_CONFIG_GET_COLOR_RGB ("Configuration", "low color", myConfig.fLowColor);
+	CD_CONFIG_GET_COLOR_RGB ("Configuration", "high color", myConfig.fHigholor);
+	CD_CONFIG_GET_COLOR_RGBA ("Configuration", "bg color", myConfig.fBgColor);
 	
 	if (! g_key_file_has_key (CD_APPLET_MY_KEY_FILE, "Configuration", "default_icon", NULL))  // new option -> get the previous "excellent" user icon
 	{
@@ -67,12 +67,13 @@ CD_APPLET_RESET_CONFIG_END
 
 
 CD_APPLET_RESET_DATA_BEGIN
-	cairo_dock_free_task (myData.pTask);
+	gldi_task_free (myData.pTask);
 	
 	CD_APPLET_REMOVE_MY_DATA_RENDERER;
 	
 	g_free (myData.cESSID);
 	g_free (myData.cInterface);
 	g_free (myData.cAccessPoint);
-	
+	g_free (myData.cIWConfigPath);
+
 CD_APPLET_RESET_DATA_END
